@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.PostPriorityPicker{width:324px}.PostPriorityPicker__apply{height:32px;padding:0 16px;font-size:12px;line-height:10px;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out}.PostPriorityPicker__apply:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.PostPriorityPicker__apply:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.PostPriorityPicker__apply:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.PostPriorityPicker__apply:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.PostPriorityPicker__apply i{display:flex;font-size:18px}.PostPriorityPicker__cancel{height:32px;padding:0 16px;font-size:12px;line-height:10px;display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out}.PostPriorityPicker__cancel:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.PostPriorityPicker__cancel:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.PostPriorityPicker__cancel:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.PostPriorityPicker__cancel i{display:flex;font-size:18px}.PostPriorityPicker__cancel i:first-child::before{margin:0 7px 0 0}.PostPriorityPicker__cancel i:last-child::before{margin:0 0 0 7px}
button.call-button{display:flex;height:32px;align-items:center;justify-content:center;padding:10px 12px;border-radius:4px;color:rgb(var(--button-bg-rgb));fill:currentColor}button.call-button:hover{background:rgba(var(--button-bg-rgb), 0.08)}button.call-button:active,button.call-button.active{background:rgba(var(--button-bg-rgb), 0.16)}button.call-button i,button.call-button span{font-size:14px;line-height:14px}button.call-button i::before,button.call-button span::before{margin:0}button.call-button svg{width:14px;height:14px}button.call-button span.call-button-label{padding:1px 0;margin:0 6px;font-size:12px;font-weight:600;line-height:9px}button.call-button.dropdown{color:rgba(var(--center-channel-color-rgb), 0.56);fill:currentColor}button.call-button.disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;fill:currentColor}button.call-button.disabled:hover{background:none}button.call-button.disabled:active{background:none}.Menu .MenuItem>button.call-button-dropdown{display:flex;padding:6px 20px 6px 16px;margin:0;color:rgb(var(--button-bg-rgb));font-size:14px;line-height:20px}.Menu .MenuItem>button.call-button-dropdown svg{width:16px;height:16px;align-self:flex-start;margin-right:12px;margin-left:4px;fill:currentColor}.Menu .MenuItem>button.call-button-dropdown i{align-self:flex-start;margin-right:12px;margin-left:4px;color:inherit;font-size:16px}.Menu .MenuItem>button.call-button-dropdown i::before{margin:0}.Menu .MenuItem>button.call-button-dropdown .call-button-dropdown-sublabel{margin-top:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.Menu .MenuItem>button.call-button-dropdown div{display:flex;flex-direction:column}.Menu .MenuItem>button.call-button-dropdown.disabled{color:rgba(var(--center-channel-color-rgb), 0.32);fill:currentColor}.Menu .MenuItem>button.call-button-dropdown.disabled svg{width:16px;height:16px;fill:currentColor}.Menu .MenuItem>button.call-button-dropdown.disabled i{color:inherit;font-size:16px}.Menu .MenuItem>button.call-button-dropdown.disabled i::before{margin:0}.Menu .MenuItem>button.call-button-dropdown.disabled .call-button-dropdown-sublabel{color:inherit;font-size:12px}
#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body{display:flex;flex-direction:column;gap:20px;overflow-y:visible;transition:height 200ms ease}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.multi-team{min-height:340px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.single-team{height:230px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.loading{height:152px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.error{height:unset}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .new-channel-modal__url{margin-top:-20px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .loadingIndicator{display:block;width:32px;height:32px;margin:36px auto 48px;font-size:32px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .conversion-error{color:var(--error-text)}#convert-gm-to-channel-modal .DropDown__menu{z-index:999;max-height:120px}#convert-gm-to-channel-modal .DropDown__menu-list{z-index:999;max-height:120px}#convert-gm-to-channel-modal .modal-body{overflow:visible}#convert-gm-to-channel-modal .GenericModal__button.delete.disabled{color:var(--button-color) !important;opacity:.65}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.url-input-main{display:flex;flex-direction:column}.url-input-main .url-input-container{display:flex;min-height:32px;flex-wrap:wrap;align-items:center;margin-top:4px}.url-input-main .url-input-container .url-input-label{max-width:100%;flex:none;margin-right:4px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:17px;overflow-wrap:anywhere}.url-input-main .url-input-container .url-input-editable-container{width:auto;margin-right:6px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper{padding:0 12px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper .url-input-editable-path{height:26px;border:0;border-radius:0;font-size:12px;line-height:16px}.url-input-main .url-input-container .url-input-button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;padding:0;border:none;background:var(--center-channel-bg);box-shadow:none}.url-input-main .url-input-container .url-input-button:hover,.url-input-main .url-input-container .url-input-button:active,.url-input-main .url-input-container .url-input-button:focus{text-decoration-line:underline}.url-input-main .url-input-container .url-input-button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.url-input-main .url-input-container .url-input-button .url-input-button-label{line-height:9px}.url-input-main .url-input-error{display:flex;margin-top:5px;color:var(--error-text);font-size:12px;line-height:16px;text-align:left}.url-input-main .url-input-error i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.url-input-main .url-input-error i::before{margin:0}
.channel-name-input-field{height:34px !important;border:0 !important;border-radius:0 !important}
.sectionNoticeContainer{position:relative;border-width:1px;border-style:solid;border-radius:4px}.sectionNoticeContainer p{margin:0}.sectionNoticeContainer.info{border-color:rgba(var(--sidebar-text-active-border-rgb), 0.16);background:rgba(var(--sidebar-text-active-border-rgb), 0.08)}.sectionNoticeContainer.info p{color:var(--center-channel-color)}.sectionNoticeContainer.success{border-color:rgba(var(--online-indicator-rgb), 0.16);background:rgba(var(--online-indicator-rgb), 0.08)}.sectionNoticeContainer.success p{color:var(--center-channel-color)}.sectionNoticeContainer.danger{border-color:rgba(var(--dnd-indicator-rgb), 0.16);background:rgba(var(--dnd-indicator-rgb), 0.08)}.sectionNoticeContainer.danger p{color:var(--center-channel-color)}.sectionNoticeContainer.welcome{border-color:rgba(var(--center-channel-color-rgb), 0.08);background:rgba(var(--center-channel-color-rgb), 0.04)}.sectionNoticeContainer.welcome p{color:rgba(var(--center-channel-color-rgb), 0.72)}.sectionNoticeContainer.warning{border-color:rgba(var(--away-indicator-rgb), 0.16);background:rgba(var(--away-indicator-rgb), 0.08)}.sectionNoticeContainer.warning p{color:var(--center-channel-color)}.sectionNoticeActions{display:flex;flex-flow:wrap}.sectionNoticeClose{position:absolute;top:10px;right:10px}.sectionNoticeContent{display:flex;flex-direction:row;align-items:start;padding:16px;gap:12px}.sectionNoticeIcon{font-size:20px}.sectionNoticeIcon.info{color:var(--sidebar-text-active-border)}.sectionNoticeIcon.success{color:var(--online-indicator)}.sectionNoticeIcon.danger{color:var(--dnd-indicator)}.sectionNoticeIcon.warning{color:var(--away-indicator)}.sectionNoticeTitle{margin:0;color:var(--center-channel-color);font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px}.sectionNoticeTitle.welcome{font-family:"Metropolis";font-size:20px;line-height:28px}.sectionNoticeBody{display:flex;flex-direction:column;gap:8px}.sectionNoticeButton{margin-top:4px;margin-bottom:4px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.CenterMessageLock{display:flex;align-items:center;padding:16px;border:1px rgba(var(--center-channel-color-rgb), 0.08) solid;margin:0 24px 13px;background-color:rgba(var(--center-channel-color-rgb), 0.04);border-radius:4px}.CenterMessageLock__left{align-self:flex-start;padding:0 12px}.CenterMessageLock__icon{color:rgba(var(--center-channel-color-rgb), 0.72)}.CenterMessageLock__title{padding-bottom:8px;font-size:14px;font-weight:600}.CenterMessageLock__cta{padding-top:12px}.CenterMessageLock__cta .btn{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;font-size:12px}.CenterMessageLock__cta .btn:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.CenterMessageLock__cta .btn:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.CenterMessageLock__cta .btn:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.CenterMessageLock__cta .btn i{display:flex;font-size:18px}.CenterMessageLock__cta .btn i:first-child::before{margin:0 7px 0 0}.CenterMessageLock__cta .btn i:last-child::before{margin:0 0 0 7px}.CenterMessageLock__cta .btn:hover,.CenterMessageLock__cta .btn:focus{color:var(--button-color)}.CenterMessageLock__cta .btn:focus{border:0}.CenterMessageLock__cta .btn.is-admin{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out}.CenterMessageLock__cta .btn.is-admin:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.CenterMessageLock__cta .btn.is-admin:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.CenterMessageLock__cta .btn.is-admin i{display:flex;font-size:18px}.CenterMessageLock__cta .btn.is-admin:hover,.CenterMessageLock__cta .btn.is-admin:focus{color:var(--button-color)}.CenterMessageLock__cta .btn.is-admin:focus{border:0}
.LessThanMaxFreeUsers,.MoreThanMaxFreeUsers{display:flex;flex-direction:row;margin-top:10px}.LessThanMaxFreeUsers .titleAndButton,.MoreThanMaxFreeUsers .titleAndButton{display:flex;flex-direction:column;padding:20px 5px;margin-left:20px}.LessThanMaxFreeUsers .titleAndButton>span,.MoreThanMaxFreeUsers .titleAndButton>span{margin-bottom:15px;font-size:16px;font-weight:600;line-height:24px}.LessThanMaxFreeUsers button,.MoreThanMaxFreeUsers button{width:fit-content;padding:8px 16px;border:none;background-color:var(--button-bg);border-radius:4px;color:var(--button-color);font-size:12px;font-weight:600;line-height:16px}.LessThanMaxFreeUsers button span,.MoreThanMaxFreeUsers button span{color:var(--button-color)}.LessThanMaxFreeUsers button i,.MoreThanMaxFreeUsers button i{color:var(--button-color);font-size:14px}.LessThanMaxFreeUsers button:hover:not(.disabled),.MoreThanMaxFreeUsers button:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg);color:var(--button-color);text-decoration:none}.MoreThanMaxFreeUsersWrapper{display:flex;flex-direction:row}.MoreThanMaxFreeUsersWrapper .channelIntroButton{margin-top:10px}.channelIntroButton{border-radius:4px;color:var(--button-bg);font-size:12px;font-weight:600;line-height:16px}.channelIntroButton i{font-size:14px}.channelIntroButton:hover{background-color:rgba(var(--button-bg-rgb), 0.04)}
.hint-toast{padding:4px 4px 4px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:0;background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 6px 14px rgba(0,0,0,.12);color:var(--center-channel-color);font-size:14px;font-weight:bold}.hint-toast .hint-toast__message{display:inline-block;line-height:20px;text-align:center;vertical-align:middle}.hint-toast .hint-toast__message .shortcut-key{font-weight:600}.hint-toast .hint-toast__dismiss{display:inline-block;padding:4px;margin-left:16px}.hint-toast .hint-toast__dismiss:hover{background-color:var(--center-channel-bg)}.hint-toast .hint-toast__dismiss:hover svg{fill:rgba(var(--center-channel-color-rgb), 0.72)}.hint-toast .hint-toast__dismiss svg{padding-top:2px;fill:rgba(var(--center-channel-color-rgb), 0.56);vertical-align:middle}.hint-toast .hint-toast__dismiss .close-btn{cursor:pointer;line-height:normal}.hint-toast__wrapper{position:absolute;z-index:3;display:flex;width:100%;align-items:center;justify-content:center}
.scroll-to-bottom-toast{display:flex;align-items:center;justify-content:space-between;padding:4px;padding-left:12px;background:linear-gradient(0deg, rgba(63, 67, 80, 0.9) 0%, rgba(63, 67, 80, 0.9) 100%),#fff;border-radius:4px;box-shadow:0 4px 6px 0 rgba(0,0,0,.12);color:var(--sidebar-text);cursor:pointer;font-size:14px;font-weight:600;gap:8px}.scroll-to-bottom-toast:hover{background-color:var(--center-channel-color)}.scroll-to-bottom-toast svg{fill:var(--sidebar-text);vertical-align:middle}body.enable-animations .scroll-to-bottom-toast{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.scroll-to-bottom-toast .scroll-to-bottom-toast__message{display:inline-block;line-height:20px;vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__message>svg{margin-right:8px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss{display:inline-block;padding:4px;border-radius:4px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss:hover{background-color:var(--center-channel-bg-08)}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss svg{padding-top:1px;fill:rgba(var(--sidebar-text-rgb), 0.56);vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss .close-btn{cursor:pointer;line-height:normal}
.search-shortcut{display:inline-block;margin:0 4px}.search-shortcut .shortcut-key{margin-right:4px}.search-shortcut .shortcut-key:last-child{margin-right:0}
.toasts-wrapper{position:absolute;z-index:3;display:flex;width:100%;align-items:center;justify-content:center;margin-top:16px;gap:7px}
.productNotices{width:692px}.app__body .modal .productNotices .modal-content{padding:40px}.productNotices .GenericModal__header{padding:0;margin-bottom:16px}.productNotices .GenericModal__body{padding:0}.productNotices .productNotices__helpText{margin-top:8px}.productNotices .productNotices__helpText p{margin-bottom:16px}.productNotices .productNotices__img{display:block;max-height:347px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:32px auto 0;border-radius:4px}.productNotices .productNotices__imageDiv{margin:0 auto}.productNotices .modal-footer{margin-top:32px}.productNotices .productNotices__info{position:fixed;z-index:1;bottom:45px}.productNotices .circle{width:6px;height:6px;margin:0 3px;background-color:var(--center-channel-color);vertical-align:middle}.productNotices svg{margin-right:5px;margin-left:23px;vertical-align:middle}.app__body .modal .productNotices.modal-dialog{height:unset;margin-top:calc(50vh - 307px)}.app__body .modal .productNotices .modal-footer{position:relative;padding:0}.productNotices .GenericModal__button{display:inline-flex;align-items:center;padding:13px 20px;border:none;font-size:14px;line-height:14px}.productNotices .GenericModal__button.confirm{background:var(--button-bg);color:var(--button-color)}.productNotices .GenericModal__button.confirm:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg)}.productNotices .GenericModal__button.confirm:active{background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.32), rgba(var(--center-channel-color-rgb), 0.32)),var(--button-bg)}.productNotices .GenericModal__button.confirm:focus{box-shadow:inset 0 0 0 2px var(--sidebar-text-active-border)}.productNotices .GenericModal__button.cancel,.productNotices .GenericModal__button.actionButton{display:inline-flex;align-items:center;background:var(--center-channel-bg);border-radius:4px;color:var(--button-bg);text-decoration:none}.productNotices .GenericModal__button.cancel:hover,.productNotices .GenericModal__button.actionButton:hover{background:rgba(var(--button-bg-rgb), 0.04)}.productNotices .GenericModal__button.cancel:active,.productNotices .GenericModal__button.actionButton:active{background:rgba(var(--button-bg-rgb), 0.08)}.productNotices .GenericModal__button.cancel:focus,.productNotices .GenericModal__button.actionButton:focus{box-shadow:inset 0 0 0 2px var(--sidebar-text-active-border)}.productNotices .GenericModal__button.actionButton{box-shadow:inset 0 0 0 1px var(--button-bg)}.productNotices .GenericModal__button.cancel{margin-right:12px}.productNotices .GenericModal__button .fa{font-size:14px}.productNotices .GenericModal__button .fa:first-child{margin-right:7px}.productNotices .GenericModal__button span~.fa{margin-left:7px}
.public-private-selector{display:flex;flex-direction:row}.public-private-selector .public-private-selector-button{display:flex;min-width:0;box-sizing:border-box;flex:1;align-items:center;padding:12px 22px 12px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button:not(:first-child){margin-left:8px}.public-private-selector .public-private-selector-button.a11y--focused,.public-private-selector .public-private-selector-button:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon,.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon-check{fill:var(--button-bg)}.public-private-selector .public-private-selector-button.selected:hover{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.4);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.disabled,.public-private-selector .public-private-selector-button.locked{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.4}.public-private-selector .public-private-selector-button.disabled:hover,.public-private-selector .public-private-selector-button.locked:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button.disabled.selected,.public-private-selector .public-private-selector-button.locked.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button .public-private-selector-button-text{min-width:0;flex:1;margin-left:12px;text-align:left}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title{overflow:hidden;color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title .public-private-selector-button-icon-upgrade{display:inline-flex;width:16px;height:16px;margin-left:8px;fill:var(--online-indicator);vertical-align:sub}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-description{overflow:hidden;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-icon{display:flex;flex:none;fill:rgba(var(--center-channel-color-rgb), 0.56)}.public-private-selector .public-private-selector-button .public-private-selector-button-icon-check{display:flex;flex:none;margin-left:auto}@media screen and (max-width: 640px){.public-private-selector{flex-direction:column}.public-private-selector .public-private-selector-button:not(:first-child){margin:8px 0 0}}
.new-channel-modal .new-channel-modal-type-selector{margin-top:24px}.new-channel-modal .new-channel-modal-purpose-container{margin-top:28px}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea{width:100%;box-sizing:border-box;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);border-radius:4px;color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error{border-color:var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-info{margin-top:5px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;line-height:16px;text-align:left}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-error{display:flex;margin-top:5px;color:var(--error-text);font-size:12px;line-height:16px;text-align:left}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-error i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-error i::before{margin:0}#new-channel-with-board-tooltip span{display:block;width:100%;text-align:left !important}#new-channel-with-board-tooltip .title{font-weight:800}#new-channel-with-board-tooltip .description{font-weight:500}
#browseChannelsModal .modal-content{min-height:600px;max-height:calc(50vh - 240px)}#browseChannelsModal .modal-dialog{margin-top:calc(45vh - 240px) !important}#browseChannelsModal .filter-row--full{position:relative;padding:0 32px}#browseChannelsModal .filter-row--full .input-clear{top:16px;right:46px}#browseChannelsModal .filter-row--full #searchIcon{position:absolute;z-index:1;top:15px;left:42px;color:rgba(var(--center-channel-color-rgb), 0.64);pointer-events:none}#browseChannelsModal .filter-row--full #searchChannelsTextbox{height:48px;padding-left:40px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:none;font-size:16px}#browseChannelsModal .filter-row--full #searchChannelsTextbox::placeholder{color:var(--center-channel-color)}#browseChannelsModal .filter-row--full #searchChannelsTextbox:focus{border:2px solid var(--button-bg)}#browseChannelsModal .more-modal__dropdown{display:flex;align-items:center;justify-content:space-between;padding:8px 32px;border-bottom:solid 1px rgba(var(--center-channel-color-rgb), 0.16);margin:0}#browseChannelsModal .more-modal__dropdown span{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:16px}#browseChannelsModal .more-modal__dropdown #channelCountLabel{color:var(--center-channel-color);font-size:12px;font-weight:400}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer{display:flex;align-items:center;justify-content:center}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox{display:flex;width:16px;height:16px;align-items:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.24)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #hideJoinedPreferenceCheckbox{display:flex;align-items:center;cursor:pointer}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper{display:flex;align-items:center;justify-content:center;padding:4px 6px 4px 8px;border:none;margin-right:10px;background-color:unset}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper[aria-expanded=true]{background-color:rgba(var(--button-bg-rgb), 0.12);border-radius:4px}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px}#browseChannelsModal .modal-body{padding:0}#browseChannelsModal .modal-body .filtered-user-list{height:500px}#browseChannelsModal .modal-body .more-modal__row{padding:0 32px;border-bottom:none}#browseChannelsModal .modal-body .more-modal__row .more-modal__details{padding-left:0;color:rgba(var(--center-channel-color-rgb), 0.56)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details svg{flex-shrink:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name{align-items:center;margin-top:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name span{color:var(--center-channel-color);font-weight:500}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer{display:flex;align-items:center;justify-content:flex-start}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .dot{width:3px;height:3px;flex-shrink:0;background-color:rgba(var(--center-channel-color-rgb), 0.56);border-radius:50%}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .more-modal__description{margin-left:4px;font-weight:400}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer{display:flex;align-items:center}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer span,#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer svg{color:var(--online-indicator)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer span{margin:0 4px;font-size:12px;font-weight:600;line-height:12px;opacity:1}#browseChannelsModal .modal-body .more-modal__row .more-modal__actions button{display:none;min-width:54px;height:32px;font-size:12px;font-weight:600}#browseChannelsModal .modal-body .more-modal__row:hover,#browseChannelsModal .modal-body .more-modal__row:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer}#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .outlineButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .outlineButton{display:inline-block}#browseChannelsModal .modal-body .form-group{padding:0 32px;margin-bottom:0}#browseChannelsModal .modal-body ::-webkit-scrollbar{width:4px}#browseChannelsModal .modal-body ::-webkit-scrollbar-track{background:none}#browseChannelsModal .modal-header .GenericModal__header{display:flex;width:100%;align-items:center;justify-content:space-between;padding-right:4px}#browseChannelsModal .modal-header .close{top:22px}#browseChannelsModal .filter-controls{padding:0}#browseChannelsModal .filter-controls button{min-width:72px;margin:8px 32px}#moreChannelsList .primary-message{margin-top:8px;color:var(--center-channel-color);line-height:28px}#moreChannelsList .secondary-message{margin-bottom:30px}#moreChannelsList #createNewChannelButton{padding:10px 20px}#browseChannelsDropdown .label-elements{padding:2px 4px;font-size:14px;line-height:20px}
#SidebarContainer .SidebarDrafts .SidebarChannel{height:100%}#SidebarContainer .SidebarDrafts .SidebarLink{width:100%}#SidebarContainer .SidebarDrafts .SidebarLink .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.6);vertical-align:middle}#SidebarContainer .SidebarDrafts .SidebarLink .badge{background:rgba(0,0,0,0);color:var(--sidebar-text)}#SidebarContainer .SidebarDrafts .SidebarLink:hover{padding-right:16px}#SidebarContainer .SidebarDrafts .SidebarLink:hover .badge{position:initial;visibility:visible}.sidebar--left .SidebarDrafts{padding-bottom:0;margin-top:13px}.sidebar--left .SidebarDrafts .icon{width:auto;padding-left:1px;margin-top:1px}.sidebar--left .SidebarDrafts .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.6)}.sidebar--left .SidebarDrafts .SidebarChannelLinkLabel_wrapper{display:flex;flex:1}.sidebar--left .SidebarDrafts .badge{margin:0 12px 0 0}
.GenericModal.CollapsedReplyThreadsModal{width:692px;padding:0 1.6rem}.GenericModal.CollapsedReplyThreadsModal .modal-content{padding:16px 15px}@media screen and (max-width: 767px){.app__body .modal .GenericModal.CollapsedReplyThreadsModal .modal-content{padding:24px}}.GenericModal.CollapsedReplyThreadsModal .CollapsedReplyThreadsModal__img{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-top:40px;border-radius:4px}.GenericModal.CollapsedReplyThreadsModal .modal-footer{margin-top:20px}.modal .GenericModal.CollapsedReplyThreadsModal.modal-dialog{height:unset;margin-top:calc(50vh - 307px)}.modal .GenericModal.CollapsedReplyThreadsModal .modal-footer{position:relative}
#SidebarContainer .SidebarGlobalThreads .SidebarChannel{height:100%}#SidebarContainer .SidebarGlobalThreads .SidebarLink{width:100%}#SidebarContainer .SidebarGlobalThreads .SidebarLink .icon{padding:3px;margin-right:8px;margin-left:1px}#SidebarContainer .SidebarGlobalThreads .SidebarLink .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.6);vertical-align:middle}#SidebarContainer .SidebarGlobalThreads .SidebarLink:hover{padding-right:16px}#SidebarContainer .SidebarGlobalThreads .SidebarLink:hover .badge{position:initial;visibility:visible}.sidebar--left .SidebarGlobalThreads{padding-bottom:0;margin-top:13px}.sidebar--left .SidebarGlobalThreads .icon{width:auto;padding-left:1px;margin-top:1px}.sidebar--left .SidebarGlobalThreads .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.6)}.sidebar--left .SidebarGlobalThreads .SidebarChannelLinkLabel_wrapper{display:flex;flex:1}.sidebar--left .SidebarGlobalThreads .badge{margin:0 12px 0 0}
#SidebarContainer .SidebarChannel .SidebarLink .channel-pencil-icon{position:relative;display:flex;width:28px;min-width:0;flex:0 0 28px;align-items:center;justify-content:center;padding:0;margin:0;font-size:14px;line-height:18px}
.nav-pills__unread-indicator{position:absolute;z-index:2;display:flex;width:188px;height:auto;align-items:center;justify-content:center;padding:8px;margin-left:50%;background:var(--mention-bg);border-radius:4px;box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--mention-color);cursor:pointer;font-size:14px;font-weight:700;line-height:16px;opacity:0;text-align:center;transform:translateX(-50%);visibility:hidden}.nav-pills__unread-indicator .icon{display:inline-flex;align-items:center;justify-content:center;margin-right:8px}body.enable-animations .nav-pills__unread-indicator{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}.nav-pills__unread-indicator svg{fill:var(--mention-color)}.nav-pills__unread-indicator-top{top:16px}.nav-pills__unread-indicator-top .icon svg{transform:rotate(180deg)}.nav-pills__unread-indicator-bottom{bottom:16px}.nav-pills__unread-indicator--visible{opacity:1;visibility:visible}body.enable-animations .nav-pills__unread-indicator--visible{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}@media screen and (max-width: 768px){.nav-pills__unread-indicator{width:260px}}@media screen and (max-width: 480px){.nav-pills__unread-indicator{width:230px}}@media screen and (max-width: 320px){.multi-teams .nav-pills__unread-indicator{width:190px}}

/*# sourceMappingURL=927.63303a970be9da2caea9.css.map*/