.customKeywordsWithNotificationSubsection .multiInput{margin-block-start:10px}.notificationSettingsModalHeader{display:flex}.notificationSettingsModalHeader>span{align-self:center;margin-left:auto}.notificationSettingsModalHeader>span a{display:flex;align-items:center}.notificationSettingsModalHeader>span a:hover,.notificationSettingsModalHeader>span a:active,.notificationSettingsModalHeader>span a:focus{color:var(--button-bg);text-decoration:none}.notificationSettingsModalHeader>span a>i{font-size:14.4px}.notificationSettingsModalHeader>span a>span{font-size:12px;font-weight:600;line-height:16px}.notificationSettingsModalHeader>span a>span:hover{text-decoration:underline}.notificationSettingsModalHeader>span a>svg{width:18px;height:18px;padding:2px;margin-right:4px;background:rgba(var(--button-bg-rgb), 0.12);border-radius:50%;text-align:center}
.sectionNoticeContainer{position:relative;border-width:1px;border-style:solid;border-radius:4px}.sectionNoticeContainer p{margin:0}.sectionNoticeContainer.info{border-color:rgba(var(--sidebar-text-active-border-rgb), 0.16);background:rgba(var(--sidebar-text-active-border-rgb), 0.08)}.sectionNoticeContainer.info p{color:var(--center-channel-color)}.sectionNoticeContainer.success{border-color:rgba(var(--online-indicator-rgb), 0.16);background:rgba(var(--online-indicator-rgb), 0.08)}.sectionNoticeContainer.success p{color:var(--center-channel-color)}.sectionNoticeContainer.danger{border-color:rgba(var(--dnd-indicator-rgb), 0.16);background:rgba(var(--dnd-indicator-rgb), 0.08)}.sectionNoticeContainer.danger p{color:var(--center-channel-color)}.sectionNoticeContainer.welcome{border-color:rgba(var(--center-channel-color-rgb), 0.08);background:rgba(var(--center-channel-color-rgb), 0.04)}.sectionNoticeContainer.welcome p{color:rgba(var(--center-channel-color-rgb), 0.72)}.sectionNoticeContainer.warning{border-color:rgba(var(--away-indicator-rgb), 0.16);background:rgba(var(--away-indicator-rgb), 0.08)}.sectionNoticeContainer.warning p{color:var(--center-channel-color)}.sectionNoticeActions{display:flex;flex-flow:wrap}.sectionNoticeClose{position:absolute;top:10px;right:10px}.sectionNoticeContent{display:flex;flex-direction:row;align-items:start;padding:16px;gap:12px}.sectionNoticeIcon{font-size:20px}.sectionNoticeIcon.info{color:var(--sidebar-text-active-border)}.sectionNoticeIcon.success{color:var(--online-indicator)}.sectionNoticeIcon.danger{color:var(--dnd-indicator)}.sectionNoticeIcon.warning{color:var(--away-indicator)}.sectionNoticeTitle{margin:0;color:var(--center-channel-color);font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px}.sectionNoticeTitle.welcome{font-family:"Metropolis";font-size:20px;line-height:28px}.sectionNoticeBody{display:flex;flex-direction:column;gap:8px}.sectionNoticeButton{margin-top:4px;margin-bottom:4px}
.pluginActionContainer{margin-bottom:20px}
.access-history-modal .table thead>tr>th,.access-history-modal .table tbody>tr>td{border-color:rgba(var(--center-channel-color-rgb), 0.12)}

/*# sourceMappingURL=4205.673ad6a051df400f0e6f.css.map*/