"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[8790],{78790:(t,e,a)=>{function s(t){return{name:"Plain text",aliases:["text","txt"],disableAutodetect:!0}}a.r(e),a.d(e,{default:()=>s})}}]);
//# sourceMappingURL=8790.cf194ce7a96d1e8c8c9f.js.map