"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[6640],{16640:(e,t)=>{var o,a;Object.defineProperty(t,"__esModule",{value:!0}),t.ReportDuration=t.LogLevel=void 0,(a=t.LogLevel||(t.LogLevel={})).Error="ERROR",a.Warning="WARNING",a.Info="INFO",a.Debug="DEBUG",(o=t.ReportDuration||(t.ReportDuration={})).Last30Days="last_30_days",o.PreviousMonth="previous_month",o.Last6Months="last_6_months"}}]);
//# sourceMappingURL=6640.bc2ba4f3b3017547c8f6.js.map