.Header{display:flex;align-items:center;justify-content:space-between;padding:0 16px}.Header h1,.Header h2,.Header h3,.Header h4,.Header h5,.Header h6{margin:0;line-height:1}.Header h2{color:rgba(var(--center-channel-color-rgb), 1);font-size:16px;font-weight:600}.Header>div p{margin:6px 0 0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;font-weight:400;line-height:16px}.Header>.spacer{flex:1}
.DraftAction__button{display:inline-flex;width:28px;height:28px;align-items:center;justify-content:center;border:none;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.4);fill:rgba(var(--center-channel-color-rgb), 0.4)}.DraftAction__button:hover,.DraftAction__button:active,.DraftAction__button--active{background:rgba(var(--center-channel-color-rgb), 0.08)}.DraftAction__button span{display:flex}.DraftAction .DraftAction__button--delete:hover,.DraftAction .DraftAction__button--delete:active,.DraftAction .DraftAction__button--delete--active{background:rgba(var(--dnd-indicator-rgb), 0.08)}.DraftAction .icon{color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.DraftAction .icon:hover{color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.DraftAction .icon-trash-can-outline,.DraftAction .icon-trash-can-outline:hover{color:var(--dnd-indicator);fill:var(--dnd-indicator)}.DraftAction+.DraftAction{padding-left:5px}
.DraftTitle__avatar{margin:0 .5em}.DraftTitle__group-icon{width:18px;min-width:18px;height:18px;margin:0 5px;background:rgba(var(--center-channel-color-rgb), 0.16);border-radius:2px;font-size:12px;font-weight:600;line-height:18px;text-align:center}
.Panel{border:1px solid rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1);cursor:pointer;transition:box-shadow .3s ease-in-out}.Panel+.Panel{margin-top:16px}.Panel:hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2);transition-duration:.15s}
.DraftPanelBody{display:flex;padding:16px}.DraftPanelBody__right{flex:1}.DraftPanelBody.post:hover{background-color:var(--center-channel-bg)}.DraftPanelBody .file-preview__container{height:auto;flex-wrap:wrap;padding-top:3px;margin:0 -5px}.DraftPanelBody .file-preview__container .file-preview.post-image__column{margin:1px 5px 5px;cursor:pointer}
.PanelHeader{display:flex;min-height:40px;flex-wrap:nowrap;align-items:center;justify-content:space-between;padding:0 16px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:16px}.PanelHeader__right{display:inline-flex;flex-shrink:0;flex-wrap:nowrap;align-items:center;justify-content:flex-end}.PanelHeader__right div+div{padding-left:4px}.PanelHeader__left{display:flex;overflow:hidden;flex-wrap:nowrap;align-items:center;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.PanelHeader__left>span{display:inline-flex;min-width:0;align-items:center}.PanelHeader__left>span span{overflow:hidden;min-width:0;text-overflow:ellipsis;white-space:nowrap}.PanelHeader__timestamp{padding-right:8px;color:rgba(var(--center-channel-color-rgb), 0.64);vertical-align:middle}.PanelHeader__sync-icon{display:flex;align-items:center}.PanelHeader__actions{display:none}.PanelHeader__actions.show{display:inline-flex !important}.PanelHeader__info{display:inline-flex;align-items:center}.PanelHeader__info.hide{display:none}
.Drafts{--border: 1px solid rgba(var(--center-channel-color-rgb), 0.16);display:grid;background:rgba(var(--center-channel-color-rgb), 0.04);grid-template-areas:"header" "list";grid-template-columns:var(--list);grid-template-rows:63px 1fr}.Drafts__header{border-bottom:var(--border);grid-area:header}.Drafts .channel-header__icon,.Drafts .search__form{margin-top:1px}.Drafts__main{display:flex;overflow:auto;flex-flow:column nowrap;padding:24px;grid-area:list}.Drafts .no-results__wrapper>svg{margin-bottom:20px}@media screen and (max-width: 768px){.Drafts{grid-template-rows:0 1fr}.Drafts>.Header{display:none}.Drafts .Header{border-top:var(--border)}}

/*# sourceMappingURL=6114.7ad285f8d8a58332f6ad.css.map*/