@keyframes emphasis-sidebar-resize-line {
  50% {
    transform: scaleX(1.5);
  }
  100% {
    transform: scaleX(1);
  }
}
@keyframes shake-horizontally {
  10%, 90% {
    transform: translate3d(-1px, 0, 0);
  }
  20%, 80% {
    transform: translate3d(2px, 0, 0);
  }
  30%, 50%, 70% {
    transform: translate3d(-4px, 0, 0);
  }
  40%, 60% {
    transform: translate3d(4px, 0, 0);
  }
}
.console__body .modal .GenericModal.modal-dialog,
.app__body .modal .GenericModal.modal-dialog {
  margin-top: calc(50vh - 240px);
}
.console__body .modal .GenericModal.modal-overflow .modal-body,
.app__body .modal .GenericModal.modal-overflow .modal-body {
  overflow: visible;
}
.console__body .modal .GenericModal .modal-body,
.app__body .modal .GenericModal .modal-body {
  max-height: 100%;
  padding: 0;
}
.console__body .modal .GenericModal .modal-body.divider,
.app__body .modal .GenericModal .modal-body.divider {
  border-top: 1px solid rgba(var(--center-channel-color-rgb), 0.08);
}
.console__body .modal .GenericModal .modal-body .form-control,
.app__body .modal .GenericModal .modal-body .form-control {
  height: 40px;
  box-sizing: border-box;
  border: 1px solid rgba(var(--center-channel-color-rgb), 0.16);
  border-radius: 4px;
}
.console__body .modal .GenericModal .modal-body .form-control:focus,
.app__body .modal .GenericModal .modal-body .form-control:focus {
  border-color: var(--button-bg);
}
.console__body .modal .GenericModal .modal-body .form-control.has-error,
.app__body .modal .GenericModal .modal-body .form-control.has-error {
  border-color: var(--error-text);
}
.console__body .modal .GenericModal .modal-body .MaxLengthInput.form-control.has-error,
.app__body .modal .GenericModal .modal-body .MaxLengthInput.form-control.has-error {
  padding-right: 66px;
}
.console__body .modal .GenericModal .modal-body .MaxLengthInput__validation,
.app__body .modal .GenericModal .modal-body .MaxLengthInput__validation {
  position: absolute;
  top: 12px;
  right: 56px;
  color: var(--error-text);
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 16px;
}
.console__body .modal .GenericModal .modal-body .input-wrapper,
.app__body .modal .GenericModal .modal-body .input-wrapper {
  position: relative;
}
.console__body .modal .GenericModal .modal-body .input-clear,
.app__body .modal .GenericModal .modal-body .input-clear {
  top: 12px;
  right: 12px;
  width: 16px;
  height: 16px;
  color: var(--center-channel-color);
  font-size: 18px;
  font-style: normal;
  font-weight: normal;
  line-height: 16px;
  opacity: 0.48;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .modal-body .GenericModal__body,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .modal-body .GenericModal__body {
  padding: 0;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .modal-body .GenericModal__body.padding,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .modal-body .GenericModal__body.padding {
  padding: 8px 32px 0;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError {
  display: flex;
  box-sizing: border-box;
  flex: 1;
  padding: 14px;
  border: 1px solid rgba(var(--dnd-indicator-rgb), 0.16);
  margin-bottom: 24px;
  background: rgba(var(--dnd-indicator-rgb), 0.08);
  border-radius: 4px;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError span,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError span {
  color: var(--center-channel-color);
  font-size: 14px;
  font-weight: 600;
  line-height: 24px;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError i,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError i {
  margin-right: 8px;
  color: var(--error-text);
  font-size: 24px;
  line-height: 24px;
}
.console__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError i::before,
.app__body .modal .GenericModal.GenericModal__compassDesign .modal-content .genericModalError i::before {
  margin: 0;
}
@media screen and (max-width: 640px) {
  .console__body .modal .GenericModal.GenericModal__compassDesign,
  .app__body .modal .GenericModal.GenericModal__compassDesign {
    margin: 0;
  }
  .console__body .modal .GenericModal.GenericModal__compassDesign .modal-header,
  .app__body .modal .GenericModal.GenericModal__compassDesign .modal-header {
    box-shadow: var(--elevation-2);
  }
}
.console__body .modal .GenericModal__wrapper-enter-key-press-catcher,
.app__body .modal .GenericModal__wrapper-enter-key-press-catcher {
  width: 100%;
  height: 100%;
}

@keyframes emphasis-sidebar-resize-line {
  50% {
    transform: scaleX(1.5);
  }
  100% {
    transform: scaleX(1);
  }
}
@keyframes shake-horizontally {
  10%, 90% {
    transform: translate3d(-1px, 0, 0);
  }
  20%, 80% {
    transform: translate3d(2px, 0, 0);
  }
  30%, 50%, 70% {
    transform: translate3d(-4px, 0, 0);
  }
  40%, 60% {
    transform: translate3d(4px, 0, 0);
  }
}
.footer-pagination {
  display: flex;
  flex: 1;
  flex-direction: row;
  align-items: center;
}
.footer-pagination__legend {
  display: flex;
  flex: 1;
  align-items: center;
  justify-content: flex-start;
  color: rgba(var(--center-channel-color-rgb), 0.64);
  font-size: 12px;
  font-weight: 600;
  line-height: 16px;
}
.footer-pagination__button-container {
  display: flex;
  align-items: center;
  justify-content: center;
}
.footer-pagination__button-container__button {
  display: inline-flex;
  align-items: center;
  border: 0;
  background: rgba(var(--button-bg-rgb), 0.08);
  border-radius: 4px;
  color: var(--button-bg);
  font-weight: 600;
  transition: all 0.15s ease-out;
  height: 32px;
  padding: 0 16px;
  font-size: 12px;
  line-height: 10px;
}
.footer-pagination__button-container__button:disabled {
  background: rgba(var(--center-channel-color-rgb), 0.08);
  color: rgba(var(--center-channel-color-rgb), 0.32);
}
.footer-pagination__button-container__button:hover:enabled {
  background: rgba(var(--button-bg-rgb), 0.12);
}
.footer-pagination__button-container__button:active:enabled {
  background: rgba(var(--button-bg-rgb), 0.16);
}
.footer-pagination__button-container__button i {
  display: flex;
  font-size: 18px;
}
.footer-pagination__button-container__button i:first-child::before {
  margin: 0 7px 0 0;
}
.footer-pagination__button-container__button i:last-child::before {
  margin: 0 0 0 7px;
}
.footer-pagination__button-container__button:not(:first-child) {
  margin-left: 8px;
}
.footer-pagination__button-container__button > :not(:first-child) {
  margin-left: 5px;
}

.tour-tip {
  display: flex;
}
.tour-tip__box.tippy-box {
  padding: 18px 24px 24px;
  border: 1px solid rgba(var(--center-channel-color-rgb), 0.16);
  background: var(--center-channel-bg);
  border-radius: 4px;
  color: var(--center-channel-color-rgb);
  filter: drop-shadow(0 12px 32px rgba(0, 0, 0, 0.12));
}
.tour-tip__box.tippy-box .tippy-content {
  padding: 0;
}
.tour-tip__box.tippy-box .tippy-arrow {
  width: 12px;
  height: 12px;
  border-color: rgba(var(--center-channel-color-rgb), 0.16);
  color: var(--center-channel-bg);
}
.tour-tip__box.tippy-box .tippy-arrow::before {
  width: 12px;
  height: 12px;
  border-color: rgba(var(--center-channel-color-rgb), 0.16);
  background: var(--center-channel-bg);
  color: var(--center-channel-bg);
  transform-origin: center;
}
.tour-tip__box.tippy-box[data-placement^=right] > .tippy-arrow {
  transform: translate3d(0, 14px, 0) !important;
}
.tour-tip__box.tippy-box[data-placement^=top] > .tippy-arrow {
  transform: translate3d(14px, 0, 0) !important;
}
.tour-tip__box.tippy-box[data-placement^=bottom] > .tippy-arrow {
  transform: translate3d(14px, 0, 0) !important;
}
.tour-tip__box.tippy-box[data-placement=bottom-end] > .tippy-arrow {
  transform: translate3d(317px, 0, 0) !important;
}
.tour-tip__pulsating-dot-ctr {
  position: absolute;
  z-index: 3;
  width: 14px;
  height: 14px;
  cursor: pointer;
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=top] {
  top: 0;
  left: calc(50% - 6px);
  transform: translate(0, 6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=top-start] {
  top: 0;
  left: 0;
  transform: translate(6px, 6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=top-end] {
  top: 0;
  right: 0;
  transform: translate(-6px, 6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=bottom] {
  bottom: 0;
  left: calc(50% - 6px);
  transform: translate(0, -6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=bottom-start] {
  bottom: 0;
  left: 0;
  transform: translate(6px, -6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=bottom-end] {
  right: 0;
  bottom: 0;
  transform: translate(-6px, -6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=left] {
  top: calc(50% - 6px);
  left: 0;
  transform: translate(6px, 0);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=left-start] {
  top: 0;
  left: 0;
  transform: translate(6px, 6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=left-end] {
  bottom: 0;
  left: 0;
  transform: translate(6px, -6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=right] {
  top: calc(50% - 6px);
  right: 0;
  transform: translate(-6px, 0);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=right-start] {
  top: 0;
  right: 0;
  transform: translate(-6px, 6px);
}
.tour-tip__pulsating-dot-ctr[data-pulsating-dot-placement=right-end] {
  right: 0;
  bottom: 0;
  transform: translate(-6px, -6px);
}
.tour-tip__overlay {
  position: fixed;
  z-index: 999;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}
.tour-tip__header {
  display: flex;
  align-items: center;
  justify-content: flex-start;
}
.tour-tip__header__title {
  flex: none;
  flex-grow: 1;
  order: 0;
  margin: 0;
  font-family: inherit;
  font-size: 1.4rem;
  font-style: normal;
  font-weight: 600;
  line-height: 2rem;
}
.tour-tip__header__close {
  display: flex;
  overflow: hidden;
  width: 3.2rem;
  height: 3.2rem;
  align-items: center;
  justify-content: center;
  border: unset;
  margin-right: -8px;
  margin-left: 1.2rem;
  background: transparent;
  border-radius: 4px;
  color: rgba(var(--center-channel-color-rgb), 0.56);
  font-weight: 600;
}
.tour-tip__header__close:hover {
  background: rgba(var(--center-channel-color-rgb), 0.08);
}
.tour-tip__header__close.active {
  background: rgba(var(--center-channel-color-rgb), 0.08);
}
.tour-tip__header__close i {
  font-size: 1.8rem;
  line-height: 1.8rem;
}
.tour-tip__header__close i ::before {
  margin-right: 0;
}
.tour-tip__body {
  display: flex;
  flex-direction: column;
  margin-top: 0.6rem;
}
.tour-tip__body p,
.tour-tip__body div {
  margin: 0 0 0.8rem;
  font-size: 1.4rem;
  line-height: 2rem;
}
.tour-tip__body p:last-child,
.tour-tip__body div:last-child {
  margin-bottom: 0;
}
.tour-tip__body:last-child {
  margin-bottom: 0;
}
.tour-tip__image {
  display: flex;
  align-items: center;
  justify-content: center;
  margin-top: 2.4rem;
}
.tour-tip__image img {
  width: 100%;
  height: 136px;
  border-radius: 4px;
  object-fit: cover;
}
.tour-tip__btn-ctr {
  display: flex;
  flex-grow: 1;
  justify-content: flex-end;
}
.tour-tip__btn {
  display: flex;
  height: 3.2rem;
  align-items: center;
  padding: 10px 16px;
  border: none;
  border-radius: 4px;
  font-size: 12px;
  font-weight: 600;
  line-height: 12px;
}
.tour-tip__confirm-btn {
  background: var(--button-bg);
  color: var(--button-color);
}
.tour-tip__confirm-btn:hover:not(.disabled) {
  background: linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)), var(--button-bg);
}
.tour-tip__confirm-btn:active {
  background: linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.32), rgba(var(--center-channel-color-rgb), 0.32)), var(--button-bg);
}
.tour-tip__confirm-btn:focus {
  box-shadow: inset 0 0 0 2px var(--sidebar-text-active-border);
}
.tour-tip__confirm-btn .icon-chevron-right::before {
  margin-right: -7px;
}
.tour-tip__cancel-btn {
  margin-right: 4px;
  background: rgba(var(--button-bg-rgb), 0.08);
  border-radius: 4px;
  color: var(--button-bg);
  text-decoration: none;
}
.tour-tip__cancel-btn:hover {
  background: rgba(var(--button-bg-rgb), 0.04);
}
.tour-tip__cancel-btn:active {
  background: rgba(var(--button-bg-rgb), 0.08);
}
.tour-tip__cancel-btn:focus {
  box-shadow: inset 0 0 0 2px var(--sidebar-text-active-border);
}
.tour-tip__cancel-btn .icon-chevron-left::before {
  margin-left: -7px;
}
.tour-tip__dot-ctr {
  display: flex;
  align-items: center;
  justify-content: flex-start;
}
.tour-tip__dot-ring {
  position: relative;
  display: flex;
  width: 12px;
  height: 12px;
  align-items: center;
  justify-content: center;
  margin-right: 4px;
  background: transparent;
  border-radius: 50%;
}
.tour-tip__dot-ring:last-child {
  margin-right: 0;
}
.tour-tip__dot-ring-active {
  background: rgba(var(--button-bg-rgb), 0.16);
}
.tour-tip__dot {
  position: absolute;
  top: 3px;
  left: 3px;
  width: 6px;
  height: 6px;
  background: rgba(var(--button-bg-rgb), 0.32);
  border-radius: 6px;
}
.tour-tip__dot.active {
  background: rgba(var(--button-bg-rgb), 1);
}
.tour-tip__footer {
  display: flex;
  flex-direction: column;
  margin-top: 2.4rem;
}
.tour-tip__footer-buttons {
  display: flex;
  align-items: center;
  justify-content: start;
}
.tour-tip__opt {
  align-self: flex-end;
  margin-top: 1.2rem;
  font-size: 12px;
}
.tour-tip__opt span {
  opacity: 0.9;
}
.tour-tip__backdrop {
  position: absolute;
  z-index: 100;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.5);
}
.tour-tip__backdrop--transparent {
  background: none !important;
}

.tippy-box[data-placement^=right] > .tippy-arrow::before {
  top: -1px !important;
  border-width: 1px 0 0 1px !important;
  transform: rotate(-45deg) !important;
}

.tippy-box[data-placement^=left] > .tippy-arrow::before {
  top: -1px !important;
  border-width: 1px 1px 0 0 !important;
  transform: rotate(45deg) !important;
}

.tippy-box[data-placement^=bottom] > .tippy-arrow::before {
  left: 1px !important;
  border-width: 1px 0 0 1px !important;
  transform: rotate(45deg) !important;
}

.tippy-box[data-placement^=top] > .tippy-arrow::before {
  left: 1px !important;
  border-width: 0 0 1px 1px !important;
  transform: rotate(-45deg) !important;
}

.tippy-blue-style {
  background: var(--button-bg) !important;
  color: var(--sidebar-text) !important;
}
.tippy-blue-style .tippy-arrow {
  border-color: var(--button-bg) !important;
  color: var(--button-bg) !important;
}
.tippy-blue-style .tippy-arrow::before {
  border-width: 0 !important;
  border-color: var(--button-bg) !important;
  border-left-color: initial;
  background-color: var(--button-bg) !important;
  transform-origin: unset !important;
}
.tippy-blue-style .tour-tip__header {
  font-weight: 600;
}
.tippy-blue-style .icon-close {
  color: var(--sidebar-text) !important;
}
.tippy-blue-style .tour-tip__btn {
  background: var(--button-color);
  color: var(--button-bg);
}
.tippy-blue-style .tour-tip__btn:hover, .tippy-blue-style .tour-tip__btn:active, .tippy-blue-style .tour-tip__btn:focus {
  background: var(--button-color);
  color: var(--button-bg);
}
.tippy-blue-style .tour-tip__dot-ring .tour-tip__dot {
  background: var(--offline-indicator);
}
.tippy-blue-style .tour-tip__dot-ring-active .active {
  background: var(--button-color);
}

.pulsating_dot {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}
.pulsating_dot-clickable {
  cursor: pointer;
}
.pulsating_dot, .pulsating_dot::before, .pulsating_dot::after {
  width: 12px;
  height: 12px;
  background-color: var(--online-indicator);
  border-radius: 50%;
}
.pulsating_dot::before, .pulsating_dot::after {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  content: "";
}
.pulsating_dot::after {
  animation: pulse1 2s ease 0s infinite;
}
.pulsating_dot::before {
  animation: pulse2 2s ease 0s infinite;
}

/*# sourceMappingURL=1011.b1f74ced71fa30073208.css.map*/