.SelectTeam__sub-header{display:flex;align-items:center;justify-content:space-between;margin-top:10px;margin-bottom:24px}.SelectTeam__sub-header>h4{margin:0}.SelectTeam__sub-header>h4 span{display:inline-flex;font-size:20px;font-weight:600;line-height:28px}

/*# sourceMappingURL=3389.bd6e91718bcb0e460cda.css.map*/