.modal .on-boarding-video_modal{width:100%;max-width:899px;height:unset;margin-top:calc(50vh - 252px);box-shadow:var(--elevation-6)}.on-boarding-video_modal .wistia_embed{width:100%;max-width:899px;height:100%;max-height:506px}.on-boarding-video_modal .modal-header{min-height:0;padding:0;border:none}.on-boarding-video_modal .modal-header .close{top:-12px;right:-12px;border-radius:16px;opacity:.8}.on-boarding-video_modal .modal-header .close :hover{opacity:1}.app__body .modal .on-boarding-video_modal .modal-header .close{background:var(--center-channel-bg);color:var(--center-channel-color)}.on-boarding-video_modal .modal-content{height:100vh;max-height:506px;padding:0;border:none;border-radius:8px}.on-boarding-video_modal .modal-body{overflow:hidden;height:100%;padding:0;margin:0;border-radius:8px}.on-boarding-video_modal .modal-footer{display:none}

/*# sourceMappingURL=6106.ef104656b8bd072b2c15.css.map*/