"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[7882],{27882:(e,t,o)=>{o.r(t),o.d(t,{default:()=>n});var r=o(84390),a=o.n(r),l=o(72060),s=o(70314),c=o(19601),f=o(35683);const n=()=>{const{formatMessage:e}=(0,l.useIntl)(),{AboutLink:t,PrivacyPolicyLink:o,TermsOfServiceLink:r,HelpLink:n}=(0,s.useSelector)(c.iE);return a().createElement("div",{className:"hfroute-footer"},a().createElement("span",{key:"footer-copyright",className:"footer-copyright"},"© ".concat((new Date).getFullYear()," Mattermost Inc.")),t&&a().createElement(f.Z,{key:"footer-link-about",className:"footer-link",href:t,location:"footer"},e({id:"web.footer.about",defaultMessage:"About"})),o&&a().createElement(f.Z,{key:"footer-link-privacy",className:"footer-link",href:o,location:"footer"},e({id:"web.footer.privacy",defaultMessage:"Privacy Policy"})),r&&a().createElement(f.Z,{key:"footer-link-terms",className:"footer-link",href:r,location:"footer"},e({id:"web.footer.terms",defaultMessage:"Terms"})),n&&a().createElement(f.Z,{key:"footer-link-help",className:"footer-link",href:n,location:"footer"},e({id:"web.footer.help",defaultMessage:"Help"})))}}}]);
//# sourceMappingURL=7882.4836784ab734854bade8.js.map