.Avatar{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:sub}.Avatar,.Avatar:focus,.Avatar.a11y--focused{border-radius:50%}.Avatar.Avatar-xxs{width:16px;min-width:16px;height:16px;font-size:8px}.Avatar.Avatar-xs{width:20px;min-width:20px;height:20px;font-size:9.5px}.Avatar.Avatar-sm{width:24px;min-width:24px;height:24px;font-size:10px}.Avatar.Avatar-md{width:32px;min-width:32px;height:32px;font-size:12px}.Avatar.Avatar-lg{width:36px;min-width:36px;height:36px;font-size:14px}.Avatar.Avatar-xl{width:50px;min-width:50px;height:50px;font-size:18px}.Avatar.Avatar-xxl{width:128px;min-width:128px;height:128px;font-size:44px}.Avatar.Avatar-plain{position:relative;display:inline-flex;align-items:center;justify-content:center;background:#fff}.Avatar.Avatar-plain::before{position:absolute;display:inline-flex;width:100%;height:100%;align-items:center;justify-content:center;border-radius:50%;color:rgba(var(--center-channel-color-rgb), 0.64);content:attr(data-content)}
.FullScreenModal{position:fixed;z-index:1030 !important;top:0;left:0;overflow:auto;width:100%;height:100%;background:var(--center-channel-bg)}.FullScreenModal .close-x,.FullScreenModal .back{position:fixed;z-index:9;top:48px;width:40px;height:40px;padding:0;border:0;background:none;cursor:pointer}.FullScreenModal .close-x svg,.FullScreenModal .back svg{width:40px;height:40px;padding:4px;border-radius:4px;fill:rgba(var(--center-channel-color-rgb), 0.56)}.FullScreenModal .close-x svg:hover,.FullScreenModal .back svg:hover{background:rgba(var(--center-channel-color-rgb), 0.08);fill:rgba(var(--center-channel-color-rgb), 0.72)}.FullScreenModal .close-x svg:active,.FullScreenModal .back svg:active{background:rgba(var(--button-bg-rgb), 0.08);fill:var(--button-bg)}.FullScreenModal .close-x{right:48px}.FullScreenModal .back{left:48px}.FullScreenModal-enter,.FullScreenModal-appear{opacity:0}.FullScreenModal-enter-active,.FullScreenModal-appear-active{opacity:1;transition:opacity 100ms}.FullScreenModal-exit{opacity:1}.FullScreenModal-exit-active{opacity:0;transition:opacity 100ms}.FullScreenModal.FullScreenModal--compact .back{top:8px;left:16px}.FullScreenModal.FullScreenModal--compact .close-x{top:8px;right:16px}.FullScreenModal.FullScreenModal--compact .close-x,.FullScreenModal.FullScreenModal--compact .back{position:absolute}
.MenuGroup.menu-divider{height:1px;margin:8px 0;background:rgba(var(--center-channel-color-rgb), 0.08)}
.Menu .MenuHeader{display:flex;overflow:hidden;width:100%;height:32px;align-items:center;padding:0 32px 0 20px;clear:both;color:inherit;cursor:default;font-weight:600;text-align:left;text-overflow:ellipsis;white-space:nowrap}
.container-slider{position:relative;overflow:hidden;width:100%;min-width:400px;height:100%;min-height:450px}@media screen and (max-width: 700px){.container-slider .container-slider{margin:10px}}.container-slider .slide{position:absolute;z-index:0;width:100%;height:100%;opacity:0;transition:opacity ease-in-out .4s}.container-slider .slide img{width:100%;height:100%;object-fit:cover}.container-slider .active-anim{z-index:1;opacity:1}.container-slider .chevron-button{z-index:2;margin-top:120px;color:var(--center-channel-color);cursor:pointer;font-size:24px}.container-slider .chevron-button.disabled{opacity:.5}.container-slider .chevron-button.chevron-right{position:absolute;right:0}.container-slider .chevron-button.chevron-left{position:absolute;left:0}.container-slider .container-footer{position:absolute;z-index:2;bottom:0;display:flex;width:100%;align-items:center;justify-content:flex-start;padding:24px 0}.container-slider .container-footer .container-buttons{margin-left:auto}.container-slider .container-footer .container-buttons .btn-slide{position:absolute;display:flex;width:60px;height:20px;align-items:center;justify-content:center;border:1px solid rgba(34,34,34,.287);cursor:pointer;font-size:12px;font-weight:600}.container-slider .container-footer .container-buttons .disabled{opacity:.5;text-decoration:none}.container-slider .container-footer .container-buttons .prev,.container-slider .container-footer .container-buttons .next{left:20px;transform:translateY(-60%)}.container-slider .container-footer .container-dots{display:flex}.container-slider .container-footer .container-dots .dot{width:8px;height:8px;margin:0 5px;background:rgba(var(--button-bg-rgb), 0.25);border-radius:50%}.container-slider .container-footer .container-dots .dot.active{width:6px;height:6px;margin-top:1px;background:var(--button-bg);box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.4)}
.TrialBenefitsModalStepMore.learn-more-button{display:block;width:fit-content;padding:13px 20px;border:none;margin-top:16px;background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModalStepMore.learn-more-button:hover:not(.disabled){background:rgba(var(--sys-button-bg-rgb), 0.04);text-decoration:none}.TrialBenefitsModalStepMore.learn-more-button:active{background:rgba(var(--sys-button-bg-rgb), 0.08);text-decoration:none}.TrialBenefitsModalStepMore.learn-more-button:focus{box-shadow:inset 0 0 0 2px var(--sys-button-bg);text-decoration:none}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.TrialBenefitsModalStep.slide-container{padding:0 24px}.TrialBenefitsModalStep.slide-container .svg-wrapper{display:flex;min-height:200px;flex:1;align-items:center;justify-content:center;margin-top:10px}.TrialBenefitsModalStep.slide-container .title{width:100%;margin:0 auto;margin-top:10px 0;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.TrialBenefitsModalStep.slide-container .description{width:100%;margin:0 auto;margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.TrialBenefitsModalStep.slide-container .bottom-text-left-message{position:fixed;bottom:24px;left:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.TrialBenefitsModalStep.slide-container.trial-just-started .title{text-align:center}.TrialBenefitsModalStep.slide-container.trial-just-started .description{font-size:12px}.TrialBenefitsModalStep.slide-container.trial-just-started .svg-wrapper{min-height:180px;margin-top:0}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper{display:flex;justify-content:flex-end;margin-top:10px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px;height:32px;font-size:12px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i{display:flex;font-size:18px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i:first-child::before{margin:0 7px 0 0}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i:last-child::before{margin:0 0 0 7px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:32px;padding:0 16px;font-size:12px;line-height:10px;margin-left:8px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button i{display:flex;font-size:18px}
.TrialBenefitsModal.modal-dialog{margin-top:calc(50vh - 240px)}.TrialBenefitsModal .modal-content{min-height:440px;padding:0 !important;border-color:rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);border-radius:8px;color:var(--center-channel-color)}.TrialBenefitsModal .modal-header{height:48px;min-height:48px;padding:0;border:0;background:var(--center-channel-bg) !important;border-radius:8px;color:var(--center-channel-color)}.TrialBenefitsModal .modal-header .close{top:6px;right:4px;width:4rem;height:4rem;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.TrialBenefitsModal .modal-header .close:hover,.TrialBenefitsModal .modal-header .close:active,.TrialBenefitsModal .modal-header .close:focus,.TrialBenefitsModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.TrialBenefitsModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-bottom:24px !important}.TrialBenefitsModal .modal-body .buttons{text-align:center}.TrialBenefitsModal .modal-body .buttons .previous-btn{height:30px;align-items:center;align-self:center;padding:8px 16px;border:none;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModal .modal-body .buttons .previous-btn:hover,.TrialBenefitsModal .modal-body .buttons .previous-btn:active,.TrialBenefitsModal .modal-body .buttons .previous-btn:focus,.TrialBenefitsModal .modal-body .buttons .previous-btn:active:focus{border:none;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px}.TrialBenefitsModal .modal-body .buttons .next-btn{height:30px;flex:none;padding:8px 16px;border:none;margin-left:8px;background:var(--button-bg);border-radius:4px;color:var(--sys-button-color);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModal .modal-body .buttons .next-btn:hover,.TrialBenefitsModal .modal-body .buttons .next-btn:active,.TrialBenefitsModal .modal-body .buttons .next-btn:focus,.TrialBenefitsModal .modal-body .buttons .next-btn:active:focus{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.TrialBenefitsModal .modal-centered{text-align:center}.TrialBenefitsModal .modal-footer{padding:12px 24px 24px;border:none;border-radius:4px}
.error,.Input_container .Input___error{color:var(--error-text)}.info{color:var(--sidebar-text-active-border)}.warning,.Input_container .Input___warning{color:var(--away-indicator-dark)}.success,.Input_container .Input___success{color:var(--online-indicator)}.Input_container{width:100%}.Input_container .Input{position:relative;z-index:2;left:0;width:100%;padding:0;border:0;border-radius:4px;box-shadow:none;color:var(--center-channel-color);font-size:14px;line-height:20px;outline:0}.Input_container .Input::placeholder{color:rgba(var(--center-channel-color-rgb), 0.64)}.Input_container .Input.Input__focus{box-shadow:none}.Input_container .Input.large{height:42px;font-size:16px;line-height:24px}.Input_container .Input_wrapper{display:flex;flex:1;align-items:center;padding:0 16px;margin:2px 0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:14px;line-height:20px}.Input_container .Input_wrapper>:not(:first-child){margin-left:8px}.Input_container .Input_limit-exceeded{align-self:center;margin-left:16px;color:var(--error-text);font-size:14px;line-height:20px}.Input_container .Input-border-error{border-color:var(--error-text)}.Input_container .Input___error,.Input_container .Input___customMessage,.Input_container .Input___info{margin-top:5px;font-size:12px;line-height:16px;text-align:left}.Input_container .Input___error i,.Input_container .Input___customMessage i,.Input_container .Input___info i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.Input_container .Input___error i::before,.Input_container .Input___customMessage i::before,.Input_container .Input___info i::before{margin:0}.Input_container .Input___error{display:flex}.Input_container .Input___warning{display:flex}.Input_container .Input___success{display:flex}.Input_container .Input___info{color:rgba(var(--center-channel-color-rgb), 0.56)}.Input_container .Input___info>span.valid{margin-left:7px}.Input_container .Input_fieldset{position:relative;z-index:3;display:flex;width:100%;box-sizing:border-box;padding:0 1px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;color:rgba(var(--secondary-blue-rgb), 0.4)}.Input_container .Input_fieldset:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.Input_container .Input_fieldset:focus-within{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg);color:var(--button-bg)}.Input_container .Input_fieldset:focus-within .Input_legend{color:var(--button-bg)}.Input_container .Input_fieldset___error{border-color:var(--error-text);color:var(--error-text)}.Input_container .Input_fieldset___error:focus-within{border-color:var(--error-text);box-shadow:inset 0 0 0 1px var(--error-text);color:var(--error-text)}.Input_container .Input_fieldset___error:focus-within .Input_legend{color:var(--error-text)}.Input_container .Input_fieldset___error:hover{border-color:var(--error-text)}.Input_container .Input_fieldset___error .Input_legend{color:var(--error-text)}.Input_container .Input_legend{position:absolute;z-index:4;top:-8px;display:flex;width:auto;padding:0 4px;border:none;margin-left:12px;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:10px;line-height:14px;opacity:0;transform:translateY(8px);transition-duration:.15s;transition-property:opacity,transform;transition-timing-function:ease-in-out;white-space:nowrap}.Input_container .Input_legend___focus{padding:0 4px;opacity:1;transform:translateY(0)}.Input_container.disabled .Input_fieldset{border-color:rgba(var(--center-channel-color-rgb), 0.16);background-color:rgba(var(--center-channel-color-rgb), 0.04)}.Input_container .Input__clear{display:flex;color:rgba(var(--center-channel-color), 0.68);cursor:pointer}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.RequestBusinessEmailModal{height:320px}.RequestBusinessEmailModal.modal-dialog{margin-top:calc(50vh - 350px) !important}.RequestBusinessEmailModal .modal-content{padding:0 !important;border-color:rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);border-radius:8px;color:var(--center-channel-color)}.RequestBusinessEmailModal .modal-header{height:38px;padding:0;border:0;background:var(--center-channel-bg) !important;border-radius:8px;color:var(--center-channel-color)}.RequestBusinessEmailModal .modal-header .close{top:6px;right:4px;width:4rem;height:4rem;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.RequestBusinessEmailModal .modal-header .close:hover,.RequestBusinessEmailModal .modal-header .close:active,.RequestBusinessEmailModal .modal-header .close:focus,.RequestBusinessEmailModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.RequestBusinessEmailModal .modal-body{display:flex;overflow:hidden;width:100%;height:calc(100% - 38px);flex-direction:column;padding:0}.RequestBusinessEmailModal .modal-body .GenericModal__body{height:100%;padding:0 24px 24px 24px}.RequestBusinessEmailModal .modal-body .GenericModal__body .container-footer{bottom:0;height:36px}.RequestBusinessEmailModal .modal-body .request-business-email-input{height:34px !important;border:0 !important;border-radius:0 !important}.RequestBusinessEmailModal .modal-body .start-trial-email-title{margin-bottom:22px;color:var(--center-channel-color);font-size:22px;font-weight:600;line-height:28px}.RequestBusinessEmailModal .modal-body .start-trial-email-description{margin-bottom:16px;color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.RequestBusinessEmailModal .modal-body .start-trial-email-disclaimer{margin-top:56px}.RequestBusinessEmailModal .modal-body .start-trial-button{display:flex}.RequestBusinessEmailModal .modal-body .start-trial-button button{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;margin-left:auto}.RequestBusinessEmailModal .modal-body .start-trial-button button:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.RequestBusinessEmailModal .modal-body .start-trial-button button:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.RequestBusinessEmailModal .modal-body .start-trial-button button:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.RequestBusinessEmailModal .modal-body .start-trial-button button:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.RequestBusinessEmailModal .modal-body .start-trial-button button i{display:flex;font-size:18px}.RequestBusinessEmailModal .modal-centered{text-align:center}.RequestBusinessEmailModal .modal-footer{padding:12px 24px 24px;border:none;border-radius:4px}
.CloudStartTrialButton:not(.style-link){width:fit-content;padding:13px 20px;border:none;font-size:14px;font-weight:600;line-height:14px}.CloudStartTrialButton.style-link{padding-left:0}
.IconMessage .content{display:flex;flex-direction:column;align-content:center;justify-content:center;text-align:center}.IconMessage .content.success{padding-bottom:2px;padding-left:7px}.IconMessage .content.success>.IconMessage__svg-wrapper{margin-left:68px}.IconMessage .content .IconMessage-h3{margin-top:43px;color:var(--center-channel-color);font-size:24px;font-weight:600;line-height:32px}@media screen and (max-width: 600px){.IconMessage .content .IconMessage-h3{font-size:36px;letter-spacing:-0.13px;line-height:42px}}.IconMessage .content .IconMessage-sub{max-width:560px;align-self:center;margin-top:16px;color:var(--center-channel-color);font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.IconMessage .content .IconMessage-sub.error{color:#db3214}.IconMessage .content .IconMessage-buttons{display:flex;height:40px;justify-content:center;margin-top:16px;font-size:14px;font-weight:600;gap:16px;line-height:14px;text-align:center}.IconMessage .content .IconMessage-progress{width:387px;height:4px;margin:0 auto;margin-top:90px;background:rgba(34,64,109,.12);border-radius:4px}.IconMessage .content .IconMessage-progress-fill{height:100%;background:#0058cc;border-radius:4px}.IconMessage .content .IconMessage-button button{background:var(--button-bg);border-radius:4px;color:var(--button-color)}.IconMessage .content .IconMessage-tertiary-button button{background:rgba(var(--denim-button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg)}.IconMessage .content .IconMessage-link{margin-top:21px;margin-left:-10px;color:#0058cc;font-size:14px;font-weight:600;line-height:14px;text-align:center}.IconMessage__svg-wrapper{align-self:center}@media screen and (max-width: 600px){.IconMessage__svg-wrapper svg{width:150%}}
.cloud_subscribe_result_modal .IconMessage{top:50%;transform:translateY(50%)}
.PaymentForm{padding-right:96px;padding-left:96px;margin:0 auto}.PaymentForm .form-row{display:flex;width:100%;margin-bottom:24px;font-weight:normal}.PaymentForm .form-row-third-1{width:66%;max-width:288px;margin-right:16px;font-weight:normal}.PaymentForm .form-row-third-1 .DropdownInput{margin-top:0}.PaymentForm .form-row-third-2{width:34%;max-width:144px}.PaymentForm .section-title{margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;font-weight:600;text-align:left}.PaymentForm .DropdownInput{position:relative;height:36px;margin-bottom:24px;font-weight:normal}.PaymentForm .DropdownInput .DropDown__control{min-height:0;background-color:var(--center-channel-bg) !important}.PaymentForm .DropdownInput .DropDown__menu{background-color:var(--center-channel-bg) !important;box-shadow:0 0 0 1px var(--center-channel-color),0 4px 11px var(--center-channel-color) !important}.PaymentForm .full-width{width:100%}.PaymentForm input{font-size:14px}.PaymentForm input:-webkit-autofill,.PaymentForm input:-webkit-autofill:hover,.PaymentForm input:-webkit-autofill:focus,.PaymentForm input:-webkit-autofill:active{-webkit-box-shadow:0 0 0 30px var(--center-channel-bg) inset !important;-webkit-text-fill-color:var(--center-channel-color) !important}.PaymentForm .Input_fieldset{height:40px;padding:2px 1px;background:var(--center-channel-bg)}.PaymentForm .Input_fieldset .Input_wrapper{margin:0}.PaymentForm .Input_fieldset.Input_fieldset___legend>legend{margin-left:11px}.PaymentForm .Input_fieldset.Input_fieldset:focus-within{padding-top:2px;box-shadow:inset 0 0 0 2px var(--button-bg);color:var(--button-bg)}.PaymentForm .Input_fieldset.Input_fieldset___error{padding-top:1px;padding-bottom:1px;box-shadow:inset 0 0 0 1px var(--error-text);color:var(--error-text)}.PaymentForm .Input_fieldset.Input_fieldset___error:focus-within{box-shadow:inset 0 0 0 2px var(--error-text);color:var(--error-text)}.PaymentForm .Input_fieldset .Input{height:32px;background:inherit}.PaymentForm .Input_fieldset .Input::placeholder{color:var(--center-channel-color);opacity:.64}.PaymentForm .PaymentForm-saved{width:442px;height:fit-content;box-sizing:border-box;padding:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-bottom:16px;background:#fff;border-radius:4px}.PaymentForm .PaymentForm-saved-title{margin-bottom:16px;color:var(--secondary-blue);font-family:Metropolis;font-size:14px;font-weight:600;letter-spacing:1.5px;line-height:18px;opacity:.4;text-transform:uppercase}.PaymentForm .PaymentForm-saved-card{padding-bottom:16px;border-bottom:1px solid rgba(0,0,0,.12);color:var(--secondary-blue);font-family:Source Sans Pro;font-size:16px;line-height:24px}.PaymentForm .PaymentForm-saved-address{margin-top:16px;margin-bottom:16px;color:var(--secondary-blue);font-family:Source Sans Pro;font-size:16px;line-height:24px}.PaymentForm .PaymentForm-change{color:#0058cc;font-family:Source Sans Pro;font-size:16px;font-weight:600;line-height:20px}
#DowngradeModal{padding-top:80px}.background-svg{position:absolute;z-index:-1;top:0;width:100%;height:100%}.ProcessPayment-progress{width:387px;height:4px;margin:0 auto;margin-top:60px;background:rgba(var(--secondary-blue-rgb), 0.12);border-radius:4px}.ProcessPayment-progress-fill{height:100%;background:var(--button-bg);border-radius:4px}
.FeedbackModal__Container .radio-list>.radio{margin-bottom:20px}.FeedbackModal__FreeFormText{width:100%;padding:10px;border-color:rgba(var(--sys-denim-center-channel-text-rgb), 0.16);margin-bottom:15px;border-radius:4px;color:#000;font-size:15px;resize:none}.FeedbackModal__FreeFormTextLimit{color:var(--dnd-indicator);float:right}
.WorkspaceLimitLine{display:flex;align-items:center;padding-bottom:16px;font-weight:600}.WorkspaceLimitLine:last-child{padding-bottom:0}.WorkspaceLimitLine__icon{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:24px}.WorkspaceLimitLine__bar{flex-grow:1;padding-right:24px;padding-left:12px;color:rgba(var(--center-channel-color-rgb), 0.72)}.WorkspaceLimitLine__bar:first-child{padding-left:0}.WorkspaceLimitLine__bar-label{padding-bottom:4px}.WorkspaceLimitLine__text-status{flex-basis:121px;align-self:end;color:var(--center-channel-color);font-size:11px;line-height:11px}
.CloudUsageModal .GenericModal__body{color:var(--center-channel-color)}.CloudUsageModal__description{padding-bottom:24px;margin-bottom:0}.CloudUsageModal .modal-content{background-color:var(--center-channel-bg)}.CloudUsageModal .modal-body{color:var(--center-channel-color)}.CloudUsageModal .modal-body:not(:last-child){padding-bottom:28px !important;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.cloud-usage-backdrop{z-index:1050}
.Content{position:relative;display:flex;flex-direction:column;justify-content:center}.Content.Content--self-hosted .alert-option{padding:40px 0}.pricing-options-container{display:flex;min-height:120px;align-items:center}.pricing-options-container .alert-option-container{flex:1}.pricing-options-container .save-text{flex:1;margin:0;margin-right:12px;color:var(--denim-status-online);font-family:"Metropolis";font-size:14px;font-style:normal;font-weight:600;line-height:18px;text-align:right}
.air-gapped-purchase-modal .content{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:32px;text-align:center}#air-gapped-modal-title span{font-size:22px;font-weight:bold}#air-gapped-modal-content span{padding-right:32px;padding-left:32px}
.ScreeningInProgressModal__content{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:0;text-align:center}.ScreeningInProgressModal__illustration{display:flex;overflow:hidden;width:350px;height:230px;align-items:center;justify-content:center}.ScreeningInProgressModal__title{padding-top:30px;color:var(--center-channel-text)}.ScreeningInProgressModal__title span{font-size:22px;font-weight:bold}.ScreeningInProgressModal__description{padding:8px 0;color:var(--center-channel-text)}.ScreeningInProgressModal__close{margin-right:0}
.PurchaseInProgressModal__body{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:32px;text-align:center}.PurchaseInProgressModal__progress-description{padding-top:20px}
.shipping-address-section{display:flex;align-items:center;padding-bottom:24px;font-weight:normal}.shipping-address-section button.no-style{height:auto;padding-left:0;border:none;background:rgba(0,0,0,0);outline:unset;text-align:left}.shipping-address-section button.no-style:focus{outline:unset}.shipping-address-section #address-same-than-billing-address{width:17px;height:17px;flex-shrink:0}.shipping-address-section .Form-checkbox-label{padding-left:12px;cursor:default;font-family:"Open Sans",sans-serif}.shipping-address-section .billing_address_btn_text{color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-weight:bold}.PurchaseModal .shipping-address-section{padding-right:96px;padding-left:96px}
.StripeElement {
    position: relative;
    width: 100%;
    height: 100%;
    padding-top: 8px;
    padding-bottom: 2px !important;
    padding-left: 12px;
    background-color: var(--center-channel-bg);
    background-image: none;
    border-radius: 4px;
    box-shadow: none;
    color: var(--center-channel-color);
    font-family: 'Open Sans';
    font-size: 14px;
    line-height: 23px;
    outline: none;
}

.StripeElement--invalid {
    color: var(--error-text);
}

.StripeElement::placeholder {
    color: rgba(var(--center-channel-color-rgb), 0.72);
    font-size: 14px;
    opacity: 0.5;
}

.StripeElement:focus::placeholder {
    color: 'transparent';
}

.StripeElement:focus {
    border-color: transparent;
    box-shadow: 0 0 0 2px var(--button-bg);
}

.SeatsCalculator{padding:14px 0;font-size:14px}.SeatsCalculator .Input___customMessage.Input___error{line-height:14px}.SeatsCalculator__seats-item{position:relative;display:flex;align-items:flex-start;justify-content:space-between;padding-bottom:12px;font-weight:400}.SeatsCalculator__seats-item fieldset{max-width:110px}.SeatsCalculator__seats-item--input{padding-bottom:20px}.SeatsCalculator__seats-label{position:relative}.SeatsCalculator__seats-tooltip{position:absolute;top:11px;left:118px}.SeatsCalculator__total{display:flex;align-items:center;justify-content:space-between;padding-bottom:8px;font-weight:600}
.CloudInvoicePreview{top:15px;width:860px;height:1030px;margin:0 auto;border-radius:8px;overflow-y:hidden !important}.CloudInvoicePreview .modal-header{display:block;padding-bottom:0;border:none;background-color:#fff !important;color:#3f4350}.CloudInvoicePreview .modal-header .close{margin-top:auto;margin-bottom:auto;color:rgba(63,67,80,.56) !important}.CloudInvoicePreview .modal-header .modal-title{color:inherit;font-family:"Metropolis";font-size:22px;font-style:normal;font-weight:600}.CloudInvoicePreview .modal-header .subtitle{margin-top:10px;color:rgba(61,60,64,.72);font-family:"Metropolis";font-size:14px;font-style:normal}.CloudInvoicePreview .modal-open{overflow-y:hidden !important}.CloudInvoicePreview .modal{width:100%;max-width:100%;height:100%;margin:0 !important}.CloudInvoicePreview .modal-dialog{width:100%;max-width:100%;height:100%;margin:0 !important}.CloudInvoicePreview .modal-body{padding:0}.CloudInvoicePreview .modal-body .view-image__loading{background-color:#fff;color:#fff}.CloudInvoicePreview .modal-body .view-image__loading .fa{color:#3f4350}.CloudInvoicePreview .post-code{display:flex}.CloudInvoicePreview .post-code canvas{display:block;max-height:100%;padding-right:0;padding-left:0;margin-right:auto;margin-left:auto}
.CloudBillingHistoryModal{top:50%;left:50%;border-radius:8px;overflow-y:hidden !important;-webkit-transform:translate(-50%, -50%);transform:translate(-50%, -50%)}.CloudBillingHistoryModal .modal-content{padding:24px 32px}.CloudBillingHistoryModal .modal-content .modal-header{padding:0;border:none;background:#fff !important;background-color:#fff !important}.CloudBillingHistoryModal .modal-content .modal-header .modal-title{color:#3f4350;font-size:22px;font-weight:semibold}.CloudBillingHistoryModal .modal-content .modal-body{padding:0}.CloudBillingHistoryModal .modal-content .modal-body .BillingHistory__table{border-radius:8px}.CloudBillingHistoryModal .modal-content .close{color:rgba(63,67,80,.56) !important}
.BillingHistory__card{width:100%;height:"463px";border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.CloudBillingHistoryModal .CloudBillingHistoryModal__title{font-family:"Metropolis";font-size:22px;font-weight:semibold}.BillingHistory__cardHeader{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__cardHeaderText-top{font-size:16px;font-weight:600;line-height:24px}.BillingHistory__cardHeaderText-bottom{font-size:14px;line-height:20px}.BillingHistory__cardBody{padding:20px}.BillingHistory__noHistory{display:flex;flex-direction:column;align-items:center}.BillingHistory__noHistory-message{margin-top:24px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.BillingHistory__noHistory-link{margin-top:20px;margin-bottom:40px;color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.BillingHistory__noHistory-graphic{margin-top:28px}.BillingHistory__table{width:100%}.BillingHistory__table th,.BillingHistory__table td{padding:8px 12px}.BillingHistory__table-header{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);background:rgba(var(--sys-center-channel-color-rgb), 0.08);font-weight:600;line-height:16px}.BillingHistory__table-header:last-child{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__table-row{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingHistory__table-row:hover{cursor:pointer}.BillingHistory__table-row:nth-child(odd){background:rgba(var(--sys-center-channel-color-rgb), 0.04)}.BillingHistory__table-bottomDesc{margin-top:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.BillingHistory__table-headerTotal{text-align:left}.BillingHistory__table-total{font-weight:600;text-align:left}.BillingHistory__spinner{margin:auto;text-align:center}.BillingHistory__paymentStatus{color:var(--sys-online-indicator)}.BillingHistory__paymentStatus i{font-size:14.4px;line-height:17px}.BillingHistory__paymentStatus i::before{margin:0}.BillingHistory__paymentStatus span{margin-left:4px;font-weight:600}.BillingHistory__paymentStatus.failed{color:var(--sys-error-text)}.BillingHistory__paymentStatus.pending span{color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.BillingHistory__table-invoice a,.BillingHistory__table-invoice a:link,.BillingHistory__table-invoice a:visited,.BillingHistory__table-invoice a:hover,.BillingHistory__table-invoice a:focus,.BillingHistory__table-invoice a:active{text-decoration:none}.BillingHistory__paging{display:flex;align-items:center;justify-content:flex-end;margin-top:4px}.BillingHistory__paging>span{margin-right:8px}.BillingHistory__paging button{height:32px;padding:7px;border:none;margin-left:4px;background:none;border-radius:4px}.BillingHistory__paging button>i{font-size:18px}.BillingHistory__paging button>i::before{margin:0}.BillingHistory__paging button:disabled{opacity:.6}.BillingHistory__paging button:hover:not(:disabled){background:rgba(var(--sys-center-channel-color-rgb), 0.08)}
.CardImage {
    width: auto;
    max-width: 30px;
    height: auto;
    max-height: 30px;
    margin-top: -1px;
    margin-right: 9px;
}

.DropdownInput{z-index:999999}.DropdownInput.Input_container{margin-top:20px}.DropdownInput .Input_wrapper{padding:0 1px}.DropdownInput .Input{font-size:14px;line-height:20px}.DropdownInput .Input.Input___focus .a11y--focused{box-shadow:none}.DropdownInput .Input_legend{margin-left:8px}.DropdownInput__controlContainer .DropDown__control{background-color:var(--center-channel-bg)}.DropDown__menu{background-color:var(--center-channel-bg) !important}.DropDown__single-value{color:var(--center-channel-color) !important}.DropdownInput__indicatorsContainer{margin-right:8px}.DropdownInput__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.DropdownInput__indicatorsContainer i::before{margin:0}.DropdownInput__option>div{z-index:999999;padding:10px 24px;cursor:pointer;line-height:16px}.DropdownInput__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.DropdownInput__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.second-dropdown-sibling-wrapper .DropdownInput{z-index:999998}.second-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999998}.third-dropdown-sibling-wrapper .DropdownInput{z-index:999997}.third-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999997}.fourth-dropdown-sibling-wrapper .DropdownInput{z-index:999996}.fourth-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999996}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.gatherIntent{margin-bottom:24px}.gatherIntent__title{padding:0;margin:0 0 8px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px !important;font-weight:600 !important;line-height:24px !important}.gatherIntent__button{height:auto !important;padding:0 !important;border:none !important;background:rgba(0,0,0,0) !important;color:var(--button-bg) !important;font-size:14px !important;font-weight:400 !important;line-height:20px !important}.savedFeedback__text{align-self:center;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:22px;font-weight:600}.AltPaymentsModal .modal-content{max-width:512px;max-height:465px;background:var(--center-channel-bg);border-radius:12px}.AltPaymentsModal .modal-dialog{position:absolute;top:50%;left:50%;min-width:532px;margin:auto;transform:translate(-50%, -50%) !important}.AltPaymentsModal .modal-footer{padding-top:24px;padding-bottom:24px;border-radius:0 0 12px 12px}.AltPaymentsModal .modal-header{border-radius:12px 12px 0 0}.AltPaymentsModal .modal-header,.AltPaymentsModal .modal-footer{display:flex;padding-right:32px;padding-left:32px}.AltPaymentsModal .AltPaymentsModal__header{align-items:baseline;border:none}.AltPaymentsModal .AltPaymentsModal__header.modal-header{background:var(--center-channel-bg)}.AltPaymentsModal .AltPaymentsModal__header h3{margin:0;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:22px;font-weight:bold;line-height:28px}.AltPaymentsModal .AltPaymentsModal__header .icon-close{padding:0;border:none;margin-left:auto;background:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.72);font-size:24px}.AltPaymentsModal .modal-body{display:block;overflow:auto;padding:0 32px;margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72)}.AltPaymentsModal__submitted-icon-container{margin-bottom:24px}.AltPaymentsModal__submitted-icon-container>svg{width:51px;height:51px;align-self:center;color:#3db887}.AltPaymentsModal__body{text-align:center}.AltPaymentsModal__body__question{margin-bottom:10px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;font-weight:600}.AltPaymentsModal__body__option{margin-top:0;margin-bottom:12px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;font-weight:400}.AltPaymentsModal__body__label{padding-left:12px;cursor:default;vertical-align:bottom}.AltPaymentsModal__body__checkbox{height:28px;vertical-align:middle}.AltPaymentsModal__body__error{display:flex;align-items:center;gap:10px}.AltPaymentsModal__body__error__text{color:var(--error-text);font-size:14px}.AltPaymentsModal__body__error__icon{display:inline-flex;width:16px;height:16px;flex-grow:0;align-items:center;filter:invert(54%) sepia(68%) saturate(314%) hue-rotate(309deg) brightness(83%) contrast(117%)}.AltPaymentsModal__body__textarea{width:100%;border:solid 1px rgba(63,67,80,.16);background:rgb(var(--center-channel-bg-rgb));border-radius:4px;resize:none}.AltPaymentsModal__footer{align-items:center;justify-content:flex-end;gap:8px}.AltPaymentsModal__footer--secondary{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.AltPaymentsModal__footer--secondary:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.AltPaymentsModal__footer--secondary:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.AltPaymentsModal__footer--secondary:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.AltPaymentsModal__footer--secondary i{display:flex;font-size:18px}.AltPaymentsModal__footer--secondary i:first-child::before{margin:0 7px 0 0}.AltPaymentsModal__footer--secondary i:last-child::before{margin:0 0 0 7px}.AltPaymentsModal__footer--primary{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.AltPaymentsModal__footer--primary:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.AltPaymentsModal__footer--primary:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.AltPaymentsModal__footer--primary:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.AltPaymentsModal__footer--primary:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.AltPaymentsModal__footer--primary i{display:flex;font-size:18px}
.SwitchToYearlyPlanConfirmModal .modal-header{border-bottom:none !important;background:none !important}.SwitchToYearlyPlanConfirmModal .modal-header button.close span{color:rgba(63,67,80,.56) !important}.SwitchToYearlyPlanConfirmModal .modal-body{padding-top:0 !important}.SwitchToYearlyPlanConfirmModal .content-body{display:flex;flex-direction:column;align-items:center;justify-content:center}.SwitchToYearlyPlanConfirmModal .content-body .alert-svg{margin-top:-20px;margin-bottom:-47px}.SwitchToYearlyPlanConfirmModal .content-body .title{margin:10px 0;color:var(--sys-denim-center-channel-text);font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.SwitchToYearlyPlanConfirmModal .content-body .subtitle{width:90%;color:var(--sys-denim-center-channel-text);font-size:14px;font-style:normal;font-weight:normal;line-height:20px;text-align:center}.SwitchToYearlyPlanConfirmModal .content-body .sales-info{margin:10px 0;color:var(--sys-denim-center-channel-text)}.SwitchToYearlyPlanConfirmModal .content-footer{display:flex;align-items:center;justify-content:center;margin-top:20px}.SwitchToYearlyPlanConfirmModal .modal-footer{display:flex;justify-content:center;padding:32px 32px 48px 32px}
.ProcessPayment-progress {
    width: 387px;
    height: 4px;
    margin: 0 auto;
    margin-top: 60px;
    background: rgb(34, 64, 109, 0.12);
    border-radius: 4px;
}

.ProcessPayment-progress-fill {
    height: 100%;
    background: #0058cc;
    border-radius: 4px;
}

.ProcessPayment-body {
    overflow-x: hidden;
    overflow-y: hidden;
}

.PurchaseModal .RenewalRHS{position:sticky;display:flex;width:25%;flex-direction:column;padding-top:80px}.PurchaseModal .RenewalRHS .RenewalCard{max-width:353px;padding:28px 32px;border:1px solid var(--light-8-center-channel-text, rgba(61, 60, 64, 0.08));background:var(--light-center-channel-bg, #fff);border-radius:4px;box-shadow:0 2px 3px 0 rgba(0,0,0,.08)}.PurchaseModal .RenewalRHS .RenewalCard .SeatsCalculator{padding:0}.PurchaseModal .RenewalRHS .RenewalCard .SeatsCalculator .SeatsCalculator__seats-item.SeatsCalculator__seats-item--input{padding:0}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary{width:332px;padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-left:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__noBillingHistory{display:flex;flex-direction:column;align-items:flex-start;justify-content:flex-start}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__noBillingHistory-title{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__noBillingHistory-message{margin-top:8px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__noBillingHistory-link{margin-top:16px;margin-bottom:24px;color:var(--sys-button-bg);font-size:12px;font-weight:600}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice{color:var(--sys-center-channel-color)}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice hr{border-color:rgba(var(--sys-center-channel-color-rgb), 0.32);margin:12px 0}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-header{display:flex;align-items:center}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-headerTitle{font-size:20px;font-weight:600;line-height:28px}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus{display:flex;align-items:center;margin-left:auto;font-size:12px;font-weight:600;line-height:16px}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus.paid{color:var(--sys-online-indicator)}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus.failed{color:var(--sys-error-text)}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus.pending{color:#f58b00}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus svg{width:16px;height:16px;margin-left:4px;font-size:14.4px}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus svg::before{margin:0 auto}.PurchaseModal .RenewalRHS .RenewalCard .BillingSummary__lastInvoice-headerStatus span{margin-left:4px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-due-date{margin-top:8px;color:var(--light-72-center-channel-text, rgba(61, 60, 64, 0.72));font-size:14px;font-style:normal;font-weight:400;line-height:20px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-productName{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-charge{display:flex;margin:12px 0;color:var(--center-channel-color);font-size:12px;font-weight:400;line-height:20px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-charge.total{font-size:14px;font-weight:600}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-hasMoreItems{display:flex;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;font-weight:400}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-hasMoreItems .RenewalSummary__upcomingInvoice-chargeDescription:hover{cursor:pointer;text-decoration:underline}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-ellipses{display:flex;align-items:center;align-self:stretch;justify-content:center;fill:#d9d9d9}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-chargeAmount{margin-left:auto}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-partialCharges{color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-partialCharges+.RenewalSummary__lastInvoice-charge{margin-top:4px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__lastInvoice-download{margin-top:32px;margin-bottom:16px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-renew-button{display:flex;width:100%;align-items:center;justify-content:center;padding:11px 20px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-renew-button:hover:not(:disabled){background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.16), rgba(var(--sys-center-channel-color-rgb), 0.16)),var(--sys-button-bg);color:var(--sys-button-color);cursor:pointer;text-decoration:none}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-renew-button:disabled{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.32);cursor:not-allowed}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-renew-button>span{margin-left:6px;font-size:14px;font-weight:600;line-height:14px}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-viewInvoiceLink{display:block;width:100%;height:16px;margin-bottom:12px;background:none;color:var(--link-color, #1c58d9);font-size:12px;font-weight:600;line-height:9.5px;text-align:center}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__upcomingInvoice-viewInvoice{display:block;width:100%;background:none;color:var(--link-color, #1c58d9);font-size:12px;font-weight:600;line-height:9.5px;text-align:center}.PurchaseModal .RenewalRHS .RenewalCard .RenewalSummary__disclaimer{margin-top:16px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}
.PurchaseModal{overflow:hidden;height:100%}.PurchaseModal .PurchaseModal__purchase-body{overflow-y:auto}.PurchaseModal>div{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:flex-start;justify-content:center;padding:40px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600}.PurchaseModal>div.processing{display:none}.PurchaseModal>div .footer-text .normal-payment-text{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px}.PurchaseModal>div .footer-text .prorrated-payment-text div{display:inline-block;margin-right:4px;font-family:"compass-icons";font-size:16px}.PurchaseModal>div .footer-text a{color:var(--button-bg) !important}.PurchaseModal>div .fineprint-text{margin-top:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;line-height:16px}.PurchaseModal>div .bold-text{font-weight:600}.PurchaseModal>div .normal-text{font-weight:normal}.PurchaseModal>div .LHS{width:25%}.PurchaseModal>div .LHS .title{font-weight:600}.PurchaseModal>div .LHS .image{padding:32px 0}.PurchaseModal>div .central-panel{width:50%;padding-top:80px}.PurchaseModal>div .central-panel .PaymentDetails{padding:10px 0 0 10%;font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text{width:416px;height:318px;box-sizing:border-box;padding:32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:24px 0;background-color:#fff;border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text .CardImage{max-width:55px !important;max-height:37px !important}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text .PaymentInfoDisplay__paymentInfo-cardInfo{margin:10px 0}.PurchaseModal>div .central-panel .PaymentDetails .title{font-size:16px;font-style:normal;font-weight:600;line-height:24px}.PurchaseModal>div .central-panel .PaymentDetails .editPaymentButton{padding-left:20px !important;border:none;background:none;color:var(--button-bg);font-size:14px;font-weight:600;line-height:24px}.PurchaseModal>div .full-width{border-color:rgba(var(--center-channel-color-rgb), 0.16)}.PurchaseModal>div .RHS{position:sticky;display:flex;width:25%;flex-direction:column;align-items:center}.PurchaseModal>div .RHS .price-text{display:flex;align-items:baseline;padding:8px 0;font-size:32px;font-weight:600;line-height:1}.PurchaseModal>div .RHS .price-text .price-decimals{align-self:end;padding-bottom:2px;font-size:16px}.PurchaseModal>div .RHS .price-text .price-decimals::before{content:"."}.PurchaseModal>div .RHS .monthly-text{align-self:center;margin-left:5px;font-size:14px;font-weight:normal}.PurchaseModal>div .RHS .plan_comparison{text-align:center}.PurchaseModal>div .RHS .plan_comparison.show_label{margin-bottom:51px}.PurchaseModal>div .RHS .plan_comparison button,.PurchaseModal>div .RHS .plan_comparison a{width:100%;height:40px;padding:10px 24px;border:none;background:none;color:var(--denim-button-bg);font-size:14px;font-weight:600;line-height:20px}.PurchaseModal>div .RHS .PlanCard{position:relative;width:280px;height:auto}.PurchaseModal>div .RHS .PlanCard .planLabel{position:absolute;top:-44px;left:52px;display:flex;width:184px;align-items:center;justify-content:center;padding:14px;border-radius:13px 13px 0 0;font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:600;gap:5px;line-height:16px}.PurchaseModal>div .RHS .PlanCard .top{height:18px;border-radius:4px 4px 0 0}.PurchaseModal>div .RHS .PlanCard .bottom{padding-right:24px;padding-bottom:24px;padding-left:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:0 0 4px 4px}.PurchaseModal>div .RHS .PlanCard .bottom:not(.delinquency,.bottom-monthly-yearly){height:auto}.PurchaseModal>div .RHS .PlanCard .bottom .enable_annual_sub{margin-top:12px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn{width:100%;height:40px;padding:10px 24px;border:none;background:none;border-radius:4px;color:var(--denim-button-bg);font-size:14px;font-weight:700;line-height:14px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.grayed{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.active{border:1px solid var(--denim-button-bg)}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.special{background:var(--denim-button-bg);color:var(--button-color)}.PurchaseModal>div .RHS .PlanCard .bottom .button-description{margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section{width:100%;height:116px;margin-top:24px;margin-bottom:24px;font-weight:400;letter-spacing:-0.02em;text-align:center}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .summary-section{background-color:rgba(var(--denim-button-bg-rgb), 0.08);border-radius:4px;font-family:"Metropolis"}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .summary-section .summary-title{padding-top:12px;font-size:14px;font-weight:400}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .summary-section .summary-total{padding-top:12px;color:#152234;font-size:28px;font-weight:700;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .summary-section .view-breakdown{padding-top:12px;padding-bottom:12px;color:var(--denim-button-bg);font-family:"Metropolis";font-size:14px;font-style:normal;font-weight:400;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .summary-section .view-breakdown:hover{cursor:pointer}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section h1{color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;line-height:60px}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section .enterprise_price{font-size:32px}.PurchaseModal>div .RHS .PlanCard .bottom .delinquency_summary_section p{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:18px;font-style:normal;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section{width:100%;height:150px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);font-weight:400;letter-spacing:-0.02em;text-align:center}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section h4{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:20px;font-style:normal;line-height:30px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section h4.plan_name{margin-top:16px;margin-bottom:0}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section h1{margin:0;color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;line-height:60px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section .enterprise_price{font-size:32px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section p{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:18px;font-style:normal;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section p.plan_text{margin-bottom:0}.PurchaseModal>div .RHS .PlanCard .bottom .plan_payment_commencement{margin-top:16px;margin-bottom:24px;color:var(--center-channel-color-rgb);font-size:14px;font-style:normal;font-weight:400;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_billing_cycle{margin-top:16px;margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_billing_cycle.delinquency{margin-bottom:24px}.PurchaseModal>div .RHS .PlanCard .bottom table{width:100%;border-collapse:collapse}.PurchaseModal>div .RHS .PlanCard .bottom table .yearly_savings{padding-top:12px;padding-bottom:12px;color:var(--denim-status-online);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:700;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom table .total_price{color:var(--sys-denim-center-channel-text);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:700;line-height:24px}.PurchaseModal>div .RHS .PlanCard .bottom table .monthly_price{color:var(--sys-denim-center-channel-text);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;letter-spacing:.02em;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom table tr td:nth-child(2){text-align:right}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid{display:flex;margin-top:20px}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .user_seats_container{width:100px}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .user_seats_container .user_seats{height:24px}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .user_seats_container .Input_container fieldset:not(.Input_fieldset___error){margin-bottom:24px}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .icon{flex:1;align-self:flex-start;justify-content:left}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .icon .icon-information-outline{margin:0;color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72)}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .Input___customMessage{width:250px;margin-bottom:4px}.PurchaseModal>div .RHS .PlanCard .bottom .flex-grid .Input___customMessage .icon.error{display:none}.PurchaseModal>div .RHS .PlanCard .bottom.bottom-monthly-yearly{display:block;overflow:auto;border-radius:4px}.PurchaseModal>div .RHS .PlanCard .signup-consequences{display:flex;flex-direction:column;margin-top:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}.PurchaseModal>div .RHS .PlanCard .signup-consequences span:first-of-type{margin-bottom:10px}.PurchaseModal>div .logo{position:absolute;right:0;bottom:0}.PurchaseModal>div button{width:fit-content;height:40px;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-size:14px;font-weight:600}.PurchaseModal>div button:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.background-svg{position:absolute;z-index:-1;top:0}.background-svg>div{position:absolute;top:0;left:0}.FullScreenModal .close-x{top:12px;right:12px}.tooltipTitle{font-weight:700}.tooltipText{color:#9a9a9a !important;text-align:left}.proratedTooltip>.tooltip-inner{min-width:300px}
.SelfHostedPurchaseModal__success{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:center;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600}
.SelfHostedPurchaseModal{overflow:hidden;height:100%}.SelfHostedPurchaseModal .form-view{display:flex;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-items:flex-start;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600;overflow-x:hidden;overflow-y:auto}.SelfHostedPurchaseModal .form-view .title{font-size:22px;font-weight:600}.SelfHostedPurchaseModal .form-view .form{padding:0 96px;margin:0 auto}.SelfHostedPurchaseModal .form-view .form .form-row{display:flex;width:100%;margin-bottom:24px}.SelfHostedPurchaseModal .form-view .form .form-row-third-1{width:66%;max-width:288px;margin-right:16px}.SelfHostedPurchaseModal .form-view .form .form-row-third-1 .DropdownInput{margin-top:0}.SelfHostedPurchaseModal .form-view .form .DropdownInput{position:relative;height:36px;margin-bottom:24px}.SelfHostedPurchaseModal .form-view .form .DropdownInput .Input_fieldset{height:43px}.SelfHostedPurchaseModal .form-view .form .form-row-third-2{width:34%;max-width:144px}.SelfHostedPurchaseModal .form-view .form .section-title{margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;font-weight:600;text-align:left}.SelfHostedPurchaseModal .form-view .form .Input_fieldset{height:40px;padding:2px 1px;background:var(--center-channel-bg)}.SelfHostedPurchaseModal .form-view .form .Input_fieldset .Input{height:32px;background:inherit}.SelfHostedPurchaseModal .form-view .form .Input_fieldset .Input_wrapper{margin:0}.SelfHostedPurchaseModal .form-view--hide{display:none}.SelfHostedPurchaseModal .form-view>.lhs{width:25%}.SelfHostedPurchaseModal .form-view>.center{width:50%}.SelfHostedPurchaseModal .form-view>.rhs{position:sticky;display:flex;width:25%;flex-direction:column;align-items:center}.SelfHostedPurchaseModal .form-view>.rhs .price-text{display:flex;align-items:baseline;padding:8px 0;font-size:32px;font-weight:600;line-height:1}.SelfHostedPurchaseModal .form-view>.rhs .price-text .price-decimals{align-self:end;padding-bottom:2px;font-size:16px}.SelfHostedPurchaseModal .form-view>.rhs .price-text .price-decimals::before{content:"."}.SelfHostedPurchaseModal .form-view>.rhs .monthly-text{align-self:center;margin-left:5px;font-size:14px;font-weight:normal}.SelfHostedPurchaseModal .form-view>.rhs .plan_comparison{text-align:center}.SelfHostedPurchaseModal .form-view>.rhs .plan_comparison.show_label{margin-bottom:51px}.SelfHostedPurchaseModal .form-view>.rhs .plan_comparison button,.SelfHostedPurchaseModal .form-view>.rhs .plan_comparison a{width:100%;height:40px;padding:10px 24px;border:none;background:none;color:var(--denim-button-bg);font-size:14px;font-weight:600;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard{position:relative;width:280px;height:auto}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .planLabel{position:absolute;top:-44px;left:52px;display:flex;width:184px;align-items:center;justify-content:center;padding:14px;border-radius:13px 13px 0 0;font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:600;gap:5px;line-height:16px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .top{height:18px;border-radius:4px 4px 0 0}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom{padding-right:24px;padding-bottom:24px;padding-left:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:0 0 4px 4px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom:not(.delinquency,.bottom-monthly-yearly){height:auto}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .enable_annual_sub{margin-top:12px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_action_btn{width:100%;height:40px;padding:10px 24px;border:none;background:none;border-radius:4px;color:var(--denim-button-bg);font-size:14px;font-weight:700;line-height:14px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_action_btn.grayed{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_action_btn.active{border:1px solid var(--denim-button-bg)}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_action_btn.special{background:var(--denim-button-bg);color:var(--button-color)}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .button-description{margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section{width:100%;height:116px;margin-top:24px;margin-bottom:24px;font-weight:400;letter-spacing:-0.02em;text-align:center}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .summary-section{background-color:rgba(var(--denim-button-bg-rgb), 0.08);border-radius:4px;font-family:"Metropolis"}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .summary-section .summary-title{padding-top:12px;font-size:14px;font-weight:400}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .summary-section .summary-total{padding-top:12px;color:#152234;font-size:28px;font-weight:700;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .summary-section .view-breakdown{padding-top:12px;padding-bottom:12px;color:var(--denim-button-bg);font-family:"Metropolis";font-size:14px;font-style:normal;font-weight:400;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .summary-section .view-breakdown:hover{cursor:pointer}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section h1{color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;line-height:60px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section .enterprise_price{font-size:32px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .delinquency_summary_section p{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:18px;font-style:normal;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section{width:100%;height:150px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);font-weight:400;letter-spacing:-0.02em;text-align:center}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section h4{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:20px;font-style:normal;line-height:30px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section h4.plan_name{margin-top:16px;margin-bottom:0}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section h1{margin:0;color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;line-height:60px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section .enterprise_price{font-size:32px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section p{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:18px;font-style:normal;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_price_rate_section p.plan_text{margin-bottom:0}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_payment_commencement{margin-top:16px;margin-bottom:24px;color:var(--center-channel-color-rgb);font-size:14px;font-style:normal;font-weight:400;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_billing_cycle{margin-top:16px;margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .plan_billing_cycle.delinquency{margin-bottom:24px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom table{width:100%;border-collapse:collapse}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom table .yearly_savings{padding-top:12px;padding-bottom:12px;color:var(--denim-status-online);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:700;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom table .total_price{color:var(--sys-denim-center-channel-text);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:700;line-height:24px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom table .monthly_price{color:var(--sys-denim-center-channel-text);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;letter-spacing:.02em;line-height:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom table tr td:nth-child(2){text-align:right}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid{display:flex;margin-top:20px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .user_seats_container{width:100px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .user_seats_container .user_seats{height:24px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .user_seats_container .Input_container fieldset:not(.Input_fieldset___error){margin-bottom:24px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .icon{flex:1;align-self:flex-start;justify-content:left}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .icon .icon-information-outline{margin:0;color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72)}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .Input___customMessage{width:250px;margin-bottom:4px}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom .flex-grid .Input___customMessage .icon.error{display:none}.SelfHostedPurchaseModal .form-view>.rhs .PlanCard .bottom.bottom-monthly-yearly{display:block;overflow:auto;border-radius:4px}.SelfHostedPurchaseModal .signup-consequences{display:flex;flex-direction:column;margin-top:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}.SelfHostedPurchaseModal .signup-consequences span:first-of-type{margin-bottom:10px}.SelfHostedPurchaseModal .submitting,.SelfHostedPurchaseModal .success,.SelfHostedPurchaseModal .failed{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:center;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600}.SelfHostedPurchaseModal .submitting .IconMessage .content .IconMessage-link,.SelfHostedPurchaseModal .success .IconMessage .content .IconMessage-link,.SelfHostedPurchaseModal .failed .IconMessage .content .IconMessage-link{margin-left:0}.SelfHostedPurchaseModal .background-svg{position:absolute;z-index:-1;top:0;width:100%;height:100%}.SelfHostedPurchaseModal .background-svg>div{position:absolute;top:0;left:0}.SelfHostedPurchaseModal .self-hosted-agreed-terms{font-size:16px}.SelfHostedPurchaseModal .self-hosted-agreed-terms label{display:flex;align-items:flex-start;justify-content:flex-start}.SelfHostedPurchaseModal .self-hosted-agreed-terms input[type=checkbox]{width:17px;height:17px;flex-shrink:0;margin-right:12px}@media(max-width: 1020px){.SelfHostedPurchaseModal .form-view>.lhs{display:none}.SelfHostedPurchaseModal .form-view>.center{width:66%}.SelfHostedPurchaseModal .form-view>.rhs{width:33%}}.FullScreenModal .close-x{top:12px;right:12px}
.AirGappedModal .modal-dialog{position:absolute;top:50%;left:50%;width:512px;height:660px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:12px;transform:translate(-50%, -50%) !important}.AirGappedModal .modal-content{border-radius:12px}.AirGappedModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;background:var(--center-channel-bg) !important;border-radius:12px;color:var(--center-channel-color)}.AirGappedModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.AirGappedModal .modal-header .close:hover,.AirGappedModal .modal-header .close:active,.AirGappedModal .modal-header .close:focus,.AirGappedModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.AirGappedModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.AirGappedModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px}.AirGappedModal .modal-body .description{margin:0 auto;margin-top:8px;color:rgb(var(--center-channel-color-rgb));font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:left}.AirGappedModal .modal-body .icon{width:100%;align-items:center;margin-top:32px;text-align:center}.AirGappedModal .modal-body .buttons{margin-top:32px;text-align:right}.AirGappedModal .modal-body .buttons .confirm-btn{height:40px;flex:none;padding:12px 20px;border:none;margin-left:8px;background:var(--button-bg);border-radius:4px;color:var(--sys-button-color);font-size:14px;font-weight:600;line-height:14px}.AirGappedModal .modal-body .buttons .confirm-btn:hover,.AirGappedModal .modal-body .buttons .confirm-btn:active,.AirGappedModal .modal-body .buttons .confirm-btn:focus,.AirGappedModal .modal-body .buttons .confirm-btn:active:focus{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}
.delete-workspace-result_modal .IconMessage{transform:translateY(50%)}.ResultModal__small .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.ResultModal__small .modal-header .close:hover,.ResultModal__small .modal-header .close:active,.ResultModal__small .modal-header .close:focus,.ResultModal__small .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.ResultModal__small .modal-dialog{position:absolute;top:50%;left:50%;width:600px;height:360px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:8px;transform:translate(-50%, -50%) !important}.ResultModal__small .modal-dialog .modal-header{border:none;background:var(--center-channel-bg) !important}.ResultModal__small .modal-dialog .modal-content{height:100%;border-radius:8px}.ResultModal__small .modal-dialog .modal-content .IconMessage__svg-wrapper{margin-left:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-h3{margin-top:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-sub{max-width:504px;margin-top:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-buttons{justify-content:right;padding-right:24px;margin-top:60px}.ResultModal__small .modal-dialog .modal-content .IconMessage-buttons .btn{font-family:"Open sans",sans-serif;font-size:12px;font-weight:600}
.StartTrialFormModal.error{display:none !important}.StartTrialFormModal .modal-dialog{position:absolute;top:50%;left:50%;width:512px;height:660px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:8px;transform:translate(-50%, -50%) !important}.StartTrialFormModal .modal-content{border-radius:8px}.StartTrialFormModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;background:var(--center-channel-bg) !important;border-radius:8px;color:var(--center-channel-color)}.StartTrialFormModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.StartTrialFormModal .modal-header .close:hover,.StartTrialFormModal .modal-header .close:active,.StartTrialFormModal .modal-header .close:focus,.StartTrialFormModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.StartTrialFormModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.StartTrialFormModal .modal-header .description{margin:0 auto;margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.StartTrialFormModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-top:32px;padding-right:32px;padding-bottom:26px;padding-left:32px}.StartTrialFormModal .modal-body .disclaimer{width:100%;height:32px;margin:0;margin-top:36px;margin-bottom:32px;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.StartTrialFormModal .modal-body .email_input{margin-top:36px}.StartTrialFormModal .modal-body .company_name_input{margin-top:36px}.StartTrialFormModal .modal-body .DropdownInput{margin-top:36px}.StartTrialFormModal .modal-body .DropdownInput .DropDown__menu{z-index:999;max-height:124px}.StartTrialFormModal .modal-body .DropdownInput .DropDown__menu-list{z-index:999;max-height:124px}.StartTrialFormModal .modal-body .Input___error{height:100%;font-weight:600;line-height:16px}.StartTrialFormModal .modal-body .Input___error .icon.error.icon-alert-circle-outline{width:16px;height:16px;margin-right:4px;font-size:16px}.StartTrialFormModal .modal-body .countries-section{z-index:999;max-height:164px}.StartTrialFormModal .modal-body .buttons{margin-top:32px;text-align:right}.StartTrialFormModal .modal-body .buttons .confirm-btn{height:40px;flex:none;padding:12px 20px;border:none;margin-left:8px;background:var(--button-bg);border-radius:4px;color:var(--sys-button-color);font-size:14px;font-weight:600;line-height:14px}.StartTrialFormModal .modal-body .buttons .confirm-btn:hover,.StartTrialFormModal .modal-body .buttons .confirm-btn:active,.StartTrialFormModal .modal-body .buttons .confirm-btn:focus,.StartTrialFormModal .modal-body .buttons .confirm-btn:active:focus{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.StartTrialFormModal .modal-centered{text-align:center}
.StartTrialBtn.embargoed{margin-top:5px;color:var(--error-text)}.StartTrialBtn.start-trial-btn{display:block;width:fit-content;padding:13px 20px;border:none;background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.StartTrialBtn.start-trial-btn:hover:not(.disabled){background:rgba(var(--sys-button-bg-rgb), 0.04);text-decoration:none}.StartTrialBtn.start-trial-btn:active{background:rgba(var(--sys-button-bg-rgb), 0.08);text-decoration:none}.StartTrialBtn.start-trial-btn:focus{box-shadow:inset 0 0 0 2px var(--sys-button-bg);text-decoration:none}
.PricingModal .modal-dialog{position:absolute;top:50%;left:50%;width:1440px;margin:auto;transform:translate(-50%, -50%) !important}.PricingModal .modal-header{height:77px;min-height:77px}.PricingModal .PricingModal__header{display:flex;align-items:center;justify-content:space-between;border:none;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);font-size:22px;font-weight:600}.PricingModal .PricingModal__header .header_lhs{display:flex;align-items:center}.PricingModal .PricingModal__header .header_lhs h1{margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px}.PricingModal .PricingModal__header .header_lhs div{padding-left:8px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:400;line-height:20px}.PricingModal .PricingModal__header::before,.PricingModal .PricingModal__header::after{display:none}.PricingModal .modal-body{display:flex;height:623px;min-height:623px;flex-direction:column;padding:0 71px;overflow-x:visible;overflow-y:scroll}.PricingModal .modal-body .alert-option{display:flex;width:100%;flex-direction:column;text-align:right}.PricingModal .modal-body .alert-option span{color:var(--center-channel-color);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:600;line-height:20px;text-align:right}.PricingModal .modal-body .alert-option a{color:var(--denim-button-bg);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:600;line-height:20px}.PricingModal .PricingModal__body{position:relative;display:flex;align-self:center;margin-bottom:111px;gap:48px}.PricingModal .PricingModal__body .BlankCard{position:relative;width:280px}.PricingModal .PricingModal__body .BlankCard .image{margin-top:8px}.PricingModal .PricingModal__body .BlankCard hr{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.PricingModal .PricingModal__body .BlankCard .description{border-bottom:1px solid rgba(var(--center-channel-color-rgb) 0.16);text-align:left}.PricingModal .PricingModal__body .BlankCard .description .title{margin-top:24px;margin-bottom:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:600;line-height:20px}.PricingModal .PricingModal__body .BlankCard .description .title .questions{margin-right:2px;color:var(--center-channel-color)}.PricingModal .PricingModal__body .BlankCard .description .title .contact{color:var(--denim-button-bg)}.PricingModal .PricingModal__body .BlankCard .description .content{margin-bottom:25px;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px}.PricingModal .PricingModal__body .BlankCard .self-hosted-interest{padding:8px;margin-top:24px;background:rgba(var(--denim-button-bg-rgb), 0.08);border-radius:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:600;line-height:20px}.PricingModal .PricingModal__body .BlankCard .self-hosted-interest .interested{margin-right:2px;color:var(--center-channel-color)}.PricingModal .PricingModal__body .BlankCard .self-hosted-interest .learn{color:var(--denim-button-bg)}.PricingModal .PricingModal__body .PlanCard{position:relative;width:280px}.PricingModal .PricingModal__body .PlanCard .planLabel{position:absolute;top:-36px;right:0;left:0;display:flex;width:auto;height:36px;align-items:center;justify-content:center;padding:14px;margin-right:auto;margin-left:auto;border-radius:13px 13px 0 0;font-size:12px;font-style:normal;font-weight:600;gap:5px;letter-spacing:.02em;line-height:16px;text-align:center;text-transform:uppercase}.PricingModal .PricingModal__body .PlanCard .top{height:18px;border-radius:4px 4px 0 0}.PricingModal .PricingModal__body .PlanCard .bottom{height:auto;border:1px solid rgba(var(--center-channel-text-rgb), 0.08);border-top:1px solid var(--center-channel-bg);background-color:var(--center-channel-bg);border-radius:0 0 4px 4px;box-shadow:var(--elevation-6)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container{padding-right:24px;padding-left:24px;margin-bottom:24px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section{width:100%;height:221px;text-align:center}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section h3{margin-top:32px;color:var(--center-channel-color);font-family:"Metropolis";font-size:24px;font-style:normal;font-weight:700;line-height:31px;text-align:center}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section h1{margin:0;color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;letter-spacing:-0.02em;line-height:60px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section span,.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section p{margin-bottom:32px;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:16px;font-style:normal;font-weight:400;line-height:24px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section .plan_rate{margin-bottom:0}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section .building_img{padding-top:0}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section .building_img__expanded{padding-top:14px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section .billed_annually{font-family:"Open sans",sans-serif;font-size:16px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section__expanded{height:244px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section__expanded span,.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_price_rate_section__expanded p{margin-bottom:45px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .contact_sales_cta{height:49px;margin-top:16px;text-align:center}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .contact_sales_cta__reduced{height:32px;margin-top:0}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_limits_cta{height:21px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_limits_cta__expanded{height:32px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons{height:auto}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn{width:100%;height:40px;padding:10px 24px;border:none;background:none;border-radius:4px;color:var(--denim-button-bg);font-weight:600}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn.grayed{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn.secondary{background:rgba(var(--denim-button-bg-rgb), 0.08);color:var(--denim-button-bg)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn.active{border:1px solid var(--denim-button-bg)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn.special{background:var(--denim-button-bg);color:var(--button-color)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_buttons .plan_action_btn.green{background:var(--denim-status-online);color:var(--button-color)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing{height:auto}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing hr{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content{margin-top:16px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content .title{color:var(--center-channel-color);font-family:"Metropolis";font-size:13px;font-style:normal;font-weight:600;letter-spacing:-0.02em;line-height:24px;white-space:nowrap}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content .item{display:flex;max-height:72px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content .item .bullet{display:inline-block;margin:8px 8px 0 0;color:var(--button-bg);font-size:10px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content .item p{margin:0;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:14px;font-style:normal;font-weight:400;letter-spacing:-0.02em;line-height:24px}.PricingModal .PricingModal__body .PlanCard .bottom .bottom_container .plan_briefing .plan_briefing_content__reduced{margin-top:0}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons{position:relative;height:auto;padding:37px 24px 24px 24px;background-color:rgba(var(--center-channel-text-rgb), 0.56);border-radius:0 0 4px 4px;color:var(--sidebar-text)}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .illustration{position:absolute;top:24px;right:36px}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .title{font-family:"Metropolis";font-size:16px;font-style:normal;font-weight:700;line-height:24px}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .item,.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .subitem{font-weight:400}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .item_title,.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .subitem_title{display:flex}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .item_title .bullet,.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .subitem_title .bullet{display:inline-block;margin:8px 8px 0 0;font-size:5px}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .item{margin-left:5px}.PricingModal .PricingModal__body .PlanCard .bottom .plan_add_ons .subitem{margin-left:20px}.PricingModal .PricingModal__body .PlanCard .bottom__round{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:8px}
.LearnMoreTrialModalStep.slide-container{padding:0 24px;color:var(--center-channel-color)}.LearnMoreTrialModalStep.slide-container .svg-wrapper{display:flex;min-height:200px;flex:1;align-items:center;justify-content:center;margin-top:-10px}.LearnMoreTrialModalStep.slide-container .pre-title{margin-top:19px;margin-bottom:8px;font-family:Metropolis,sans-serif;font-size:16px;line-height:24px}.LearnMoreTrialModalStep.slide-container .title{width:100%;margin:0 auto;margin-top:10px 0;font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.LearnMoreTrialModalStep.slide-container .description{width:100%;margin:0 auto;margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.LearnMoreTrialModalStep.slide-container .disclaimer{width:90%;height:32px;margin-top:15px;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.LearnMoreTrialModalStep.slide-container .bottom-text-left-message{position:fixed;bottom:24px;left:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:normal;line-height:16px}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.Menu .MenuItem{display:flex;width:100%;align-items:center;font-size:14px}.Menu .MenuItem.MenuItem--with-icon .MenuItem__help-text{padding-left:28px}.Menu .MenuItem .destructive{color:var(--error-text)}.Menu .MenuItem .MenuItem__icon{width:20px;margin-right:8px;text-align:center}.Menu .MenuItem .MenuItem__compass-icon{margin:4px -6px;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.Menu .MenuItem .MenuItem__compass-icon-dangerous{margin:4px -6px}.Menu .MenuItem .MenuItem__opacity{opacity:.56}.Menu .MenuItem span.icon{display:inline-block;width:28px;height:16px;align-self:center;padding-right:12px;line-height:16px}.Menu .MenuItem span.MenuItem__primary-text{display:inline-flex;padding:5px 0;line-height:22px;white-space:normal}.Menu .MenuItem span.MenuItem__text-color{color:rgba(var(--center-channel-color-rgb), 0.56)}.Menu .MenuItem span.MenuItem__help-text{display:block;padding-bottom:8px;font-size:12px;line-height:16px;opacity:.7;white-space:normal}@media(max-width: 768px){.Menu .MenuItem span.MenuItem__help-text{padding-left:28px !important}.mobile-main-menu .Menu .MenuItem span.MenuItem__help-text{padding-left:36px !important}}.Menu .MenuItem>div,.Menu .MenuItem>button,.Menu .MenuItem>a{display:block;overflow:hidden;width:100%;align-items:center;padding:1px 16px;clear:both;color:inherit;cursor:pointer;font-weight:normal;line-height:28px;text-align:left;text-overflow:ellipsis;white-space:nowrap}.Menu .MenuItem>div i.icon,.Menu .MenuItem>button i.icon,.Menu .MenuItem>a i.icon{padding:0 3px;margin-right:4px;margin-bottom:2px;color:rgba(var(--center-channel-color-rgb), 0.72);vertical-align:middle}.Menu .MenuItem>div i.icon::before,.Menu .MenuItem>button i.icon::before,.Menu .MenuItem>a i.icon::before{margin:0}.Menu .MenuItem>div i.icon+span.MenuItem__primary-text,.Menu .MenuItem>button i.icon+span.MenuItem__primary-text,.Menu .MenuItem>a i.icon+span.MenuItem__primary-text{padding:5px 4px}.Menu .MenuItem>div.disabled,.Menu .MenuItem>button.disabled,.Menu .MenuItem>a.disabled{color:rgba(var(--center-channel-color-rgb), 0.48);cursor:default;pointer-events:none}.Menu .MenuItem>div.disabled:hover,.Menu .MenuItem>button.disabled:hover,.Menu .MenuItem>a.disabled:hover{background:none}.Menu .MenuItem>div.disabled .icon,.Menu .MenuItem>button.disabled .icon,.Menu .MenuItem>a.disabled .icon{color:rgba(var(--center-channel-color-rgb), 0.48)}.Menu .MenuItem>div.MenuItem__with-help,.Menu .MenuItem>button.MenuItem__with-help,.Menu .MenuItem>a.MenuItem__with-help{display:block;height:auto}.Menu .MenuItem>div.MenuItem__with-help .MenuItem__primary-text,.Menu .MenuItem>button.MenuItem__with-help .MenuItem__primary-text,.Menu .MenuItem>a.MenuItem__with-help .MenuItem__primary-text{padding:7px 0 3px}@media(max-width: 768px){.Menu .MenuItem>div.MenuItem__with-help .icon,.Menu .MenuItem>button.MenuItem__with-help .icon,.Menu .MenuItem>a.MenuItem__with-help .icon{top:10px}}.Menu .MenuItem>div.MenuItem__with-sibling,.Menu .MenuItem>button.MenuItem__with-sibling,.Menu .MenuItem>a.MenuItem__with-sibling{padding-right:0 !important}.Menu .MenuItem>div.MenuItem__with-sibling.disabled,.Menu .MenuItem>button.MenuItem__with-sibling.disabled,.Menu .MenuItem>a.MenuItem__with-sibling.disabled{color:rgba(var(--center-channel-color-rgb), 0.48);cursor:default;pointer-events:none}.Menu .MenuItem>div.MenuItem__with-sibling.disabled:hover,.Menu .MenuItem>button.MenuItem__with-sibling.disabled:hover,.Menu .MenuItem>a.MenuItem__with-sibling.disabled:hover{background:none}.Menu .MenuItem>div.MenuItem__with-sibling.disabled .icon,.Menu .MenuItem>button.MenuItem__with-sibling.disabled .icon,.Menu .MenuItem>a.MenuItem__with-sibling.disabled .icon{color:rgba(var(--center-channel-color-rgb), 0.48)}.Menu .MenuItem>div .MenuItem__icon,.Menu .MenuItem>button .MenuItem__icon,.Menu .MenuItem>a .MenuItem__icon{position:relative;top:4px;display:inline-flex;width:20px;height:20px;align-items:center;justify-content:center;margin-right:8px}.Menu .MenuItem>div.MenuItem__dangerous,.Menu .MenuItem>button.MenuItem__dangerous,.Menu .MenuItem>a.MenuItem__dangerous{color:var(--dnd-indicator)}.Menu .MenuItem>div.MenuItem__dangerous i,.Menu .MenuItem>button.MenuItem__dangerous i,.Menu .MenuItem>a.MenuItem__dangerous i{color:var(--dnd-indicator) !important}.Menu .MenuItem>div.MenuItem__dangerous:is(:hover,:active,:focus),.Menu .MenuItem>button.MenuItem__dangerous:is(:hover,:active,:focus),.Menu .MenuItem>a.MenuItem__dangerous:is(:hover,:active,:focus){background-color:var(--dnd-indicator) !important;color:var(--button-color)}.Menu .MenuItem>div.MenuItem__dangerous:is(:hover,:active,:focus) i,.Menu .MenuItem>button.MenuItem__dangerous:is(:hover,:active,:focus) i,.Menu .MenuItem>a.MenuItem__dangerous:is(:hover,:active,:focus) i{color:var(--button-color) !important}.Menu .MenuItem>a{text-decoration:none}.Menu .MenuItem>a:focus,.Menu .MenuItem>a:hover{color:inherit}.Menu .MenuCloudTrial{padding:8px 12px;margin:8px;margin-top:0;border-radius:4px}.Menu .MenuCloudTrial__free-trial__content-title{margin:4px 0;font-weight:600;line-height:20px}.Menu .MenuCloudTrial__free-trial__content-section{display:flex}.Menu .MenuCloudTrial__free-trial__content-section__icon-section{margin-top:-2px;color:var(--denim-button-bg);font-size:18px}.Menu .MenuCloudTrial .upgradeLink{color:var(--button-bg);font-style:normal;font-weight:600}.Menu .MenuCloudTrial .upgradeLink:hover{color:var(--button-bg);font-style:normal;font-weight:600;text-decoration:none}.Menu .MenuCloudTrial .style-link{display:inline-block;min-width:fit-content;border:none;background:none;color:var(--button-bg);font-weight:600}.Menu .MenuCloudTrial .style-link:hover:not(.disabled){border:none;background:none;color:var(--button-bg);text-decoration:underline}.Menu .MenuCloudTrial .open-trial-benefits-modal{display:inline !important;margin-left:2px}.Menu .MenuCloudTrial .open-see-plans-modal{display:block}.Menu .MenuItemCloudLimit{padding:16px 20px;margin-top:0;background-color:rgba(var(--mention-highlight-bg-rgb), 0.16)}.Menu .MenuItemCloudLimit--critical{background-color:rgba(var(--error-text-color-rgb), 0.16)}.Menu .MenuItemCloudLimit .icon-information-outline{color:var(--denim-button-bg);cursor:pointer}.Menu .MenuItemCloudLimit a{color:var(--denim-button-bg) !important;font-weight:bold;text-decoration:none}.Menu .MenuItemCloudLimit a:hover{background:inherit !important}.Menu .MenuItemCloudLimit__title{display:flex;align-items:center;padding-bottom:5px;color:var(--center-channel-color);font-size:14px;font-weight:bold}.Menu .MenuItemCloudLimit__description{padding-bottom:12px;font-size:12px}.Menu .MenuItemCloudLimit__usage{display:flex;align-items:center}.Menu .MenuItemCloudLimit__usage-label{padding-left:18px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:11px;font-weight:bold}.Menu .MenuStartTrial{display:flex;flex-direction:column;align-items:flex-start;padding:8px;padding-left:16px;margin:8px;margin-top:0;background-color:rgba(var(--button-bg-rgb), 0.04);border-radius:4px}.Menu .MenuStartTrial button{padding:3px 0;border:none;background-color:rgba(0,0,0,0);color:var(--link-color);font-style:normal;font-weight:600}.Menu .MenuStartTrial button:hover{background-color:rgba(0,0,0,0)}.Menu .MenuStartTrial .start_trial_content{position:relative;width:100%}.SubMenu{position:absolute;top:unset;left:unset;padding-left:0;cursor:auto}.SubMenu__icon-left{position:relative;top:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:19px}.SubMenu__icon-left-empty{position:relative;top:0;display:none;width:0;font-size:19px;visibility:hidden}.SubMenu__icon-right{padding-top:3px;color:rgba(var(--center-channel-color-rgb), 0.56);float:right;font-size:19px}.SubMenu__icon-right-empty{top:0;display:none;width:0;padding:0;margin-left:auto;font-size:19px}.MenuItem__divider{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:8px 0}
.Menu{z-index:10000}.Menu .dropdown-menu{display:block;min-width:225px;max-width:270px;max-height:80vh;padding:8px 0;border-radius:4px}.Menu .dropdown-menu ul{padding:8px 0;margin:0}.Menu .dropdown-menu li{list-style:none}.Menu .dropdown-menu li a{color:inherit}.Menu.Menu-enter .dropdown-menu{opacity:0}@media screen and (min-width: 768px){.Menu.Menu-enter .dropdown-menu{overflow:hidden;max-height:0;overflow-y:hidden}}.Menu.Menu-enter-active .dropdown-menu{opacity:1}@media screen and (min-width: 768px){.Menu.Menu-enter-active .dropdown-menu{max-height:80vh;overflow-y:hidden;transition:max-height 1000ms ease-in,opacity 250ms linear}}@media screen and (max-width: 640px){.Menu.Menu-enter-active .dropdown-menu{transition:opacity 1000ms linear}}.Menu.Menu-enter-done .dropdown-menu{opacity:1}@media screen and (min-width: 768px){.Menu.Menu-enter-done .dropdown-menu{max-height:80vh;overflow-y:auto}}.Menu.Menu-exit .dropdown-menu{opacity:0}@media screen and (min-width: 768px){.Menu.Menu-exit .dropdown-menu{max-height:0;overflow-y:hidden;transition:max-height 1000ms ease-in 0ms,opacity 250ms linear 750ms}}@media screen and (max-width: 768px){.Menu.Menu-exit .dropdown-menu{transition:opacity 1000ms linear}}.Menu #ChannelMenu-moveToDivider{height:1px;padding:0;margin:8px 0;background:rgba(var(--center-channel-color-rgb), 0.08);pointer-events:none}.Menu #ChannelMenu-moveToDivider span{display:none}@media screen and (max-width: 768px){.Menu #ChannelMenu-moveToDivider{background:none}.Menu #ChannelMenu-moveToDivider .menu-divider{margin:0}}.Menu .SubMenuItemContainer:not(.hasDivider){display:flex;align-items:center;justify-content:space-between}.Menu .styleSelectableItem .MenuItem{width:100%}.Menu .styleSelectableItem .MenuItem div:hover,.Menu .styleSelectableItem .MenuItem div:focus{background:none !important}.Menu .styleSelectableItem .SubMenu__icon-right{padding:0 9px 0 8px;margin-right:0;line-height:28px}.Menu .styleSelectableItem .SubMenu__icon-right.mobile{padding:0 4px 0 9px}.Menu .styleSelectableItem .styleSelectableItemDiv{display:flex;height:34px;align-items:center;justify-content:space-between;padding:0 15px;margin:0}.Menu .styleSelectableItem .grid{display:grid;width:100%;grid-template-columns:auto 1fr auto auto}.Menu .styleSelectableItem .flex{width:100%}.Menu .styleSelectableItem .sorting-menu-checkbox{width:0;padding-right:30px}.Menu .styleSelectableItem .sorting-menu-checkbox i{color:var(--button-bg)}.Menu>.product-switcher-menu .MenuItem .MenuItem__primary-text{line-height:26px}.Menu>.product-switcher-menu .MenuItem a,.Menu>.product-switcher-menu .MenuItem button{padding:0 20px}.Menu>.product-switcher-menu .MenuItem a .icon,.Menu>.product-switcher-menu .MenuItem button .icon{color:rgba(var(--center-channel-color-rgb), 0.56)}.Menu__content.openLeft{right:0;left:inherit}@media screen and (min-width: 768px){.Menu__content.openUp{top:auto;bottom:100%}}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.MenuWrapper{position:relative}.MenuWrapper *:first-child{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}div[disabled]{opacity:.7;pointer-events:none}.MenuWrapperAnimation-enter{opacity:0}.MenuWrapperAnimation-enter-active,.MenuWrapperAnimation-enter-done,.MenuWrapperAnimation-exit{opacity:1}.MenuWrapperAnimation-exit-active,.MenuWrapperAnimation-exit-done{opacity:0}body.enable-animations .MenuWrapperAnimation-enter-active,body.enable-animations .MenuWrapperAnimation-exit-active{transition-duration:80ms;transition-property:opacity}
@media screen and (max-width: 768px){#submenuModal{padding:0}#submenuModal .mobile-sub-menu{max-width:100% !important;height:100%;margin-top:0 !important}#submenuModal .mobile-sub-menu .modal-content{height:100%;padding:0;border:unset;background:rgba(0,0,0,0) !important;box-shadow:unset}#submenuModal .mobile-sub-menu .modal-content .modal-body{overflow:unset;height:100%;max-height:unset;padding:0}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper{height:100%}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper div{height:100%}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu{padding:0 1.5em}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu{position:relative;top:0;display:flex;width:100%;max-width:inherit;height:100%;max-height:inherit;flex-direction:column;justify-content:center;padding-top:0;border:0;margin-bottom:0;background:rgba(0,0,0,0);box-shadow:none;color:inherit;list-style:none}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu button,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu a,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu a:hover{opacity:.8}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem{background:var(--center-channel-bg)}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>button,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>a{width:100%;height:auto;padding:15px 20px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);font-size:14px;opacity:1;text-align:left}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem:first-child div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem:first-child button{border:none}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuGroup.menu-divider{background:#fff}}
.header-footer-route .header-footer-route-container{display:flex;justify-content:space-between}.AccessProblem__body{display:flex;flex-direction:column;align-items:center;justify-content:center}.AccessProblem__title{display:flex;align-items:center;margin:32px 0 16px 0;color:var(--portal-denim);font-family:"Metropolis";font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:center}.AccessProblem__description{display:flex;max-width:640px;align-items:center;padding:0 40px;color:var(--portal-denim);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}
.AlertBanner{display:flex;overflow:hidden;align-items:flex-start;padding:14px;border:1px solid;border-radius:4px}.AlertBanner__message{margin-top:8px}.AlertBanner__footerMessage{margin-top:16px}.AlertBanner__message,.AlertBanner__footerMessage{line-height:20px}.AlertBanner__icon{font-size:24px;line-height:24px}.AlertBanner__icon i{display:contents}.AlertBanner__icon i::before{margin:0}.AlertBanner__body{flex-flow:column;flex-grow:1;flex-shrink:1;margin-left:10px;font-size:14px}.AlertBanner__title{font-weight:600;line-height:24px}.AlertBanner__actionButtons{margin-top:12px;font-family:"Open Sans"}.AlertBanner__actionButtons .AlertBanner__buttonLeft{padding:10px 16px;border:none;background:var(--denim-button-bg);border-radius:4px;color:#fff;font-size:12px;font-weight:600}.AlertBanner__actionButtons .AlertBanner__buttonLeft:hover{background:#1156b2}.AlertBanner__actionButtons .AlertBanner__buttonRight{padding:10px 16px;border:none;margin-left:4px;background:rgba(28,88,217,.08);border-radius:4px;color:#1c58d9}.AlertBanner__actionButtons .AlertBanner__buttonRight:hover{background:rgba(28,88,217,.1215686275)}.AlertBanner__closeButton{display:flex;padding:3px;border:none;background:none;border-radius:4px}.AlertBanner__closeButton:hover{background:rgba(0,0,0,.08)}.AlertBanner--app.danger{border-color:rgba(var(--error-text-color-rgb), 0.24);background:rgba(var(--error-text-color-rgb), 0.08)}.AlertBanner--app.danger .AlertBanner__icon{color:var(--error-text)}.AlertBanner--app.info{border-color:rgba(var(--sidebar-text-active-border-rgb), 0.24);background:rgba(var(--sidebar-text-active-border-rgb), 0.08)}.AlertBanner--app.info .AlertBanner__icon{color:var(--sidebar-text-active-border)}.AlertBanner--app.warning{border-color:rgba(var(--away-indicator-rgb), 0.24);background:rgba(var(--away-indicator-rgb), 0.08)}.AlertBanner--app.warning .AlertBanner__icon{color:var(--away-indicator)}.AlertBanner--app.success{border-color:rgba(var(--online-indicator-rgb), 0.16);background:rgba(var(--online-indicator-rgb), 0.08)}.AlertBanner--app.success .AlertBanner__icon{color:var(--denim-status-online)}.AlertBanner--app .AlertBanner__body{color:var(--center-channel-color)}.AlertBanner--app .AlertBanner__closeButton{color:rgba(var(--center-channel-color-rgb), 0.56)}.AlertBanner--sys.danger{border-color:rgba(var(--sys-error-text-color-rgb), 0.24);background:rgba(var(--sys-error-text-color-rgb), 0.08)}.AlertBanner--sys.danger .AlertBanner__icon{color:var(--sys-error-text)}.AlertBanner--sys.info{border-color:rgba(var(--sys-sidebar-text-active-border-rgb), 0.24);background:rgba(var(--sys-sidebar-text-active-border-rgb), 0.08)}.AlertBanner--sys.info .AlertBanner__icon{color:var(--sys-sidebar-text-active-border)}.AlertBanner--sys.warning{border-color:rgba(var(--sys-away-indicator-rgb), 0.24);background:rgba(var(--sys-away-indicator-rgb), 0.08)}.AlertBanner--sys.warning .AlertBanner__icon{color:var(--sys-away-indicator)}.AlertBanner--sys.success{border-color:rgba(var(--sys-online-indicator-rgb), 0.16);background:rgba(var(--sys-online-indicator-rgb), 0.08)}.AlertBanner--sys.success .AlertBanner__icon{color:var(--sys-online-indicator)}.AlertBanner--sys .AlertBanner__body{color:var(--sys-center-channel-color)}.AlertBanner--sys .AlertBanner__closeButton{color:rgba(var(--sys-center-channel-color-rgb), 0.56)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.ToPaidNudgeBanner__actions{padding-top:12px}.ToPaidNudgeBanner__primary{font-size:12px;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out}.ToPaidNudgeBanner__primary:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.ToPaidNudgeBanner__primary:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.ToPaidNudgeBanner__primary:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.ToPaidNudgeBanner__primary:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.ToPaidNudgeBanner__primary i{display:flex;font-size:18px}.ToPaidNudgeBanner__primary:hover{color:var(--button-color)}.ToPaidNudgeBanner__secondary{margin-left:4px;font-size:12px;display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out}.ToPaidNudgeBanner__secondary:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.ToPaidNudgeBanner__secondary:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.ToPaidNudgeBanner__secondary:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.ToPaidNudgeBanner__secondary i{display:flex;font-size:18px}.ToPaidNudgeBanner__secondary i:first-child::before{margin:0 7px 0 0}.ToPaidNudgeBanner__secondary i:last-child::before{margin:0 0 0 7px}.ToPaidNudgeBanner__secondary:hover{color:var(--button-bg)}
.annnouncementBar__purchaseNow{display:block;padding:12px 20px;border:none;margin-top:15px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.annnouncementBar__purchaseNow span{font-size:14px;font-weight:600;line-height:14px}
.noInternetConnection__container{display:flex;flex-direction:column;text-align:center}.noInternetConnection__container .noInternetConnection__noAccessToInternet{width:304px;height:56px;margin:0 auto;color:rgba(var(--center-channel-color-rgb), 1);font-family:Open Sans;font-size:20px;font-style:normal;font-weight:600;line-height:28px;text-align:center}.noInternetConnection__container .noInternetConnection__contactSupport,.noInternetConnection__container .noInternetConnection__emailUs{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;font-style:normal;font-weight:normal;line-height:28px;text-align:center}.noInternetConnection__container .noInternetConnection__image{margin:0 auto}
.annnouncementBar__renewLicense{display:block;padding:12px 20px;border:none;margin-top:15px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.annnouncementBar__renewLicense span{font-size:14px;font-weight:600;line-height:14px}
.modal .StatusModal.GenericModal .StatusModal__clear-container.input-clear{position:absolute;top:16px;right:20px;color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.StatusModal{width:600px}.StatusModal.modal-dialog{margin:auto}.modal .StatusModal.GenericModal .modal-body{overflow:visible}.modal .StatusModal.GenericModal .emoji-quick-input.form-control{height:4.8rem;padding:0 4.8rem;border-radius:4px;font-size:14px;font-weight:600}.modal .StatusModal.GenericModal .emoji-quick-input.form-control:focus{border-color:var(--button-bg)}.modal .StatusModal.GenericModal .dateTime__calendar-input{border:2px solid var(--button-bg);font-size:14px}.modal .StatusModal.GenericModal .dateTime__calendar-input:hover{border:2px solid var(--button-bg);cursor:pointer}.modal .StatusModal.GenericModal .dateTime__calendar-input:focus-within{box-shadow:0}.modal .StatusModal.GenericModal .dateTime__calendar-input .Input_wrapper{padding:0 10px}.modal .StatusModal.GenericModal .dateTime__calendar-input button.dateTime__calendar-icon{margin:0 8px 0 0;color:rgba(var(--center-channel-color-rgb), 0.72)}.modal .StatusModal.GenericModal .dateTime__calendar-input input#customStatus__calendar-input.form-control{height:auto;padding:0;border:0;font-weight:400}.modal .StatusModal.GenericModal .dateTime__calendar-input input#customStatus__calendar-input.form-control[readonly]{background:rgba(0,0,0,0)}.modal .StatusModal.GenericModal .dateTime__calendar-input input#customStatus__calendar-input.form-control:hover{cursor:pointer}.StatusModal .GenericModal__body{padding:0}.StatusModal .GenericModal__button.btn:disabled,.StatusModal .GenericModal__button.btn:disabled:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);opacity:1}.StatusModal__emoji-container{position:absolute;z-index:5;top:14px;left:40px;margin-right:2px}.StatusModal__emoji-button{display:flex;width:36px;height:36px;align-items:center;justify-content:center;border:none;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.StatusModal__emoji-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.StatusModal__emoji-button:active,.StatusModal__emoji-button--active,.StatusModal__emoji-button--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.StatusModal__emoji-button svg{width:20px;height:20px}.StatusModal__footer{display:flex;align-items:center;justify-content:space-between;padding:2rem 0;text-align:right}.StatusModal__footer .btn{height:4rem;padding:0 2rem;border-radius:4px;font-size:14px;font-weight:600}.status-dropdown-menu .input-clear-x,.StatusModal__input .input-clear-x{color:rgba(var(--center-channel-color-rgb), 0.56)}.status-dropdown-menu .input-clear-x .icon,.StatusModal__input .input-clear-x .icon{font-size:20px}.status-dropdown-menu .MaxLengthInput__validation,.StatusModal__input .MaxLengthInput__validation{top:17px !important;right:44px !important}.status-dropdown-menu .MaxLengthInput.form-control.has-error,.StatusModal__input .MaxLengthInput.form-control.has-error{padding-right:76px !important}.ic-clear-search,.ic-search{position:absolute;z-index:1;background-position:center;background-repeat:no-repeat;cursor:pointer}.ic-clear-search{top:12px;right:12px;width:2rem;height:2rem}.statusSuggestion{overflow:auto;min-height:232px;max-height:264px}.statusSuggestion__content{display:flex;overflow:auto;width:100%;height:100%;flex-direction:column;border:none;box-shadow:none}.statusSuggestion__row{display:flex;width:100%;min-height:40px;align-items:center;padding-right:10px;padding-left:18px;border:none;background:rgba(0,0,0,0);color:var(--center-channel-color);font-size:inherit}.statusSuggestion__row:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px}.statusSuggestion__row:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:v(button-bg)}.statusSuggestion__icon{margin-right:15px;margin-bottom:1px}.statusSuggestion__title{display:flex;height:24px;margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.55);font-size:12px;font-weight:600}.statusSuggestion__text{overflow:hidden;height:20px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.statusSuggestion__text.with_duration{max-width:62%}.statusSuggestion__duration{margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:14px;font-weight:400;line-height:14px}.suggestion-clear{margin-top:3px;margin-left:auto}#custom-status-tooltip p{margin:0}#custom-status-tooltip .custom-status{display:flex;justify-content:center}#custom-status-tooltip .custom-status-expiry{font-weight:400;opacity:.7}span.emoticon[style]:hover{opacity:1 !important}.statusExpiry{display:inline-block;margin-top:12px;font-size:14px}.statusExpiry__menu{cursor:pointer}.statusExpiry__menu .expiry-value{margin-right:4px;font-weight:600}.dateTime{display:flex;margin:24px 0 8px;gap:16px}.dateTime .dateTime__date{position:relative;width:100%}.dateTime .dateTime__date-icon{position:absolute;top:11.3px;left:15px}.dateTime .dateTime__time{position:relative;width:100%}.dateTime .dateTime__time .style--none{width:100%}.dateTime .dateTime__time #expiryTimeMenu .dropdown-menu{overflow:auto;min-width:266px;max-height:268px}.dateTime .dateTime__time-icon{position:absolute;top:11.3px;left:15px}.dateTime .dateTime__input{width:266px;height:40px;padding:10px 40px;border:2px solid var(--button-bg);background:var(--center-channel-bg);border-radius:4px;color:var(--center-channel-color);cursor:pointer;font-size:14px;text-align:left}.dateTime .dateTime__input-title{position:absolute;bottom:32px;left:12px;padding:0 4px;background:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:10px;letter-spacing:.03em;line-height:16px}
.rdp {
  --rdp-cell-size: 40px;
  --rdp-accent-color: #0000ff;
  --rdp-background-color: #e7edff;
  --rdp-accent-color-dark: #3003e1;
  --rdp-background-color-dark: #180270;
  --rdp-outline: 2px solid var(--rdp-accent-color); /* Outline border for focused elements */
  --rdp-outline-selected: 3px solid var(--rdp-accent-color); /* Outline border for focused _and_ selected elements */

  margin: 1em;
}

/* Hide elements for devices that are not screen readers */
.rdp-vhidden {
  box-sizing: border-box;
  padding: 0;
  margin: 0;
  background: transparent;
  border: 0;
  -moz-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  position: absolute !important;
  top: 0;
  width: 1px !important;
  height: 1px !important;
  padding: 0 !important;
  overflow: hidden !important;
  clip: rect(1px, 1px, 1px, 1px) !important;
  border: 0 !important;
}

/* Buttons */
.rdp-button_reset {
  appearance: none;
  position: relative;
  margin: 0;
  padding: 0;
  cursor: default;
  color: inherit;
  background: none;
  font: inherit;

  -moz-appearance: none;
  -webkit-appearance: none;
}

.rdp-button_reset:focus-visible {
  /* Make sure to reset outline only when :focus-visible is supported */
  outline: none;
}

.rdp-button {
  border: 2px solid transparent;
}

.rdp-button[disabled]:not(.rdp-day_selected) {
  opacity: 0.25;
}

.rdp-button:not([disabled]) {
  cursor: pointer;
}

.rdp-button:focus-visible:not([disabled]) {
  color: inherit;
  background-color: var(--rdp-background-color);
  border: var(--rdp-outline);
}

.rdp-button:hover:not([disabled]):not(.rdp-day_selected) {
  background-color: var(--rdp-background-color);
}

.rdp-months {
  display: flex;
}

.rdp-month {
  margin: 0 1em;
}

.rdp-month:first-child {
  margin-left: 0;
}

.rdp-month:last-child {
  margin-right: 0;
}

.rdp-table {
  margin: 0;
  max-width: calc(var(--rdp-cell-size) * 7);
  border-collapse: collapse;
}

.rdp-with_weeknumber .rdp-table {
  max-width: calc(var(--rdp-cell-size) * 8);
  border-collapse: collapse;
}

.rdp-caption {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 0;
  text-align: left;
}

.rdp-multiple_months .rdp-caption {
  position: relative;
  display: block;
  text-align: center;
}

.rdp-caption_dropdowns {
  position: relative;
  display: inline-flex;
}

.rdp-caption_label {
  position: relative;
  z-index: 1;
  display: inline-flex;
  align-items: center;
  margin: 0;
  padding: 0 0.25em;
  white-space: nowrap;
  color: currentColor;
  border: 0;
  border: 2px solid transparent;
  font-family: inherit;
  font-size: 140%;
  font-weight: bold;
}

.rdp-nav {
  white-space: nowrap;
}

.rdp-multiple_months .rdp-caption_start .rdp-nav {
  position: absolute;
  top: 50%;
  left: 0;
  transform: translateY(-50%);
}

.rdp-multiple_months .rdp-caption_end .rdp-nav {
  position: absolute;
  top: 50%;
  right: 0;
  transform: translateY(-50%);
}

.rdp-nav_button {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: var(--rdp-cell-size);
  height: var(--rdp-cell-size);
  padding: 0.25em;
  border-radius: 100%;
}

/* ---------- */
/* Dropdowns  */
/* ---------- */

.rdp-dropdown_year,
.rdp-dropdown_month {
  position: relative;
  display: inline-flex;
  align-items: center;
}

.rdp-dropdown {
  appearance: none;
  position: absolute;
  z-index: 2;
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  margin: 0;
  padding: 0;
  cursor: inherit;
  opacity: 0;
  border: none;
  background-color: transparent;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

.rdp-dropdown[disabled] {
  opacity: unset;
  color: unset;
}

.rdp-dropdown:focus-visible:not([disabled]) + .rdp-caption_label {
  background-color: var(--rdp-background-color);
  border: var(--rdp-outline);
  border-radius: 6px;
}

.rdp-dropdown_icon {
  margin: 0 0 0 5px;
}

.rdp-head {
  border: 0;
}

.rdp-head_row,
.rdp-row {
  height: 100%;
}

.rdp-head_cell {
  vertical-align: middle;
  text-transform: uppercase;
  font-size: 0.75em;
  font-weight: 700;
  text-align: center;
  height: 100%;
  height: var(--rdp-cell-size);
  padding: 0;
}

.rdp-tbody {
  border: 0;
}

.rdp-tfoot {
  margin: 0.5em;
}

.rdp-cell {
  width: var(--rdp-cell-size);
  height: 100%;
  height: var(--rdp-cell-size);
  padding: 0;
  text-align: center;
}

.rdp-weeknumber {
  font-size: 0.75em;
}

.rdp-weeknumber,
.rdp-day {
  display: flex;
  overflow: hidden;
  align-items: center;
  justify-content: center;
  box-sizing: border-box;
  width: var(--rdp-cell-size);
  max-width: var(--rdp-cell-size);
  height: var(--rdp-cell-size);
  margin: 0;
  border: 2px solid transparent;
  border-radius: 100%;
}

.rdp-day_today:not(.rdp-day_outside) {
  font-weight: bold;
}

.rdp-day_selected,
.rdp-day_selected:focus-visible,
.rdp-day_selected:hover {
  color: white;
  opacity: 1;
  background-color: var(--rdp-accent-color);
}

.rdp-day_selected:focus-visible {
  /* Since the background is the same use again the outline */
  outline: var(--rdp-outline);
  outline-offset: 2px;
  z-index: 1;
}

.rdp:not([dir='rtl']) .rdp-day_range_start:not(.rdp-day_range_end) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.rdp:not([dir='rtl']) .rdp-day_range_end:not(.rdp-day_range_start) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.rdp[dir='rtl'] .rdp-day_range_start:not(.rdp-day_range_end) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.rdp[dir='rtl'] .rdp-day_range_end:not(.rdp-day_range_start) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.rdp-day_range_end.rdp-day_range_start {
  border-radius: 100%;
}

.rdp-day_range_middle {
  border-radius: 0;
}

.date-picker__popper{padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:0;background:var(--center-channel-bg);border-radius:4px;box-shadow:0 8px 24px 0 rgba(0,0,0,.12)}.rdp{--rdp-accent-color: var(--button-bg);--rdp-background-color: rgba(var(--center-channel-color-rgb), 0.08);--rdp-cell-size: 36px}.rdp .rdp-caption{padding:4px}.rdp .rdp-caption .rdp-caption_label{color:var(--center-channel-color);font-family:"Metropolis";font-size:16px;font-style:normal;font-weight:600;line-height:24px}.rdp .rdp-head_cell{color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:600;letter-spacing:.02em;line-height:16px;text-transform:uppercase}.rdp .rdp-cell{padding:4px}.rdp .rdp-button{font-weight:600}.rdp .rdp-button.rdp-day{color:var(--center-channel-color)}.rdp .rdp-button.rdp-day_selected{color:var(--button-color)}.rdp .rdp-button.rdp-day_selected:focus-visible:not([disabled]){background-color:var(--rdp-accent-color)}.rdp .rdp-button.rdp-day_selected:hover{background-color:var(--rdp-accent-color);color:var(--button-color)}.rdp .rdp-button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.rdp .rdp-button:active{background-color:rgba(var(--button-bg-rgb), 0.12);color:var(--button-bg)}.rdp .rdp-button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32);opacity:unset}.rdp .rdp-button[disabled]:hover{background-color:rgba(0,0,0,0)}.rdp .rdp-button.rdp-nav_button{border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56)}.rdp .rdp-button.rdp-nav_button_previous{margin-right:8px}.rdp .rdp-button.rdp-nav_button .icon{font-size:24px;font-weight:400;line-height:24px}.rdp .rdp-button.rdp-nav_button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.rdp .rdp-button.rdp-nav_button:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.rdp .rdp-button.rdp-nav_button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32)}.rdp .rdp-button.rdp-nav_button[disabled]:hover{background-color:rgba(0,0,0,0)}
.no-results__holder{display:grid;width:100%;height:100%;place-content:center}.no-results__wrapper{display:flex;max-width:500px;flex-direction:column;align-items:center;padding:30px;margin:auto;text-align:center;word-break:break-word}.no-results__wrapper.horizontal-layout{flex-direction:row}.no-results__wrapper.horizontal-layout svg{flex:0 0 auto;margin-right:16px}.no-results__wrapper.horizontal-layout .no-results__text-container{display:flex;flex-direction:column;text-align:start}.no-results__wrapper.horizontal-layout .no-results__title{margin-bottom:10px}.no-results__variant-wrapper{display:flex;width:120px;height:120px;align-items:center;justify-content:center;margin:22px;border-radius:100%}.no-results__title{margin:0;margin-bottom:15px;color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:20px}.no-results__subtitle{color:rgba(var(--center-channel-color-rgb), 0.72)}.no-results__icon{display:flex}.no-results__icon svg{width:140px;height:140px;fill:var(--button-bg)}.no-results__icon.icon{color:var(--button-bg);font-size:62px}.no-results__mini_icon{width:11px;margin:2px;vertical-align:middle}.no-results__mini_icon svg{fill:var(--button-bg)}
.edit-category__helpText{color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;line-height:40px}.GenericModal__button.delete{background:var(--dnd-indicator) !important}.delete-category__helpText{color:var(--center-channel-color)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.user-popover__set-custom-status-btn{display:flex;width:max-content;align-items:center;padding:2px 0;border:none;background:rgba(0,0,0,0);color:var(--button-bg);font-size:12px;font-weight:600;gap:6px;line-height:10px}.user-profile-popover__heading{font-family:Metropolis,sans-serif;font-size:20px;font-weight:600;line-height:24px;text-align:center}.user-popover-last-active{display:block;margin:8px 0 4px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:11px;font-weight:400;letter-spacing:.02em;line-height:16px;text-align:center}.user-profile-popover{width:240px;max-height:calc(100vh - 240px);overflow-y:auto}.user-profile-popover .popover-title{overflow:unset;max-width:110%;padding:0;border-bottom:none;margin-top:8px;margin-right:-8px}.user-profile-popover .popover-title.popover-title_height{overflow:visible;height:22px}.user-profile-popover .popover-title .user-popover__role{padding:0 4px;margin-left:0;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color-rgb);font-family:Open Sans,sans-serif;font-size:10px;letter-spacing:.02em;line-height:16px}.user-profile-popover .popover-content{padding:0 16px}.user-profile-popover .popover-content .overflow--ellipsis{text-align:center}.user-profile-popover .popover-content .user-popover__subtitle{margin-bottom:4px;font-size:11px;font-weight:600;line-height:16px}.user-profile-popover .popover-content .user-popover__time-status-container{display:flex;flex-direction:column;margin-bottom:8px}.user-profile-popover .popover-content .popover__row{display:flex;align-items:center;justify-content:space-between;padding:16px;gap:12px}.user-profile-popover .popover-content .popover__row.first{border-top-color:rgba(var(--center-channel-color-rgb), 0.08)}.user-profile-popover .popover-content .popover__row .btn{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:32px;padding:8px 12px;gap:6px}.user-profile-popover .popover-content .popover__row .btn:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.user-profile-popover .popover-content .popover__row .btn:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.user-profile-popover .popover-content .popover__row .btn:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.user-profile-popover .popover-content .popover__row .btn:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.user-profile-popover .popover-content .popover__row .btn i{display:flex;font-size:18px}.user-profile-popover .popover-content .popover__row .btn span{font-size:12px;font-weight:600;line-height:10px}.user-profile-popover .popover-content .popover__row .icon-btn{width:32px;padding:0;background-color:unset;color:rgba(var(--center-channel-color-rgb), 0.56)}.user-profile-popover .popover-content .popover__row .icon-btn:hover{background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px}.user-profile-popover .popover-content .popover__row .icon-btn-disabled{cursor:not-allowed;opacity:.65}.user-profile-popover .popover-content .popover__row .popover_row-controlContainer{display:flex;align-items:center}.user-profile-popover .popover-content .popover__row .popover_row-controlContainer .callButtonContainer{height:unset;margin-top:0}
.user-groups-modal-create.modal-dialog,.user-groups-modal-update.modal-dialog,.view-user-groups-modal.modal-dialog,.user-groups-modal.modal-dialog{margin-top:50px}.user-groups-modal-create .modal-content,.user-groups-modal-update .modal-content,.view-user-groups-modal .modal-content,.user-groups-modal .modal-content{border-radius:8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner,.user-groups-modal .modal-content .ad_ldap_upsell_banner{position:sticky;z-index:4;right:12px;bottom:6px;left:12px;display:flex;height:44px;align-items:center;justify-content:space-between;padding:12px 8px;margin:0 12px;background-color:var(--denim-sidebar-active-border);border-radius:8px;box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--button-color)}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .message,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .message,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .message,.user-groups-modal .modal-content .ad_ldap_upsell_banner .message{display:flex;gap:8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .btn-container,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .btn-container,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .btn-container,.user-groups-modal .modal-content .ad_ldap_upsell_banner .btn-container{display:flex;gap:13px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .banner-close,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .banner-close,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .banner-close,.user-groups-modal .modal-content .ad_ldap_upsell_banner .banner-close{height:4rem;border:none;margin-top:0;background:none;font-size:25px;font-weight:400;line-height:18px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.user-groups-modal .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn{border:none;background:none;color:var(--button-color);font-size:14px;font-weight:600;line-height:14px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm,.user-groups-modal .modal-content .ad_ldap_upsell_confirm{position:sticky;z-index:4;top:0;right:0;bottom:0;left:0;overflow:hidden;width:100%;height:100%;border-radius:0 0 8px 8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop{position:fixed;z-index:5;bottom:164px;width:100%;height:calc(100% - 164px);background:rgba(0,0,0,.16)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground{height:148px;padding:16px 32px;background:var(--button-color)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .title,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .title,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .title,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .title{color:#000;font-size:14px;font-weight:600;line-height:20px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .subtitle,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .subtitle,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .subtitle,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .subtitle{color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container{display:flex;justify-content:right;gap:10px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn{width:100px;height:32px;padding:10px 16px;border:none;background:rgba(28,88,217,.08);border-radius:4px;color:var(--denim-button-bg);font-size:12px;font-weight:600;line-height:10px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more{background:rgba(var(--denim-button-bg-rgb), 0.08);color:var(--denim-button-bg)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .continue{background:var(--denim-button-bg);color:var(--button-color)}.user-groups-modal-create .modal-content .modal-header h1#createGroupsModalTitleWithBack,.user-groups-modal-create .modal-content .modal-header h1#updateGroupsModalTitle,.user-groups-modal-create .modal-content .modal-header h1#addUsersToGroupsModalLabel,.user-groups-modal-update .modal-content .modal-header h1#createGroupsModalTitleWithBack,.user-groups-modal-update .modal-content .modal-header h1#updateGroupsModalTitle,.user-groups-modal-update .modal-content .modal-header h1#addUsersToGroupsModalLabel,.view-user-groups-modal .modal-content .modal-header h1#createGroupsModalTitleWithBack,.view-user-groups-modal .modal-content .modal-header h1#updateGroupsModalTitle,.view-user-groups-modal .modal-content .modal-header h1#addUsersToGroupsModalLabel,.user-groups-modal .modal-content .modal-header h1#createGroupsModalTitleWithBack,.user-groups-modal .modal-content .modal-header h1#updateGroupsModalTitle,.user-groups-modal .modal-content .modal-header h1#addUsersToGroupsModalLabel{margin-left:16px}.user-groups-modal-create .modal-body,.user-groups-modal-update .modal-body,.view-user-groups-modal .modal-body,.user-groups-modal .modal-body{max-height:100%;padding:0}.user-groups-modal-create .modal-body .no-results__wrapper,.user-groups-modal-update .modal-body .no-results__wrapper,.view-user-groups-modal .modal-body .no-results__wrapper,.user-groups-modal .modal-body .no-results__wrapper{max-width:350px;padding-bottom:60px}.user-groups-modal-create .modal-body .user-groups-search,.user-groups-modal-update .modal-body .user-groups-search,.view-user-groups-modal .modal-body .user-groups-search,.user-groups-modal .modal-body .user-groups-search{position:relative;margin:6px 32px 8px}.user-groups-modal-create .modal-body .user-groups-search .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-search .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-search .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-search .Input_container .Input_wrapper{margin:6px 0;line-height:38px}.user-groups-modal-create .modal-body .user-groups-search .Input_container .Input,.user-groups-modal-update .modal-body .user-groups-search .Input_container .Input,.view-user-groups-modal .modal-body .user-groups-search .Input_container .Input,.user-groups-modal .modal-body .user-groups-search .Input_container .Input{font-size:14px;line-height:38px}.user-groups-modal-create .modal-body .user-groups-search .fa-search,.user-groups-modal-update .modal-body .user-groups-search .fa-search,.view-user-groups-modal .modal-body .user-groups-search .fa-search,.user-groups-modal .modal-body .user-groups-search .fa-search{position:absolute;top:15px;left:16px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:16px;pointer-events:none}.user-groups-modal-create .modal-body .more-modal__dropdown,.user-groups-modal-update .modal-body .more-modal__dropdown,.view-user-groups-modal .modal-body .more-modal__dropdown,.user-groups-modal .modal-body .more-modal__dropdown{width:100%;padding:0 32px 24px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown{padding:6px;border-radius:4px;line-height:12px}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:active{background:rgba(var(--button-bg-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown a,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown a,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown a,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown a{line-height:12px}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown a span,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown a span,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown a span,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown a span{color:var(--button-bg);font-size:12px;line-height:12px}.user-groups-modal-create .modal-body .more-modal__dropdown .groups-filter-btn span,.user-groups-modal-update .modal-body .more-modal__dropdown .groups-filter-btn span,.view-user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span,.user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span{width:100%}.user-groups-modal-create .modal-body .more-modal__dropdown .groups-filter-btn span i,.user-groups-modal-update .modal-body .more-modal__dropdown .groups-filter-btn span i,.view-user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span i,.user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span i{display:flex;align-items:center;margin-left:auto;color:var(--button-bg)}.user-groups-modal-create .modal-body .user-groups-modal__content,.user-groups-modal-update .modal-body .user-groups-modal__content,.view-user-groups-modal .modal-body .user-groups-modal__content,.user-groups-modal .modal-body .user-groups-modal__content{overflow:auto}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list{position:relative;max-height:460px;padding-top:24px;padding-bottom:16px;overflow-y:scroll;overflow-y:overlay}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar{width:20px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track{background:rgba(0,0,0,0)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb{border:8px rgba(0,0,0,0) solid;background:rgba(var(--center-channel-color-rgb), 0.24);background-clip:padding-box;border-radius:9999px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row{display:flex;align-items:center;padding:14px 32px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover{background:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:active{background:rgba(var(--button-bg-rgb), 0.08)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name{display:block;overflow:hidden;max-width:200px;text-overflow:ellipsis;white-space:nowrap}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i{color:rgba(var(--center-channel-color-rgb), 0.56);font-size:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name{padding-left:8px;color:rgba(var(--center-channel-color-rgb), 0.64)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count{margin-right:8px;margin-left:auto;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action{width:24px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper{width:24px;margin-left:auto}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu{position:absolute;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-top:8px;border-radius:4px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text{font-size:14px;line-height:20px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text.leave-group-action,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text.leave-group-action,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text.leave-group-action,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text.leave-group-action{color:var(--dnd-indicator)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text span.icon,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text span.icon,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text span.icon,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text span.icon{display:inline-flex;width:auto;height:auto;align-self:center;padding-right:12px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:18px;line-height:18px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper{display:flex;width:24px;height:24px;flex-direction:column;align-items:center;padding:4px 6px;border:none;margin-left:auto;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);text-decoration:none}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover{background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon{font-size:16px;line-height:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i{display:flex}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .loading-screen{position:fixed;bottom:0;height:60px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper{padding:6px 32px 12px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus{border-color:rgba(0,0,0,0);box-shadow:none;outline-style:none}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper{margin:6px 0;line-height:38px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input{font-size:14px;line-height:38px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper{padding:12px 32px 24px}.user-groups-modal-create .modal-body .user-groups-modal__content h2,.user-groups-modal-update .modal-body .user-groups-modal__content h2,.view-user-groups-modal .modal-body .user-groups-modal__content h2,.user-groups-modal .modal-body .user-groups-modal__content h2{padding:0 32px;color:inherit;font-size:18px;font-weight:600;line-height:24px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper{margin-top:0}
.ProfilePicture{border-radius:50%}
.user-groups-modal-update .modal-body .update-buttons-wrapper{display:flex;align-items:center;padding:0 24px 24px;float:right}.user-groups-modal-update .modal-body .update-buttons-wrapper .Input___error{margin-top:0;margin-right:12px}.user-groups-modal-update .modal-body .update-buttons-wrapper button{height:40px;padding:0 20px;border-radius:4px;font-size:14px;font-weight:600}.user-groups-modal-update .modal-body .update-buttons-wrapper button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32)}
.view-user-groups-modal .modal-content .modal-header{overflow:visible;padding-bottom:0}.view-user-groups-modal .modal-content .modal-header .modal-title{margin-left:46px}.view-user-groups-modal .modal-content .modal-header .modal-title i{margin-left:5px;color:rgba(var(--center-channel-color-rgb), 0.56)}.view-user-groups-modal .modal-content .modal-header .details-action{margin-right:42px}.view-user-groups-modal .modal-content .modal-header .details-action .MenuWrapper{margin-left:auto}.view-user-groups-modal .modal-body .no-results__wrapper{padding-bottom:60px}.view-user-groups-modal .modal-body .group-mention-name{margin-bottom:25px}.view-user-groups-modal .modal-body .group-mention-name span.group-name{margin-left:70px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;line-height:12px}.view-user-groups-modal .modal-body .group-mention-name span.group-source span{padding:0 4px;margin-left:8px;background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;font-size:10px;line-height:16px}.view-user-groups-modal .modal-body .user-groups-search{margin-bottom:24px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list{max-height:450px;padding-bottom:16px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);overflow-y:scroll;overflow-y:overlay}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar{width:20px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar-track{background:rgba(0,0,0,0)}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar-thumb{border:8px rgba(0,0,0,0) solid;background:rgba(var(--center-channel-color-rgb), 0.24);background-clip:padding-box;border-radius:9999px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list h2.group-member-count{padding:0 32px;margin:16px 0;font-size:16px;line-height:24px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row{display:flex;align-items:center;padding:8px 32px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row .group-member-name{padding-left:12px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row .group-member-username{padding-left:8px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:18px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row button.remove-group-member{display:none;margin-right:0;margin-left:auto}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:hover button.remove-group-member{display:block}
.user-groups-modal-create.modal-dialog{margin-top:calc(50vh - 240px)}.user-groups-modal-create .modal-body{overflow:visible}.user-groups-modal-create .Input___error.group-error{position:absolute;bottom:35px;left:24px}
#user-group-popover .popover-content{padding:0}
.NotificationFromMembersModal .modal-content .modal-header .close{top:16px !important;right:15px !important}.NotificationFromMembersModal .modal-content .modal-body .GenericModal__header{padding:6px 24px 16px 24px}
.tooltip-container{opacity:0;transition:opacity .12s ease-in;visibility:hidden}.tooltip-container.visible{opacity:1;visibility:visible}
.markdown-image-expand{position:relative;display:flex;align-items:center}.markdown-image-expand__collapse-button{position:absolute;top:0;left:0;display:none;width:24px;height:24px;padding:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:16px;box-shadow:var(--elevation-1);color:rgba(var(--center-channel-color-rgb), 0.56);font-size:18px;line-height:21px}.markdown-image-expand__collapse-button .icon{width:18px;height:18px}.markdown-image-expand--expanded:hover .markdown-image-expand__collapse-button{display:block}.markdown-image-expand__collapse-button:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.24);box-shadow:var(--elevation-2)}.markdown-image-expand__expand-button{display:inline-flex;width:100%;padding:0;border:none;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:18px;line-height:18px}.markdown-image-expand__expand-button:hover{color:rgba(var(--center-channel-color-rgb), 0.72)}.markdown-image-expand__expand-button .icon{width:18px;height:18px}.markdown-image-expand__expand-button .icon::before{margin-right:0;margin-left:0}.markdown-image-expand__expand-icon{display:inline-block;vertical-align:middle}.markdown-image-expand__alt-text{display:inline-block;overflow:hidden;font-size:12px;line-height:16px;text-align:left;text-overflow:ellipsis;white-space:nowrap}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.overage_users_banner__description{color:var(--center-channel-text);font-size:14px;font-weight:400;line-height:20px}.overage_users_banner__button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;background:rgba(0,0,0,0);font-size:14px}.overage_users_banner__button:hover,.overage_users_banner__button:active,.overage_users_banner__button:focus{text-decoration-line:underline}.overage_users_banner__button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.GenericModal.modal-dialog{margin-top:calc(40vh - 240px) !important}.ThreeDaysLeftTrialModal .modal-content,.ThreeDaysLeftTrialModal .modal-header{border-radius:8px}.ThreeDaysLeftTrialModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-bottom:24px !important}.ThreeDaysLeftTrialModal .modal-body .header-subtitle-text{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-weight:400;line-height:16px}.ThreeDaysLeftTrialModal .modal-body .content-container{display:flex;flex-direction:column;margin-right:24px}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card{display:flex;width:100%;height:136px;align-items:flex-start;padding:28px 0 16px;gap:10px}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card .svg-wrapper{width:130px;height:91px}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card .content-wrapper{display:flex;flex-direction:column;margin-left:15px;font-family:"Open Sans";font-style:normal}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card .content-wrapper .title{color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card .content-wrapper .description{margin-top:8px;font-size:14px;font-weight:400;line-height:20px}.ThreeDaysLeftTrialModal .modal-body .content-container .three-days-left-card .content-wrapper .LearnMoreActionButton{margin-left:5px}.ThreeDaysLeftTrialModal .modal-body .content-container .workspace-limits-panel{margin:24px 0}.ThreeDaysLeftTrialModal .modal-body .content-container .workspace-limits-panel .limits-title{color:rgba(var(--center-channel-color-rgb), 0.56);font-size:10px;font-weight:700;letter-spacing:.02em;line-height:16px;text-transform:uppercase}.ThreeDaysLeftTrialModal .modal-body .divisory-line{width:598px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.1);margin-left:-32px}.ThreeDaysLeftTrialModal .modal-body .footer-content{display:flex;min-height:60px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn{align-self:self-end;margin-top:24px;margin-left:auto;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn i{display:flex;font-size:18px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus-visible{outline:none !important}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus{border:0}
.apps-form-modal-body-common{position:absolute;z-index:0;top:0;right:0;bottom:0;left:0;display:flex;align-items:center;justify-content:center;backdrop-filter:blur(0);background:var(--center-channel-bg)}.apps-form-modal-body-loaded{z-index:-10}.apps-form-modal-body-loading{z-index:1000}.apps-form-select-option .select-option-item{display:flex;flex-direction:row;align-items:center;column-gap:1.2rem}.apps-form-select-option .select-option-item-label{overflow:hidden;max-width:89%;text-overflow:ellipsis;white-space:nowrap}.apps-form-select-option .select-option-item-label .select-option-main{overflow:hidden;max-width:89%;text-overflow:ellipsis;white-space:nowrap}.apps-form-select-option .select-option-icon{display:inline-flex;flex:0 0 1.6rem;align-items:center;justify-content:center;fill:v(center-channel-color);opacity:.56}.apps-form-select-option .select-option-icon--large{width:2.4rem;height:2.4rem;flex:0 0 1.2rem;font-size:2rem}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.marketplace-modal{width:832px}.marketplace-modal.streamlined-marketplace .modal-header{padding:26px 32px 26px !important}.marketplace-modal.streamlined-marketplace.with-web-marketplace-link .modal-content{border-bottom-left-radius:16px !important;border-bottom-right-radius:16px !important}.marketplace-modal div.navigation-row{overflow:unset;margin-top:10px}.marketplace-modal div.navigation-row div{font-size:14px;text-align:center}.marketplace-modal div.navigation-row div button{font-size:14px;font-weight:bold}.marketplace-modal div.navigation-row div.count{padding:9px 15px}.marketplace-modal .input-clear{top:32px;right:36px;display:flex;width:32px;height:32px;align-items:center;justify-content:center;font-size:16px}.marketplace-modal .nav-tabs{padding:0 32px;margin:0 0 8px}.marketplace-modal .nav-tabs li{margin-right:0}.marketplace-modal .nav-tabs li a{padding:13px 12px;border:none;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14px;font-weight:600;line-height:20px;transition:all .15s ease}.marketplace-modal .nav-tabs li a:hover,.marketplace-modal .nav-tabs li a:active,.marketplace-modal .nav-tabs li a:focus,.marketplace-modal .nav-tabs li a:focus-within{border:none;background:rgba(0,0,0,0);border-radius:none;color:var(--center-channel-color)}.marketplace-modal .nav-tabs li.active{border-bottom:2px solid var(--denim-button-bg)}.marketplace-modal .nav-tabs li.active a{color:var(--denim-button-bg)}.marketplace-modal .nav-tabs li:not(:first-child){margin-left:8px}.marketplace-modal h2{font-weight:300}.marketplace-modal h2 strong{font-weight:400}.marketplace-modal .more-modal__list{height:390px;margin:0 6px 8px 12px;overflow-y:scroll}.marketplace-modal .more-modal__list .more-modal__row{overflow:hidden;min-height:80px;padding:16px 20px;border-bottom:none}.marketplace-modal .more-modal__list .more-modal__row .marketplace__tag{margin-left:6px}.marketplace-modal .more-modal__list .more-modal__row .update{font-size:.9em}.marketplace-modal .more-modal__list .more-modal__row .update a{text-decoration:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details{padding-left:16px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details .more-modal__row--link{color:var(--center-channel-color);font-size:16px;font-weight:600;line-height:24px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details .more-modal__description{margin:2px 0 0;color:var(--center-channel-color-rgb);font-size:14px;font-weight:400;line-height:20px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions{padding-left:16px;margin:0}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed{position:relative;display:inline-flex;align-items:center;justify-content:center;border:1px solid var(--denim-button-bg);background:var(--center-channel-bg);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:hover{background:rgba(var(--denim-button-bg-rgb), 0.08)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:active,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:active{background:rgba(var(--denim-button-bg-rgb), 0.16)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:focus,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:disabled,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:disabled{border:rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure i,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed i{display:flex;font-size:18px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:active,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:focus,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:disabled:not(.always-show-enabled),.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install i,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install i{display:flex;font-size:18px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions a:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions a:focus{text-decoration:none}.marketplace-modal .more-modal__list .more-modal__row:hover,.marketplace-modal .more-modal__list .more-modal__row:focus,.marketplace-modal .more-modal__list .more-modal__row:focus-within{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.marketplace-modal .more-modal__list .icon__plugin{display:flex;height:48px;flex:0 0 48px;align-items:center;justify-content:center;background-color:#fff;border-radius:50%}.marketplace-modal .more-modal__list .icon__plugin svg,.marketplace-modal .more-modal__list .icon__plugin img{width:48px;height:48px}.marketplace-modal .more-modal__list .icon__plugin svg{fill:var(--button-bg)}.marketplace-modal .more-modal__list .icon__plugin img{border-radius:4px}.marketplace-modal .marketplace-modal-search{padding:24px 0 0}.marketplace-modal .marketplace-modal-search .search_input{width:100%;border:0 !important;border-radius:0 !important;box-shadow:none}.marketplace-modal .btn{min-width:8rem;padding:8px 16px;border-radius:4px;font-size:13px;font-weight:600}.marketplace-modal .btn-outline{border:1px solid var(--button-bg);background:rgba(0,0,0,0)}.marketplace-modal .tabs{display:flex;width:100%;flex-direction:column;margin-top:12px}.marketplace-modal .tabs .nav-tabs{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.marketplace-modal .subtitle{margin-left:5px}.marketplace-modal .plugin__list{display:flex;flex-direction:column}.marketplace-modal .plugin__list .plugin__row{display:flex;align-items:center;padding:10px 15px;border-bottom:1px solid rgba(0,0,0,.15)}.marketplace-modal .plugin__list .plugin__row.clickable{cursor:pointer}.marketplace-modal .plugin__list .plugin__row:hover .plugin__actions--round{opacity:.5}.marketplace-modal .no_plugins{display:flex;height:390px;flex-flow:column;align-items:center;justify-content:center;margin-bottom:8px}.marketplace-modal .no_plugins__message{margin-top:20px;color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:28px}.marketplace-modal .no_plugins__action{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px;margin-top:30px}.marketplace-modal .no_plugins__action:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.marketplace-modal .no_plugins__action:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.marketplace-modal .no_plugins__action:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .no_plugins__action:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .no_plugins__action i{display:flex;font-size:18px}.marketplace-modal .no_plugins .icon__plugin svg{fill:var(--button-bg)}.marketplace-modal .item_error{background-color:rgba(var(--error-text-color-rgb), 0.08)}.marketplace-modal .loading{height:390px}.more-modal__description-tooltip .tooltip-inner{text-align:left}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.app-bar{display:flex;min-height:0;flex-flow:column;border-left:solid 1px rgba(var(--center-channel-color-rgb), 0.12);background-color:var(--center-channel-bg)}@media(max-width: 768px){.app-bar{display:none}}.app-bar__top{position:relative;display:flex;width:48px;flex:1;flex-flow:column;padding-top:19px;background-color:rgba(var(--center-channel-color-rgb), 0.04);-ms-overflow-style:none;overflow-x:hidden;overflow-y:scroll;scrollbar-width:none;text-align:center}.app-bar__top .app-bar__icon{position:relative;z-index:21;width:100%;border-left:none;margin-bottom:16px;cursor:pointer}.app-bar__top .app-bar__icon--active::before{position:absolute;top:0;left:0;width:3px;height:24px;background-color:var(--sidebar-text-active-border);border-radius:0 2px 2px 0;content:""}.app-bar__top .app-bar__icon--active .app-bar__icon-inner,.app-bar__top .app-bar__icon--active span:not(.pulsating_dot){box-shadow:0 0 0 2px var(--sidebar-text-active-border)}.app-bar__top .app-bar__icon--active .app-bar__icon-inner:hover,.app-bar__top .app-bar__icon--active span:not(.pulsating_dot):hover{box-shadow:0 0 0 2px rgba(var(--sidebar-text-active-border-rgb), 0.92) !important}.app-bar__top .app-bar__icon .app-bar__icon-inner,.app-bar__top .app-bar__icon span:not(.pulsating_dot){display:block;overflow:hidden;width:24px;height:24px;margin:0 auto;border-radius:50%;line-height:1}.app-bar__top .app-bar__icon .app-bar__icon-inner:hover,.app-bar__top .app-bar__icon span:not(.pulsating_dot):hover{box-shadow:0 0 0 2px rgba(var(--center-channel-color-rgb), 0.16)}.app-bar__top .app-bar__icon .app-bar__icon-inner img,.app-bar__top .app-bar__icon span:not(.pulsating_dot) img{width:24px;height:24px;border-radius:50%}.app-bar__top .app-bar__icon span:not(.pulsating_dot){padding:2px;background-color:#fff;fill:var(--button-bg);font-size:14px;line-height:20px;vertical-align:middle}.app-bar__top .app-bar__icon span:not(.pulsating_dot).CompassIcon,.app-bar__top .app-bar__icon span:not(.pulsating_dot).icon-brand-zoom{font-size:20px}.app-bar__top .app-bar__icon span:not(.pulsating_dot).CompassIcon::before,.app-bar__top .app-bar__icon span:not(.pulsating_dot).icon-brand-zoom::before{margin:0 0 0 .5px}.app-bar__top .app-bar__icon .app-bar__old-icon{color:rgba(var(--center-channel-color-rgb), 0.56)}.app-bar__top .app-bar__icon .app-bar__old-icon:hover,.app-bar__top .app-bar__icon .app-bar__old-icon--active{color:rgba(var(--center-channel-color-rgb), 0.72)}.app-bar__top .app-bar__icon .app-bar__icon-inner--centered{display:grid;place-items:center}.app-bar__top .app-bar__divider{width:28px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-top:0;margin-bottom:19px}.app-bar__top .app-bar__icon.channel-header__icon--active{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.app-bar__bottom{position:relative;display:flex;flex-flow:column;align-items:center;padding-top:24px;padding-bottom:36px;background-color:rgba(var(--center-channel-color-rgb), 0.04)}.app-bar__bottom .app_bar__marketplace_button{display:flex;align-items:center;justify-content:center;border:0;background:none;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);width:28px;height:28px;padding:6px;font-size:16px}.app-bar__bottom .app_bar__marketplace_button:focus,.app-bar__bottom .app_bar__marketplace_button:focus-within{box-sizing:border-box;border:2px solid rgba(var(--denim-button-bg-rgb), 0.32);box-shadow:none;outline:none}.app-bar__bottom .app_bar__marketplace_button:hover{border:0;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.app-bar__bottom .app_bar__marketplace_button:active{border:0;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.app-bar__bottom .app_bar__marketplace_button:disabled{background:none;color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.app-bar__top::-webkit-scrollbar{display:none}
.app__body .shortcut-key{display:inline-block;padding:10px 9px 8px 8px;background:var(--center-channel-color);border-radius:4px;color:var(--center-channel-bg);font-size:14px;font-weight:500;line-height:1}.app__body .shortcut-key.shortcut-key--contrast{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.app__body .shortcut-key.shortcut-key--tooltip{padding:2px 5px;background-color:rgba(255,255,255,.08);color:rgba(255,255,255,.72);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.app__body .shortcut-key.shortcut-key--tutorial-tip{padding:2px 5px;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.app__body .shortcut-key.shortcut-key--shortcut-modal{font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.console__body .shortcut-key{display:inline-block;border-radius:4px}.console__body .shortcut-key.shortcut-key--tooltip{padding:2px 5px;background-color:rgba(255,255,255,.08);color:rgba(255,255,255,.72);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}
.shortcut-line{margin:16px 0}.shortcut-line span:first-child{margin-right:5px}.shortcut-line .shortcut-key{padding:2px 5px}.shortcut-line .shortcut-key+.shortcut-key{margin-left:2px}.tooltip-inner .shortcut-line{margin:4px 0}@media(max-height: 800px){.shortcut-line{margin-top:14px}}
.modal .shortcuts-modal{width:1100px;margin-top:50px}.modal .shortcuts-modal .modal-header .shortcut-line{margin:0}.modal .shortcuts-modal .modal-header .shortcut-line span:first-child{margin-right:12px}.modal .shortcuts-modal .modal-body{max-height:calc(100vh - 200px);padding:40px 48px}.modal .shortcuts-modal .section>div:first-child{margin-bottom:2.5em}.modal .shortcuts-modal .section .shortcut-line{display:flex}.modal .shortcuts-modal .section .shortcut-line span:first-child{margin-right:5px}.modal .shortcuts-modal .section-title{margin:0 0 24px;font-size:18px}.modal .shortcuts-modal .subsection{padding-left:15px;border-left:2px solid}.modal .shortcuts-modal .info__label{margin:1rem 0;text-align:center}@media(max-height: 800px){.modal .shortcuts-modal .section-title{margin-top:0}.modal .shortcuts-modal .info__label{margin-top:0}}
.FileSearchResultItem{display:flex;overflow:hidden;max-width:600px;flex-direction:row;flex-grow:1;align-items:center;padding:11px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:0 14px 8px 14px;background:rgba(0,0,0,0);border-radius:4px;color:var(--center-channel-color);cursor:pointer;transition:box-shadow .15s ease}.FileSearchResultItem .Menu__content{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg)}.FileSearchResultItem:hover,.FileSearchResultItem:focus-within,.FileSearchResultItem.keep-open{overflow:visible;box-shadow:0 2px 3px 0 rgba(0,0,0,.1),0 2px 3px 0 rgba(0,0,0,.1)}.FileSearchResultItem:hover .action-icon,.FileSearchResultItem:focus-within .action-icon,.FileSearchResultItem.keep-open .action-icon{display:flex;opacity:1}.FileSearchResultItem:hover .MenuWrapper,.FileSearchResultItem:focus-within .MenuWrapper,.FileSearchResultItem.keep-open .MenuWrapper{display:block;opacity:1}.FileSearchResultItem:hover .fileData,.FileSearchResultItem:focus-within .fileData,.FileSearchResultItem.keep-open .fileData{overflow:hidden}.FileSearchResultItem .file-icon{width:4rem;min-width:4rem;height:4rem}.FileSearchResultItem .fileData{display:flex;min-width:0;flex-direction:column;flex-grow:1;padding:0 11px;font-size:12px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.FileSearchResultItem .fileData .fileDataName{overflow:hidden;margin-bottom:3px;text-align:left;text-overflow:ellipsis}.FileSearchResultItem .fileData .fileMetadata{display:flex;flex-direction:row;font-weight:400;gap:8px}.FileSearchResultItem .fileData .fileMetadata>:not(.Tag){opacity:.56}.FileSearchResultItem .fileData .fileMetadata .Tag{max-width:100px}.FileSearchResultItem .post-image{min-width:4rem}.FileSearchResultItem .action-icon{display:flex;width:32px;min-width:32px;height:32px;justify-content:center;margin-left:8px;background-color:var(--center-channel-bg);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.72);cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.72);opacity:0;text-decoration:none;transition:opacity .15s ease}.FileSearchResultItem .action-icon.download-icon{margin-right:6px}.FileSearchResultItem .action-icon svg{display:flex}.FileSearchResultItem .action-icon:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.FileSearchResultItem .MenuWrapper{display:flex;opacity:0}
.FilesFilterMenu .MenuWrapper{z-index:100;align-self:end}.FilesFilterMenu .MenuWrapper .action-icon{z-index:5;display:flex;min-width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;text-align:center}.FilesFilterMenu .MenuWrapper .action-icon .icon-dot{position:absolute;top:6px;right:6px;width:10px;height:10px;border:2px solid var(--center-channel-bg);background-color:var(--button-bg);border-radius:50%}.FilesFilterMenu .MenuWrapper .action-icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.FilesFilterMenu .MenuItem span.icon{position:absolute;right:13px;color:var(--button-bg)}
.MessagesOrFilesSelector{display:flex;align-items:center;justify-content:space-between;padding:7px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.MessagesOrFilesSelector .buttons-container{margin:7px 0}.MessagesOrFilesSelector .tab{padding:4px 12px;border:0;margin-right:4px;background-color:rgba(var(--center-channel-bg-rgb), 1);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-weight:600;text-decoration:none}.MessagesOrFilesSelector .tab.active{background-color:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg)}.MessagesOrFilesSelector .tab.active .counter{background-color:rgba(var(--button-bg-rgb), 0.08)}.MessagesOrFilesSelector .tab .counter{position:relative;bottom:1px;padding:1px 6px;margin-left:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08);border-radius:8px;font-size:10px;font-weight:700}
.AutoHeight{display:block}.AutoHeight>div{display:block}
.truncate,.PostAttachmentOpenGraph__body .description,.PostAttachmentOpenGraph__body .sitename,.PostAttachmentOpenGraph__body .title{display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;hyphens:auto;-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text}.PostAttachmentOpenGraph{position:relative;display:grid;width:100%;max-width:700px;padding:16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:5px 0;background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);grid-auto-columns:80px;grid-template-columns:1fr;text-decoration:none !important;transition:box-shadow}.PostAttachmentOpenGraph:hover:not(:active){border-color:rgba(var(--center-channel-color-rgb), 0.24);box-shadow:0 4px 6px rgba(0,0,0,.12)}.PostAttachmentOpenGraph:hover .remove-button{display:block}.PostAttachmentOpenGraph:active{border-color:rgba(var(--button-bg-rgb), 0.32)}.PostAttachmentOpenGraph .remove-button{position:absolute;z-index:10;top:-1px;left:-28px;display:none;padding:5px;background-color:rgba(var(--center-channel-color-rgb), 0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56)}.PostAttachmentOpenGraph .remove-button:hover:not(:active){background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.56)}.PostAttachmentOpenGraph .remove-button:active{background-color:rgba(var(--button-bg-rgb), 0.16);color:rgba(var(--button-bg-rgb), 1)}.PostAttachmentOpenGraph__body .sitename,.PostAttachmentOpenGraph__body .title{-webkit-line-clamp:1;word-break:break-all}.PostAttachmentOpenGraph__body .sitename{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:11px;font-weight:400;line-height:16px}.PostAttachmentOpenGraph__body .title{margin-bottom:4px;color:var(--link-color);font-size:14px;font-weight:600;line-height:20px}.PostAttachmentOpenGraph__body .description{color:var(--center-channel-color);font-size:14px;font-weight:400;-webkit-line-clamp:2;line-height:20px;word-break:none}.PostAttachmentOpenGraph__body .isInPermalink{overflow:hidden;width:100%;height:1.5em;line-height:1.5em;text-overflow:ellipsis;white-space:nowrap}.PostAttachmentOpenGraph__image{position:relative;display:flex;overflow:visible;height:80px;border-radius:4px;grid-column:2/3;grid-row:1/2;place-content:stretch;place-items:stretch}.PostAttachmentOpenGraph__image.large{width:auto;max-width:392px;height:auto;max-height:240px;margin-top:12px;grid-column:1/2;grid-row:2/3;place-content:center;place-items:center}.PostAttachmentOpenGraph__image figure{overflow:hidden;max-width:392px;max-height:240px;border-radius:4px}.PostAttachmentOpenGraph__image figure img{min-width:100%;min-height:100%;object-fit:cover}.PostAttachmentOpenGraph__image .preview-toggle{position:absolute;top:-4px;left:-4px;display:flex;width:24px;height:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:50%;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;place-content:center;place-items:center}.PostAttachmentOpenGraph__image.collapsed{place-content:start;place-items:start}.PostAttachmentOpenGraph__image.collapsed .preview-toggle{position:relative;top:unset;left:unset;display:flex;width:auto;border:none;background-color:rgba(0,0,0,0);border-radius:0}.PostAttachmentOpenGraph__image:hover:not(.collapsed) .preview-toggle{display:flex}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.AcknowledgementButton{height:24px;padding:4px 6px;font-size:11px;line-height:16px;position:relative;display:flex;min-width:0;align-items:center;border:0;margin:4px 0;background:rgba(var(--online-indicator-rgb), 0.08);border-radius:4px;color:var(--online-indicator);font-weight:600;transition:all .15s ease-out}.AcknowledgementButton>svg{margin-right:3px;fill:var(--online-indicator)}.AcknowledgementButton--default{padding-right:9px}.AcknowledgementButton--disabled,.AcknowledgementButton:disabled{background:rgba(var(--online-indicator-rgb), 0.08);cursor:default}.AcknowledgementButton:hover:enabled{background:rgba(var(--online-indicator-rgb), 0.12)}.AcknowledgementButton:active:enabled{background:rgba(var(--online-indicator-rgb), 0.16)}.AcknowledgementButton--acked{background:rgba(var(--online-indicator-rgb), 0.8);color:#fff}.AcknowledgementButton--acked>svg{margin-right:3px;fill:#fff}.AcknowledgementButton--acked.AcknowledgementButton--disabled,.AcknowledgementButton--acked.AcknowledgementButton--disabled:hover,.AcknowledgementButton--acked:disabled{background:rgba(var(--online-indicator-rgb), 0.8);color:#fff}.AcknowledgementButton--acked.AcknowledgementButton--disabled>svg,.AcknowledgementButton--acked.AcknowledgementButton--disabled:hover>svg,.AcknowledgementButton--acked:disabled>svg{margin-right:3px;fill:#fff}.AcknowledgementButton--acked:active:enabled:not(.AcknowledgementButton--disabled),.AcknowledgementButton--acked:hover:enabled:not(.AcknowledgementButton--disabled){background:rgb(var(--online-indicator-rgb))}.AcknowledgementButton__divider{width:1px;height:24px;margin:0 4px;background:rgba(var(--center-channel-color-rgb), 0.16)}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.Separator{position:relative;z-index:1;height:1px;margin:0;margin-top:-1em;margin-bottom:1em;pointer-events:none;text-align:center}.Separator::before,.Separator::after{position:absolute;left:0;display:none;width:100%;height:1em;content:""}.Separator::before{bottom:0}.Separator::after{top:0}.Separator.hovered--after::before{display:block;background:#f5f5f5}.Separator.hovered--before::after{display:block;background:#f5f5f5}.Separator .separator__hr{position:relative;z-index:5;top:1em;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:0}.Separator .separator__text{position:relative;z-index:5;display:inline-block;padding:0 1em;background:var(--center-channel-bg);border-radius:50px;color:var(--center-channel-color);font-size:13px;font-weight:700;line-height:2em}@media screen and (max-width: 1440px){.Separator.hovered--comment::before,.Separator.hovered--comment::after{background:none !important}}@media screen and (max-width: 768px){.Separator.hovered--after::before{background:none}.Separator.hovered--before::after{background:none}}@media print{.Separator .separator__hr{top:1.7em}}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.reaction-emoji--large img{width:48px;max-width:none;height:48px;max-height:none;margin:4px 0}.Reaction{padding:0;border:none;background:rgba(0,0,0,0);display:inline-flex;min-width:28px;height:24px;align-items:center;padding:0 5px;border:1px solid rgba(0,0,0,0);margin:0 4px 4px 0;background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.64);cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.56);font-size:11px;font-weight:600;transition:border-color 100ms linear,background-color 100ms linear;user-select:none}.Reaction:focus{outline:0;text-decoration:none}.Reaction.btn{padding:6px 12px}.Reaction.btn--block{width:100%;text-align:left}.Reaction:hover,.Reaction:active{text-decoration:none}.Reaction:hover{border:solid 1px rgba(61,60,64,.16);background-color:rgba(0,0,0,0);color:rgba(61,60,64,.72)}.Reaction:not(.Reaction--reacted):hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.Reaction:not(.Reaction--reacted):active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.Reaction.Reaction--read-only{cursor:default}.Reaction__add{position:relative;font-size:20px;line-height:0;vertical-align:middle}.Reaction__emoji{min-width:16px;max-width:16px;min-height:16px;max-height:16px;margin:0 2px 0 0;object-fit:contain;vertical-align:middle}.Reaction__emoji--large{width:48px;max-width:none;height:48px;max-height:none;margin:4px 0}.Reaction__emoji--post-menu{width:18px;height:18px;vertical-align:middle}.Reaction__count{display:flex;overflow:hidden;flex-direction:row-reverse;justify-content:flex-start;line-height:16px;pointer-events:none}.Reaction.Reaction--reacted,.Reaction.Reaction--reacting{border-color:var(--button-bg);background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.Reaction.Reaction--reacted:hover,.Reaction.Reaction--reacting:hover{border-color:var(--button-bg);background:var(--center-channel-bg)}.Reaction.Reaction--reacted:active,.Reaction.Reaction--reacting:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.Reaction.Reaction--reacting{transition:border-color 200ms ease-in-out}.Reaction.Reaction--reacting .Reaction__number--display{visibility:hidden}.Reaction.Reaction--reacting .Reaction__number--reacted,.Reaction.Reaction--reacting .Reaction__number--unreacted{display:inline-block;animation-duration:200ms;animation-fill-mode:forwards;animation-name:reacted-anim;animation-timing-function:ease-in-out}.Reaction.Reaction--unreacting{transition:border-color 200ms ease-in-out}.Reaction.Reaction--unreacting .Reaction__number--display{visibility:hidden}.Reaction.Reaction--unreacting .Reaction__number--reacted,.Reaction.Reaction--unreacting .Reaction__number--unreacted{display:inline-block;animation-direction:reverse;animation-duration:200ms;animation-fill-mode:forwards;animation-name:reacted-anim;animation-timing-function:ease-in-out}.Reaction .Reaction__number{position:relative}.Reaction .Reaction__number--display{display:inline-block}.Reaction .Reaction__number--reacted{position:absolute;top:100%;left:0;display:none}.Reaction .Reaction__number--unreacted{position:absolute;top:0%;left:0;display:none}@keyframes reacted-anim{from{transform:translateY(0%)}to{transform:translateY(-100%)}}
.Button{position:relative;padding:4px 10px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:Open Sans;font-style:normal;font-weight:600}.Button.allowTextOverflow{min-width:4rem}.Button.allowTextOverflow .Button_label{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.Button:hover{text-decoration:none}.Button:disabled{opacity:32%}.Button.Button___transparent{border:none;background:rgba(0,0,0,0)}.Button.Button___transparent:hover:not(:disabled){background:rgba(var(--center-channel-color-rgb), 0.08)}.Button.Button___transparent:active:not(:disabled),.Button.Button___transparent.is-active:not(:disabled){background:rgba(var(--button-bg-rgb), 0.08)}.Button.Button___transparent.is-active:active:not(:disabled),.Button.Button___transparent.is-active:hover:not(:disabled){background:rgba(var(--button-bg-rgb), 0.16)}.Button.Button___transparent.is-active:hover:active:not(:disabled){background:rgba(var(--button-bg-rgb), 0.24)}.Button.Button___transparent:hover:not(:disabled){color:rgba(var(--center-channel-color-rgb), 0.72)}.Button.Button___transparent:active:not(:disabled),.Button.Button___transparent.is-active:not(:disabled){color:rgba(var(--button-bg-rgb), 1)}.Button.Button___large{font-size:14px}.Button.Button___large.Button___icon{width:32px;height:32px;padding:7px 0;font-size:18px;line-height:18px}.Button .Button_label{display:inline-block;max-width:100%}.Button .Button_label.margin_top{margin-top:4px}.Button .Button_prepended{margin-right:.5em}.Button .Button_appended{margin-left:.5em}.Button .dot{position:absolute;top:6px;right:6px;width:4px;height:4px;background:rgba(var(--sidebar-text-active-border-rgb), 1);border-radius:50%}.separated+.separated{margin-left:var(--button-separator-gap, 0)}.separated:not(.Button)+.separated:not(.Button),.separated:not(.Button)+.separated:not(:hover):not(.is-active),.separated:not(:hover):not(.is-active)+.separated:not(.Button),.separated:not(:hover):not(.is-active)+.separated:not(:hover):not(.is-active){position:relative}.separated:not(.Button)+.separated:not(.Button)::before,.separated:not(.Button)+.separated:not(:hover):not(.is-active)::before,.separated:not(:hover):not(.is-active)+.separated:not(.Button)::before,.separated:not(:hover):not(.is-active)+.separated:not(:hover):not(.is-active)::before{position:absolute;top:50%;left:calc(-0.5px - var(--button-separator-gap, 0px)/2);display:inline-block;width:1px;height:var(--button-separator-height, 100%);background:rgba(var(--center-channel-color-rgb), 0.16);content:"";pointer-events:none;transform:translateY(-50%)}
.Avatars{display:inline-flex;flex-flow:nowrap;align-items:center;justify-content:center}.Avatars.Avatars___xxs{--offset: -4px;--border-width: 1px}.Avatars.Avatars___xs{--offset: -5px;--border-width: 1px}.Avatars.Avatars___sm{--offset: -5px;--border-width: 1px}.Avatars.Avatars___md{--offset: -6px;--border-width: 1.5px}.Avatars.Avatars___lg{--offset: -7px;--border-width: 2px}.Avatars.Avatars___xl{--offset: -10px;--border-width: 2px}.Avatars.Avatars___xxl{--offset: -26px;--border-width: 5px}.Avatars>button{transition:all 100ms ease-in-out}.Avatars>button:not(:first-child){margin-left:var(--offset)}.Avatars>button:hover,.Avatars>button:focus{z-index:1;box-shadow:var(--elevation-2);transform:scale(1.2)}.Avatars .Avatar{border:var(--border-width) solid rgba(var(--center-channel-bg-rgb), 1)}.Avatars .Avatar:not(:first-child){margin-left:var(--offset)}.Avatars .Avatar:hover,.Avatars .Avatar:focus{z-index:1;filter:drop-shadow(0 2px 3px rgba(0, 0, 0, 0.08))}.Avatars .Avatar.Avatar-plain[data-content^="+"]::before{text-indent:-4%}
.ThreadFooter{--button-separator-height: 15px;--button-separator-gap: 4px;position:relative;left:-34px;display:inline-flex;width:calc(100% + 15px);align-items:center;padding:0 0 5px 10px;margin-top:1px;margin-bottom:5px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:15px;white-space:nowrap}.ThreadFooter .indicator{width:24px;height:24px;padding:8px}.ThreadFooter .dot-unreads{width:8px;height:8px;background:rgba(var(--sidebar-text-active-border-rgb), 1);border-radius:50%}.ThreadFooter .Avatars{margin-right:4px;font-weight:600}.ThreadFooter .icon{width:14px;height:13px;font-size:14px}.ThreadFooter .alt-visible{opacity:0}.ThreadFooter:hover .alt-visible,.ThreadFooter:focus-within .alt-visible,.ThreadFooter.is-active .alt-visible,.post:hover .ThreadFooter .alt-visible,.post:focus-within .ThreadFooter .alt-visible{opacity:1}.ThreadFooter:hover .alt-hidden,.ThreadFooter:focus-within .alt-hidden,.ThreadFooter.is-active .alt-hidden,.post:hover .ThreadFooter .alt-hidden,.post:focus-within .ThreadFooter .alt-hidden{display:none}.ThreadFooter .Timestamp{display:inline-grid;padding-left:1rem;font-weight:400}.ThreadFooter .Timestamp>span{display:inline-block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}
.visit-marketplace-text{margin:12px;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;text-align:center}.visit-marketplace{top:1px;padding-top:4px;padding-right:16px;padding-bottom:16px;padding-left:16px;font-size:12px;text-align:center}.visit-marketplace-button{border-radius:4px}.visit-marketplace-button-text{align-items:center;font-size:12px;font-weight:600;line-height:9px}.visit-marketplace-button-icon{margin-right:5px;font-size:14.4px}
.forward-post.modal-dialog{margin-top:64px}.forward-post__body{display:flex;overflow:visible;flex-direction:column;color:var(--center-channel-color);gap:24px}.forward-post__body .custom-textarea,.forward-post__body #forward_post_textbox{min-height:40px;padding:10px 16px}.forward-post__body #forward_post_textbox{overflow:auto;border:none;box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.forward-post__body #forward_post_textbox:focus{box-shadow:inset 0 0 0 2px var(--button-bg)}.forward-post__body #forward_post_textbox:focus:not(:focus-visible){box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.forward-post__body #forward_post_textbox:focus:focus-visible{box-shadow:inset 0 0 0 2px var(--button-bg)}.forward-post__select{position:relative}.forward-post__select .option,.forward-post__select .singleValue{top:100%;display:grid;align-content:center;align-items:center;color:var(--center-channel-color);gap:12px;grid-auto-columns:minmax(20%, max-content);grid-template-columns:24px 1fr;grid-template-rows:24px}.forward-post__select .option svg,.forward-post__select .option .status-wrapper,.forward-post__select .option .status--group,.forward-post__select .singleValue svg,.forward-post__select .singleValue .status-wrapper,.forward-post__select .singleValue .status--group{place-self:center}.forward-post__select .option .status--group,.forward-post__select .singleValue .status--group{display:flex;width:1.8rem;height:1.8rem;align-items:center;justify-content:center;margin:0;background-color:rgba(var(--center-channel-color-rgb), 0.12)}.forward-post__select .option .status-wrapper,.forward-post__select .singleValue .status-wrapper{height:2.4rem}.forward-post__select .option__content,.forward-post__select .singleValue__content{display:flex;overflow:hidden;max-width:100%;flex-direction:row;gap:8px}.forward-post__select .option__content--text,.forward-post__select .singleValue__content--text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.forward-post__select .option__content--description,.forward-post__select .singleValue__content--description{color:rgba(var(--center-channel-color-rgb), 0.56)}.forward-post__select .option__content .emoticon,.forward-post__select .singleValue__content .emoticon{margin-left:0}.forward-post__select .option__team-name,.forward-post__select .singleValue__team-name{overflow:hidden;width:100%;color:rgba(var(--center-channel-color-rgb), 0.56);grid-column:3/4;text-align:right;text-overflow:ellipsis;white-space:nowrap}.forward-post__post-preview--title{font-size:12px;font-weight:600;line-height:16px}.forward-post__post-preview--override{padding:2px 0;pointer-events:none}.forward-post__post-preview--override:not(.post--editing):not(.post--editing):hover{background-color:rgba(0,0,0,0)}.forward-post__post-preview--override:not(.post--editing):not(.post--editing):hover .attachment__content.attachment__content--permalink{box-shadow:0 2px 3px rgba(0,0,0,.08)}.console__body .modal .GenericModal.forward-post,.app__body .modal .GenericModal.forward-post{margin-top:64px}.console__body .modal .GenericModal.forward-post .modal-body,.app__body .modal .GenericModal.forward-post .modal-body{max-height:calc(100vh - 128px - 61px - 88px)}.console__body .modal .GenericModal.forward-post .modal-body .form-control,.app__body .modal .GenericModal.forward-post .modal-body .form-control{border:none;box-shadow:none}.console__body .modal .GenericModal.forward-post .modal-body .form-control#forward_post_textbox_placeholder,.app__body .modal .GenericModal.forward-post .modal-body .form-control#forward_post_textbox_placeholder{opacity:.64 !important}.console__body .modal .GenericModal.forward-post .modal-body .post-error,.app__body .modal .GenericModal.forward-post .modal-body .post-error{position:relative;top:3px;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}
.menuModal .modal-header>.close{visibility:hidden}.menuModal .GenericModal__body{padding:0}
.move-thread .modal-body{overflow:visible}.move-thread.modal-dialog{margin-top:64px}.move-thread__body{display:flex;overflow:visible;flex-direction:column;color:var(--center-channel-color);gap:24px}.move-thread__body .custom-textarea,.move-thread__body #move_thread_textbox{min-height:40px;padding:10px 16px}.move-thread__body #move_thread_textbox{overflow:auto;border:none;box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.move-thread__body #move_thread_textbox:focus{box-shadow:inset 0 0 0 2px var(--button-bg)}.move-thread__body #move_thread_textbox:focus:not(:focus-visible){box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.move-thread__body #move_thread_textbox:focus:focus-visible{box-shadow:inset 0 0 0 2px var(--button-bg)}.move-thread__select{position:relative}.move-thread__select .option,.move-thread__select .singleValue{top:100%;display:grid;align-content:center;align-items:center;color:var(--center-channel-color);gap:12px;grid-auto-columns:minmax(20%, max-content);grid-template-columns:24px 1fr;grid-template-rows:24px}.move-thread__select .option svg,.move-thread__select .option .status-wrapper,.move-thread__select .option .status--group,.move-thread__select .singleValue svg,.move-thread__select .singleValue .status-wrapper,.move-thread__select .singleValue .status--group{place-self:center}.move-thread__select .option .status--group,.move-thread__select .singleValue .status--group{display:flex;width:1.8rem;height:1.8rem;align-items:center;justify-content:center;margin:0;background-color:rgba(var(--center-channel-color-rgb), 0.12)}.move-thread__select .option .status-wrapper,.move-thread__select .singleValue .status-wrapper{height:2.4rem}.move-thread__select .option__content,.move-thread__select .singleValue__content{display:flex;overflow:hidden;max-width:100%;flex-direction:row;gap:8px}.move-thread__select .option__content--text,.move-thread__select .singleValue__content--text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.move-thread__select .option__content--description,.move-thread__select .singleValue__content--description{color:rgba(var(--center-channel-color-rgb), 0.56)}.move-thread__select .option__content .emoticon,.move-thread__select .singleValue__content .emoticon{margin-left:0}.move-thread__select .option__team-name,.move-thread__select .singleValue__team-name{overflow:hidden;width:100%;color:rgba(var(--center-channel-color-rgb), 0.56);grid-column:3/4;text-align:right;text-overflow:ellipsis;white-space:nowrap}.move-thread__post-preview--title{font-size:12px;font-weight:600;line-height:16px}.move-thread__post-preview--override{padding:2px 0;pointer-events:none}.move-thread__post-preview--override:not(.post--editing):not(.post--editing):hover{background-color:rgba(0,0,0,0)}.move-thread__post-preview--override:not(.post--editing):not(.post--editing):hover .attachment__content.attachment__content--permalink{box-shadow:0 2px 3px rgba(0,0,0,.08)}.console__body .modal .GenericModal.move-thread,.app__body .modal .GenericModal.move-thread{margin-top:64px}.console__body .modal .GenericModal.move-thread .modal-body,.app__body .modal .GenericModal.move-thread .modal-body{max-height:calc(100vh - 128px - 61px - 88px)}.console__body .modal .GenericModal.move-thread .modal-body .form-control,.app__body .modal .GenericModal.move-thread .modal-body .form-control{border:none;box-shadow:none}.console__body .modal .GenericModal.move-thread .modal-body .form-control#move_thread_textbox_placeholder,.app__body .modal .GenericModal.move-thread .modal-body .form-control#move_thread_textbox_placeholder{opacity:.64 !important}.console__body .modal .GenericModal.move-thread .modal-body .post-error,.app__body .modal .GenericModal.move-thread .modal-body .post-error{position:relative;top:3px;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}
.dot-menu__item-new-badge{display:flex;align-items:center;gap:4px}.dot-menu__post-reminder-menu-header{padding:6px 20px;margin:0;color:var(--center-channel-color);font-weight:bold;pointer-events:none}.dot-menu__item-trailing-icon{display:flex;margin-right:-4px}
.SearchResults .messages-or-files .active{background-color:rgba(var(--buton-bg-rgb), 0.08)}.SearchResults .messages-or-files a{padding:4px 12px;margin-left:10px;text-decoration:none}.SearchResults .channel-files__header{display:flex;align-items:center;justify-content:space-between;padding:7px 14px}.SearchResults .channel-files__header .channel-files__title{font-size:14px;font-weight:600}.SearchResults .channel-files-container{padding-top:0}
.about-modal.cloud{position:absolute;top:50%;left:50%;margin:auto;transform:translate(-50%, -50%) !important}.about-modal.cloud .about-modal__hash{padding-bottom:20px}.about-modal.cloud .modal-content{overflow:hidden;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:8px;box-shadow:0 20px 32px rgba(0,0,0,.12)}.about-modal.cloud .modal-content .modal-header{width:600px;height:66px}.about-modal.cloud .modal-content .modal-body{overflow:hidden;width:600px;padding:0 50px}.about-modal.cloud .modal-content .modal-body .about-modal__logo{padding-right:32px;padding-left:0}.about-modal.cloud .modal-content .modal-body .about-modal__logo svg{width:104px;height:104px}.about-modal.cloud .modal-content .modal-body .about-modal__title{margin:0;font-size:24px;font-weight:600;line-height:32px}.about-modal.cloud .modal-content .modal-body .about-modal__content{padding-top:46px}.about-modal.cloud .modal-content .modal-body .subtitle{top:32px;left:0;width:294px;height:24px;margin-bottom:16px;color:var(--center-channel-color);font-size:16px;line-height:24px}.about-modal.cloud .modal-content .modal-body .description,.about-modal.cloud .modal-content .modal-body .form-group{top:0;left:0;width:342px;height:20px;align-self:center;margin:0 0;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14px;line-height:20px}.about-modal.cloud .modal-content .modal-body .about-footer{margin-top:16px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;line-height:16px}.about-modal.cloud .modal-content .modal-body .about-footer .copy-right{margin-top:12px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.FeatureRestrictedModal__description{color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.FeatureRestrictedModal__terms{padding-top:14px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-weight:400;line-height:16px}.FeatureRestrictedModal__terms a{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px}.FeatureRestrictedModal__terms a:hover,.FeatureRestrictedModal__terms a:active,.FeatureRestrictedModal__terms a:focus{text-decoration-line:underline}.FeatureRestrictedModal__terms a:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.FeatureRestrictedModal__buttons{display:flex;justify-content:space-between;padding:24px 0}.FeatureRestrictedModal__buttons .button-plans{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.FeatureRestrictedModal__buttons .button-plans:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.FeatureRestrictedModal__buttons .button-plans:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.FeatureRestrictedModal__buttons .button-plans:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.FeatureRestrictedModal__buttons .button-plans i{display:flex;font-size:18px}.FeatureRestrictedModal__buttons .button-plans i:first-child::before{margin:0 7px 0 0}.FeatureRestrictedModal__buttons .button-plans i:last-child::before{margin:0 0 0 7px}.FeatureRestrictedModal__buttons .button-trial{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.FeatureRestrictedModal__buttons .button-trial:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.FeatureRestrictedModal__buttons .button-trial:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.FeatureRestrictedModal__buttons .button-trial:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.FeatureRestrictedModal__buttons .button-trial:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.FeatureRestrictedModal__buttons .button-trial i{display:flex;font-size:18px}.FeatureRestrictedModal__buttons.single{justify-content:flex-end}.FeatureRestrictedModal__buttons.single .button-plans{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out}.FeatureRestrictedModal__buttons.single .button-plans:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.FeatureRestrictedModal__buttons.single .button-plans:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.FeatureRestrictedModal__buttons.single .button-plans:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.FeatureRestrictedModal__buttons.single .button-plans:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.FeatureRestrictedModal__buttons.single .button-plans i{display:flex;font-size:18px}
.RestrictedIndicator__icon-tooltip-container{display:flex;height:100%;flex:1;align-self:stretch;padding:0 10px}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__button{padding:0}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__icon-tooltip{padding:5px 0;color:var(--denim-button-bg);line-height:22px}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__icon-tooltip.trial::before{content:"⚡"}a:focus+.RestrictedIndicator__icon-tooltip-container,a:hover+.RestrictedIndicator__icon-tooltip-container,button:focus+.RestrictedIndicator__icon-tooltip-container,button:hover+.RestrictedIndicator__icon-tooltip-container{background-color:rgba(var(--center-channel-color-rgb), 0.1)}.RestrictedIndicator__icon-tooltip{max-width:240px;align-items:center}.RestrictedIndicator__icon-tooltip .title{display:block;line-height:15px}.RestrictedIndicator__icon-tooltip .message{font-size:11px;letter-spacing:.02em;line-height:16px;opacity:.56}
#systemConsole{position:relative}.system-console-visit{position:absolute;top:0;right:0;bottom:0;left:0}
#statusDropdownMenu .icon{position:relative;display:inline-flex;width:24px;height:24px;justify-content:center;padding:0;margin:0 8px 0 0}#statusDropdownMenu .icon span{display:flex}#statusDropdownMenu .icon svg{width:16px;height:16px}#statusDropdownMenu #status-menu-dnd{padding:4px 16px}#statusDropdownMenu #status-menu-dnd .dropdown-menu{margin:auto}#statusDropdownMenu #status-menu-dnd .dropdown-menu #dndSubMenu-header{font-weight:bold;pointer-events:none}#statusDropdownMenu #status-menu-dnd .icon{top:2px}#statusDropdownMenu #status-menu-dnd .SubMenu__icon-right{padding-top:5px}#status-menu-dnd_menuitem .SubMenuItem.MenuItem{flex-grow:1}#status-menu-dnd_menuitem .SubMenuItemContainer:hover,#status-menu-dnd_menuitem .SubMenuItemContainer:focus{background-color:unset}#status-menu-dnd_menuitem #dndTime-tomorrow .dndTime-tomorrow_timestamp{margin-left:auto;opacity:.7}#status-menu-dnd_menuitem #dndTime-tomorrow .dndTime-tomorrow_timestamp::before{content:" "}button.custom_status__row{position:relative;height:auto;font-size:inherit}button.custom_status__row.flex{display:flex}button.custom_status__row:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08)}button.custom_status__row:hover .custom-status-emoji{fill:rgba(var(--center-channel-color-rgb), 0.72)}button.custom_status__row:active{background-color:rgba(var(--button-bg-rgb), 0.08)}.custom_status__container{display:flex;padding:7px 0;line-height:20px}.custom_status__icon{margin-right:12px}.custom_status__text{overflow:hidden;max-width:73%;height:16px;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.custom_status__expiry{font-size:12px;line-height:16px;opacity:.7}.custom_status__expiry.padded{display:block;padding-left:28px}#custom_status__clear{position:absolute;top:0;right:10px;width:auto;padding:0;color:rgba(var(--center-channel-color-rgb), 0.52)}#custom_status__clear:hover{background:rgba(0,0,0,0)}.custom-status-emoji{fill:rgba(var(--center-channel-color-rgb), 0.56)}.custom-status-suggestion-emoji>span:first-child{background-size:20px}.status-dropdown-menu-global-header{padding:4px 8px;border-radius:4px}.status-dropdown-menu-global-header .icon>i:not(.status-icon){color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"compass-icons"}.status-dropdown-menu-global-header:hover{background:var(--sidebar-text-08);cursor:pointer}.status-dropdown-menu-global-header:hover .status{background-image:linear-gradient(0deg, rgba(var(--global-header-text-rgb), 0.08), rgba(var(--global-header-text-rgb), 0.08))}.status-dropdown-menu-global-header.active{background:rgba(var(--global-header-text-rgb), 0.16)}.status-dropdown-menu-global-header.active .status{background-image:linear-gradient(0deg, rgba(var(--global-header-text-rgb), 0.16), rgba(var(--global-header-text-rgb), 0.16))}.status-dropdown-menu-global-header .Menu__content{right:-1px;left:inherit;width:264px}.status-dropdown-menu-global-header .custom_status__row>#custom_status__clear{top:4px}.status-dropdown-menu-global-header .custom_status__container{align-items:center;line-height:14px}.status-dropdown-menu-global-header .username-wrapper{padding:0 12px}.status-dropdown-menu-global-header .username-wrapper>p{overflow:hidden;max-width:150px;text-overflow:ellipsis;white-space:nowrap}.status-dropdown-menu-global-header .username-wrapper>p.bold{font-weight:600}.status-dropdown-menu-global-header .MenuHeader{height:50px;padding:0 16px;cursor:pointer}.status-dropdown-menu-global-header .MenuHeader:hover{background-color:rgba(var(--center-channel-color-rgb), 0.1)}.status-dropdown-menu-global-header .MenuItem>button,.status-dropdown-menu-global-header #status-menu-dnd{padding:1px 16px}.status-dropdown-menu-global-header .MenuItem>button .flex,.status-dropdown-menu-global-header #status-menu-dnd .flex{display:flex}.status-dropdown-menu-global-header .MenuItem>button .MenuItem__primary-text,.status-dropdown-menu-global-header .MenuItem>button .grid,.status-dropdown-menu-global-header #status-menu-dnd .MenuItem__primary-text,.status-dropdown-menu-global-header #status-menu-dnd .grid{display:grid;align-items:center;grid-template-columns:auto 1fr auto auto auto}.status-dropdown-menu-global-header .MenuItem>button .MenuItem__primary-text .SubMenu__icon-right,.status-dropdown-menu-global-header .MenuItem>button .grid .SubMenu__icon-right,.status-dropdown-menu-global-header #status-menu-dnd .MenuItem__primary-text .SubMenu__icon-right,.status-dropdown-menu-global-header #status-menu-dnd .grid .SubMenu__icon-right{padding-top:0;padding-left:12px}.status-dropdown-menu-global-header .MenuItem>button>.MenuItem__help-text,.status-dropdown-menu-global-header #status-menu-dnd>.MenuItem__help-text{padding-left:28px}.status-dropdown-menu-global-header #statusDropdownMenu .icon,.status-dropdown-menu-global-header #statusDropdownMenu #status-menu-dnd .icon{top:unset;width:auto;height:auto;padding:0 12px 0 0;margin:0}.status-dropdown-menu-global-header #statusDropdownMenu .SubMenu__icon-right,.status-dropdown-menu-global-header #statusDropdownMenu #status-menu-dnd .SubMenu__icon-right{padding-top:0}.status-dropdown-menu-global-header .dnd--icon{vertical-align:middle}.status-dropdown-menu-global-header .status-wrapper{display:flex;height:auto;align-items:center}.status-dropdown-menu-global-header .status-wrapper .status{position:absolute;top:auto;right:-4px;bottom:-4px;display:inline-flex;width:16px;height:16px;align-items:center;justify-content:center;background-color:var(--global-header-background);color:var(--global-header-text)}.status-dropdown-menu-global-header .status-wrapper .status:hover{cursor:pointer}.status-dropdown-menu-global-header .status-wrapper .status svg{top:0}@keyframes pulse1{0%{opacity:1;transform:scale(1)}80%{opacity:0;transform:scale(2.5)}100%{opacity:0;transform:scale(2.5)}}@keyframes pulse2{0%{opacity:1;transform:scale(1)}30%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(2.5)}}.status-dropdpwn-menu .status-dropdown-menu__clear-container .input-clear{position:absolute;color:rgba(var(--center-channel-color-rgb), 0.72);opacity:1}.status-dropdpwn-account-settings{position:relative}#accountSettings{position:relative}.account-settings-complete{position:absolute;top:0;right:0;bottom:0;left:0}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.header-footer-route{position:relative;display:flex;overflow:hidden;width:100%;min-height:100%;flex-direction:column;margin:0 auto;grid-area:center}.header-footer-route .header-footer-route-container{display:flex;width:100%;height:100vh;flex-flow:column;background-image:url(/static/files/dfd37a8398963fbb9994.jpg);background-position:center;background-repeat:no-repeat;background-size:cover;-webkit-overflow-scrolling:touch;overflow-y:auto}
.PreparingWorkspaceDescription{margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:18px}@media screen and (max-width: 900px){.PreparingWorkspaceDescription{font-size:16px}}
.PreparingWorkspaceTitle{display:flex;margin-top:0;margin-bottom:12px;color:var(--sidebar-header-bg);font-size:56px;letter-spacing:-0.01em}.PreparingWorkspaceTitle .subtitle{font-size:18px;line-height:28px}.PreparingWorkspaceTitle svg{margin:0 10px 0 20px}@media screen and (max-width: 900px){.PreparingWorkspaceTitle{flex-direction:column;font-size:36px}.PreparingWorkspaceTitle .subtitle{font-size:14px;line-height:20px}}
.LaunchingWorkspaceFullscreenWrapper-body{position:fixed;top:0;right:0;bottom:0;left:0;display:flex;align-items:center;justify-content:center;background-image:url(/static/files/dfd37a8398963fbb9994.jpg);background-position:50%;background-repeat:no-repeat;background-size:cover;text-align:center}.LaunchingWorkspaceFullscreenWrapper-exit{opacity:1}.LaunchingWorkspaceFullscreenWrapper-exit-active{opacity:0;transition:opacity 500ms ease-in-out}.LaunchingWorkspaceFullscreenWrapper-edit-done{opacity:0}.LaunchingWorkspaceFullscreenWrapper__logo{position:absolute;z-index:1;top:32px;right:32px}.LaunchingWorkspace-body{display:flex;width:420px;height:100vh;flex-direction:column;align-items:center;justify-content:center;margin:auto;text-align:center}.LaunchingWorkspace-body--non-fullscreen{position:fixed;left:calc(50vw - 210px)}.LaunchingWorkspace__spinner{width:32px;margin-bottom:16px}.LaunchingWorkspace--enter-from-before-enter{opacity:0}.LaunchingWorkspace--enter-from-before-enter-active{opacity:1;transition:opacity 300ms ease-in-out}.LaunchingWorkspace--enter-from-before-enter-done{opacity:1}.LaunchingWorkspace--exit-to-before-exit{opacity:1}.LaunchingWorkspace--exit-to-before-exit-active{opacity:0;transition:opacity 300ms ease-in-out}.LaunchingWorkspace--exit-to-before-exit-done{opacity:0}
.mm-modal-generic-section-item{display:flex;flex-direction:column;gap:8px}.mm-modal-generic-section-item__title{display:flex;align-items:center;padding:0;margin:0 0 8px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.mm-modal-generic-section-item__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__content{display:flex;flex-direction:column}.mm-modal-generic-section-item__fieldset-checkbox-ctr{display:flex;flex-direction:row}.mm-modal-generic-section-item__fieldset-checkbox{display:flex;flex-direction:row;align-items:center;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-radio{display:flex;flex-direction:column;gap:12px}.mm-modal-generic-section-item__label-radio{display:flex;width:fit-content;flex-direction:row;align-items:center;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__input-checkbox{width:1.6rem;height:1.6rem}.mm-modal-generic-section-item input[type=checkbox]{display:grid;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);border-radius:3px;color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.mm-modal-generic-section-item input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=checkbox]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=checkbox]:checked{border-color:var(--denim-button-bg);background:var(--denim-button-bg)}.mm-modal-generic-section-item input[type=radio]{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);border-radius:50%;color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center}.mm-modal-generic-section-item input[type=radio]::before{width:8px;height:8px;background:var(--denim-button-bg);border-radius:50%;content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=radio]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=radio]:checked{border-color:var(--denim-button-bg)}
.mm-modal-header{display:flex;align-items:center;padding:20px 20px 20px 32px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);background:none;gap:8px}.mm-modal-header__title{padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px}.mm-modal-header__vertical-divider{width:1px;height:24px;background:rgba(var(--center-channel-color-rgb), 0.16)}.mm-modal-header__subtitle{overflow:hidden;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:inherit;font-size:12px;font-style:normal;font-weight:400;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.mm-modal-header__ctr{display:flex;flex:1 1 auto;align-items:center;justify-content:flex-end;color:rgba(var(--center-channel-color-rgb), 0.56);gap:24px}.mm-modal-header__close-btn{display:flex;overflow:hidden;width:40px;height:40px;align-items:center;justify-content:center;border:unset;margin-left:8px;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56)}.mm-modal-header__close-btn:hover,.mm-modal-header__close-btn.active{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}@media screen and (max-width: 768px){.mm-modal-header{padding:18px 24px}.mm-modal-header__title{font-size:20px}.mm-modal-header__subtitle{display:none}.mm-modal-header__vertical-divider{display:none}}
.mm-modal-generic-section{display:flex;flex-direction:column;gap:16px}.mm-modal-generic-section__info-ctr{display:flex;flex-direction:column;margin-bottom:8px;gap:8px}.mm-modal-generic-section__title{display:flex;align-items:center;padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:16px;font-style:normal;font-weight:600;line-height:24px}.mm-modal-generic-section__row{display:flex;align-items:center;gap:8px}.mm-modal-generic-section__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section__content{display:flex;flex-direction:column;gap:24px}
.modal .channel-notifications-settings-modal{overflow:hidden;width:100%;max-width:600px;margin-top:-24px}.modal .channel-notifications-settings-modal .modal-content{display:flex;overflow:hidden;max-height:calc(100vh - 240px);flex-direction:column;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:12px;box-shadow:var(--elevation-6)}.modal .channel-notifications-settings-modal__ctr{display:flex;place-items:center}.modal .channel-notifications-settings-modal .modal-header{border:none;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);background:none}.modal .channel-notifications-settings-modal__body{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;padding:32px;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .channel-notifications-settings-modal__footer{display:flex;width:100%;max-width:1024px;align-items:center;justify-content:flex-end;padding:24px 32px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);gap:8px}.modal .channel-notifications-settings-modal__reset-btn{display:flex;padding:5px 8px;border:none;background:rgba(0,0,0,0);border-radius:4px;color:var(--button-bg);font-size:12px;font-weight:600;gap:4px;line-height:9.5px;place-items:center}.modal .channel-notifications-settings-modal__reset-btn:hover,.modal .channel-notifications-settings-modal__reset-btn:active{background:rgba(var(--button-bg-rgb), 0.08)}.modal .channel-notifications-settings-modal__server-error{flex-grow:1;color:var(--error-text)}.modal .channel-notifications-settings-modal__save-btn{padding:12px 20px 12px 20px;border:none;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-size:14px;font-weight:600;line-height:14px;text-transform:capitalize}.modal .channel-notifications-settings-modal__save-btn:hover,.modal .channel-notifications-settings-modal__save-btn:active{background:rgba(var(--button-bg-rgb), 0.12);background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.modal .channel-notifications-settings-modal__save-btn:focus{box-sizing:border-box;padding:10px 18px;border:2px solid var(--sidebar-text-active-border);box-shadow:none}.modal .channel-notifications-settings-modal__cancel-btn{padding:12px 20px 12px 20px;border:none;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-size:14px;font-weight:600;line-height:14px;text-transform:capitalize}.modal .channel-notifications-settings-modal__cancel-btn:hover,.modal .channel-notifications-settings-modal__cancel-btn:active{background:rgba(var(--button-bg-rgb), 0.12)}.modal .channel-notifications-settings-modal__divider{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}@media screen and (max-width: 768px){.modal .channel-notifications-settings-modal{max-width:100%;margin:0}.modal .channel-notifications-settings-modal .modal-content{display:flex;height:100vh;max-height:unset;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.modal .channel-notifications-settings-modal .modal-content{max-height:calc(100vh - 160px)}}
.info-toast{position:fixed;z-index:99;right:16px;bottom:16px;display:grid;width:fit-content;min-height:40px;align-items:center;padding:8px;background:var(--center-channel-text);border-radius:4px;box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--sidebar-text);font-weight:600;grid-template-columns:min-content auto min-content auto;line-height:20px}.info-toast .info-toast__icon_button{color:inherit}.info-toast span{padding-left:4px}.info-toast>div{display:flex;align-items:center}.info-toast>div .Icon{font-size:16px}.info-toast__undo{display:flex;height:24px;align-items:center;padding:6px 10px;border:none;margin-right:16px;margin-left:8px;background:var(--button-bg);border-radius:4px;color:var(--sidebar-text);font-size:11px;font-weight:600;line-height:10px}.toast-appear{opacity:0;transform:translateY(150px)}.toast-appear-active{opacity:1;transform:translateY(0);transition:all 500ms ease}
.sidebar-right__edit-post-history .scrollbar--view{display:flex;flex-direction:column}.edit-post-history__error_container{display:flex;flex:1;align-items:center;justify-content:center}.edit-post-history__error_item{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:56px;text-align:center}.edit-post-history__error_heading{color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:28px}.edit-post-history__error_subheading{color:rgba(var(--center-channel-color-rgb), 0.72);font-weight:400}
.toast{position:absolute;z-index:2;width:calc(100% - 30px);height:32px;margin:10px 15px 0;background-color:var(--button-bg);border-radius:4px;color:var(--button-color);cursor:default;font-size:13px;font-weight:bold;opacity:0;visibility:hidden}.toast svg{fill:var(--button-color);vertical-align:middle}body.enable-animations .toast{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.toast .toast__jump{position:absolute}.toast .toast__jump svg{margin-right:5px;vertical-align:middle}.toast .toast__dismiss{position:absolute;right:0;height:32px;padding:0 8px;cursor:pointer}.toast .toast__dismiss:hover{background-color:rgba(0,0,0,.2)}.toast .toast__dismiss span{line-height:31px}.toast .toast__message{position:absolute;z-index:-1;width:calc(100% - 40px);height:32px;padding-left:10px;line-height:31px;text-align:center}.toast .toast__message.toast__pointer{cursor:pointer}.toast .toast__message.toast__pointer:hover{background-color:rgba(0,0,0,.2)}.toast__visible{opacity:1;visibility:visible}body.enable-animations .toast__visible{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.toast__history{z-index:1;background-color:#d8d8d8;color:#3d3c40}.toast__history svg{fill:rgba(61,60,64,.9)}.toast__red{background-color:#d64946}@media screen and (max-width: 768px){.toast .toast__message{display:inline-block}}.tooltip__shortcut--txt{opacity:.6}
.new-replies-banner{position:absolute;bottom:56px;display:flex;justify-content:center}.new-replies-banner .toast{width:156px}.new-replies-banner .toast .toast__jump~span{margin-left:24px}
.AdvancedTextEditor{display:flex;width:100%;flex-direction:row;align-items:end;padding:0 24px;margin:0 auto;gap:12px;justify-items:stretch;--right-padding-for-scrollbar: 0px;--right-padding-for-preview-button: 0px}.AdvancedTextEditor__ctr form{padding:unset}.sidebar--right .AdvancedTextEditor{padding-top:12px}.ThreadViewer .AdvancedTextEditor{padding-top:12px}.AdvancedTextEditor .custom-textarea{height:0;padding-right:calc(16px + var(--right-padding-for-scrollbar) + var(--right-padding-for-preview-button));box-shadow:none}.AdvancedTextEditor .custom-textarea:focus{box-shadow:none}.AdvancedTextEditor .custom-textarea.textbox-preview-area{height:auto}.AdvancedTextEditor.scroll{--right-padding-for-scrollbar: 8px}.AdvancedTextEditor.formatting-bar{--right-padding-for-preview-button: 32px}.AdvancedTextEditor__body{position:relative;max-width:100%;flex:1;border:2px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px}.AdvancedTextEditor__body:focus-visible,.AdvancedTextEditor__body:focus-within,.AdvancedTextEditor__body:focus-visible:hover,.AdvancedTextEditor__body:focus-within:hover{border:2px solid rgba(var(--center-channel-color-rgb), 0.32);outline:none;outline-offset:0}.AdvancedTextEditor__body:hover{border:2px solid rgba(var(--center-channel-color-rgb), 0.24)}.AdvancedTextEditor__body[disabled]:hover{border:none}.AdvancedTextEditor__action-button{display:flex;width:32px;height:32px;flex-shrink:0;align-items:center;justify-content:center;padding:0;border:none;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;fill:currentColor}.AdvancedTextEditor__action-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:currentColor;text-decoration:none}.AdvancedTextEditor__action-button.hidden{visibility:hidden}.AdvancedTextEditor__action-button+input{position:absolute;top:0;right:0;width:100%;height:100%;margin:0;cursor:pointer;direction:ltr;font-size:23px;opacity:0;pointer-events:none}.AdvancedTextEditor__action-button--active{background:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb));fill:currentColor}.AdvancedTextEditor__icon{display:inline-flex;width:100%;height:100%;align-items:center;justify-content:center;font-family:"compass-icons";font-size:18px}.AdvancedTextEditor__cell{position:relative;display:flex;flex-direction:column;vertical-align:top}.AdvancedTextEditor__helper-text{display:inline-block;margin:8px 0 4px;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif}.AdvancedTextEditor__footer{position:relative;display:flex;flex-direction:column;padding:0 24px;font-size:13px;gap:8px}.AdvancedTextEditor__footer .help__text{text-align:right}.AdvancedTextEditor__footer .help__text a,.AdvancedTextEditor__footer .help__text button{margin-left:10px}.AdvancedTextEditor__footer--has-error{padding:6px 0 0;color:var(--error-text)}.AdvancedTextEditor__footer .post-error{position:absolute;top:4px;display:inline-block;margin-bottom:0;font-size:.85em;font-weight:normal}@media screen and (max-width: 768px){.AdvancedTextEditor{padding:0}.AdvancedTextEditor__body{border-right:none;border-left:none;border-radius:0}.AdvancedTextEditor__body:focus-visible,.AdvancedTextEditor__body:focus-within,.AdvancedTextEditor__body:focus-visible:hover,.AdvancedTextEditor__body:focus-within:hover,.AdvancedTextEditor__body:hover{border-right:none;border-left:none}.ThreadViewer .AdvancedTextEditor .msg-typing:empty{display:none}.sidebar--right .post-create__container form{padding:0}}.msg-typing{display:block;overflow:hidden;height:20px;margin-bottom:5px;font-size:11px;opacity:.7;text-overflow:ellipsis;white-space:nowrap}
.NotificationSeparator .separator__hr{border-color:#ffaf53}.NotificationSeparator .separator__text{display:inline-flex;color:#f80;font-weight:normal}
.ThreadViewer .post:not(.same--root.same--user) a.post__permalink{position:initial !important;text-align:left !important}.ThreadViewer .post-list__dynamic--RHS{scrollbar-color:var(--center-channel-color-32) rgba(255,255,255,0);scrollbar-width:thin}.ThreadViewer>div{flex:1 1 auto}.ThreadViewer .channel-archived-warning__container{padding-top:16px}.ThreadViewer .channel-archived-warning__content{display:flex;justify-content:center;padding:24px;padding-right:47.5px;padding-left:46.5px;margin:0 auto;line-height:20px;text-align:center}.ThreadViewer .channel-archived-warning__content svg{margin-right:3.4px}
.LearnAboutTeamsLink>span{width:100%}.LearnAboutTeamsLink>span a{display:flex;align-items:center;padding:6px 18px;column-gap:10px}.LearnAboutTeamsLink>span a:hover,.LearnAboutTeamsLink>span a:focus,.LearnAboutTeamsLink>span a:active{text-decoration:none}.LearnAboutTeamsLink>span a>i{display:inline-flex !important;padding:3px;background-color:rgba(28,88,217,.08);border-radius:50%;font-size:14px !important}.LearnAboutTeamsLink>span a>i::before{margin:0}.LearnAboutTeamsLink>span a span{font-size:12px;font-weight:600;line-height:16px}.LearnAboutTeamsLink>span a span:hover{text-decoration:underline}
.GeneralTab__header{display:flex;align-items:center;justify-content:space-between;margin:20px 0}.GeneralTab__header>h3{margin:0}.GeneralTab__header>h3 span{display:inline-flex;font-size:20px;font-weight:600;line-height:28px}
.MainMenu_dropdown-link a:focus,.MainMenu_dropdown-link a:hover,.MainMenu_dropdown-link a:active{background-color:rgba(63,67,80,.1)}.MainMenu_dropdown-link a i+span:hover{text-decoration:none}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.TeamIcon__content{display:flex;overflow:hidden;height:100%;flex-direction:column;justify-content:center;border-radius:8px;transition:all .25s ease}.TeamIcon__content.no-hover{transition:none}.TeamIcon__initials.TeamIcon__initials__lg{font-size:3em}.TeamIcon__initials.TeamIcon__initials__sm{font-size:14px}.TeamIcon{position:relative;width:34px;height:34px;box-sizing:content-box;border:3px solid rgba(255,255,255,0);background-color:rgba(var(--sidebar-text-rgb), 0.16);border-radius:8px;font-weight:600;text-align:center;text-transform:uppercase;transform-origin:center center;transition:box-shadow .3s,background-color .3s,border-color .3s;will-change:box-shadow,background-color,border-color}.TeamIcon:not(.no-hover):hover{border-color:var(--sidebar-teambar-bg);background-color:rgba(var(--sidebar-text-rgb), 0.3);box-shadow:0 0 0 3px rgba(var(--sidebar-text-rgb), 0.3)}.TeamIcon:active{border-color:var(--sidebar-teambar-bg);box-shadow:0 0 0 3px var(--sidebar-text-active-border)}.TeamIcon.active{border-color:var(--sidebar-teambar-bg);background-color:rgba(var(--sidebar-text-rgb), 0.3);box-shadow:0 0 0 3px var(--sidebar-text-active-border)}.TeamIcon.TeamIcon__lg{width:94px;height:94px}.TeamIcon.TeamIcon__sm{width:34px;height:34px}.TeamIcon.withImage{border:none}.TeamIcon.withImage.TeamIcon__lg{width:100px;height:100px}.TeamIcon.withImage.TeamIcon__sm{width:40px;height:40px}.TeamIcon.withImage .TeamIcon__image{border-radius:8px;transition:box-shadow 200ms}.TeamIcon.withImage:not(.no-hover):hover{box-shadow:0 0 0 3px rgba(255,255,255,.32)}.TeamIcon.withImage:not(.no-hover):hover .TeamIcon__image{box-shadow:inset 0 0 0 3px var(--sidebar-teambar-bg)}.TeamIcon.withImage.active{box-shadow:0 0 0 3px rgba(var(--sidebar-text-active-border-rgb), 0.72)}.TeamIcon.withImage.active .TeamIcon__image{box-shadow:inset 0 0 0 3px var(--sidebar-teambar-bg)}.TeamIcon .TeamIcon__image{overflow:hidden;width:100%;height:100%;background-color:#fff;background-repeat:unset;background-size:100% 100%}

/*# sourceMappingURL=4270.f58b5c1654b3c72f3e0b.css.map*/